Class: Aws::Bedrock::Types::AutomatedReasoningCheckScenario

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Represents a logical scenario where claims can be evaluated as true or false, containing specific logical assignments.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#statementsArray<Types::AutomatedReasoningLogicStatement>

List of logical assignments and statements that define this scenario.



538
539
540
541
542
# File 'lib/aws-sdk-bedrock/types.rb', line 538

class AutomatedReasoningCheckScenario < Struct.new(
  :statements)
  SENSITIVE = []
  include Aws::Structure
end