Class: Aws::Bedrock::Types::AutomatedReasoningPolicyAddRuleAnnotation
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::AutomatedReasoningPolicyAddRuleAnnotation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
An annotation for adding a new rule to an Automated Reasoning policy using a formal logical expression.
Constant Summary collapse
- SENSITIVE =
[:expression]
Instance Attribute Summary collapse
-
#expression ⇒ String
The formal logical expression that defines the rule, using mathematical notation and referencing policy variables and types.
Instance Attribute Details
#expression ⇒ String
The formal logical expression that defines the rule, using mathematical notation and referencing policy variables and types.
694 695 696 697 698 |
# File 'lib/aws-sdk-bedrock/types.rb', line 694 class AutomatedReasoningPolicyAddRuleAnnotation < Struct.new( :expression) SENSITIVE = [:expression] include Aws::Structure end |