Class: Aws::Bedrock::Types::AutomatedReasoningPolicyAnnotatedContent

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Note:

AutomatedReasoningPolicyAnnotatedContent is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AutomatedReasoningPolicyAnnotatedContent corresponding to the set member.

Represents a content element within an annotated chunk. This union type allows for different types of content elements to be included in document chunks, such as individual lines of text with their line numbers.

Direct Known Subclasses

Line, Unknown

Defined Under Namespace

Classes: Line, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#lineTypes::AutomatedReasoningPolicyAnnotatedLine

An annotated line of text from the source document, including both the line number and the text content.



878
879
880
881
882
883
884
885
886
887
# File 'lib/aws-sdk-bedrock/types.rb', line 878

class AutomatedReasoningPolicyAnnotatedContent < Struct.new(
  :line,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Line < AutomatedReasoningPolicyAnnotatedContent; end
  class Unknown < AutomatedReasoningPolicyAnnotatedContent; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



878
879
880
# File 'lib/aws-sdk-bedrock/types.rb', line 878

def unknown
  @unknown
end