Class: Aws::Bedrock::Types::AutomatedReasoningPolicyAnnotatedLine

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Represents a single line of text from a source document, annotated with its line number for precise referencing.

Constant Summary collapse

SENSITIVE =
[:line_text]

Instance Attribute Summary collapse

Instance Attribute Details

#line_numberInteger

The line number of this text within the source document.

Returns:

  • (Integer)


902
903
904
905
906
907
# File 'lib/aws-sdk-bedrock/types.rb', line 902

class AutomatedReasoningPolicyAnnotatedLine < Struct.new(
  :line_number,
  :line_text)
  SENSITIVE = [:line_text]
  include Aws::Structure
end

#line_textString

The actual text content of this line from the source document.

Returns:

  • (String)


902
903
904
905
906
907
# File 'lib/aws-sdk-bedrock/types.rb', line 902

class AutomatedReasoningPolicyAnnotatedLine < Struct.new(
  :line_number,
  :line_text)
  SENSITIVE = [:line_text]
  include Aws::Structure
end