Class: Aws::Bedrock::Types::AutomatedReasoningPolicyAnnotation
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::AutomatedReasoningPolicyAnnotation
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
AutomatedReasoningPolicyAnnotation is a union - when making an API calls you must set exactly one of the members.
AutomatedReasoningPolicyAnnotation is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AutomatedReasoningPolicyAnnotation corresponding to the set member.
Contains the various operations that can be performed on an Automated Reasoning policy, including adding, updating, and deleting rules, variables, and types.
Direct Known Subclasses
AddRule, AddRuleFromNaturalLanguage, AddType, AddVariable, DeleteRule, DeleteType, DeleteVariable, IngestContent, Unknown, UpdateFromRulesFeedback, UpdateFromScenarioFeedback, UpdateRule, UpdateType, UpdateVariable
Defined Under Namespace
Classes: AddRule, AddRuleFromNaturalLanguage, AddType, AddVariable, DeleteRule, DeleteType, DeleteVariable, IngestContent, Unknown, UpdateFromRulesFeedback, UpdateFromScenarioFeedback, UpdateRule, UpdateType, UpdateVariable
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#add_rule ⇒ Types::AutomatedReasoningPolicyAddRuleAnnotation
An operation to add a new logical rule to the policy using formal mathematical expressions.
-
#add_rule_from_natural_language ⇒ Types::AutomatedReasoningPolicyAddRuleFromNaturalLanguageAnnotation
An operation to add a new rule by converting natural language descriptions into formal logical expressions.
-
#add_type ⇒ Types::AutomatedReasoningPolicyAddTypeAnnotation
An operation to add a new custom type to the policy, defining a set of possible values for policy variables.
-
#add_variable ⇒ Types::AutomatedReasoningPolicyAddVariableAnnotation
An operation to add a new variable to the policy, which can be used in rule expressions to represent dynamic values.
-
#delete_rule ⇒ Types::AutomatedReasoningPolicyDeleteRuleAnnotation
An operation to remove a rule from the policy.
-
#delete_type ⇒ Types::AutomatedReasoningPolicyDeleteTypeAnnotation
An operation to remove a custom type from the policy.
-
#delete_variable ⇒ Types::AutomatedReasoningPolicyDeleteVariableAnnotation
An operation to remove a variable from the policy.
-
#ingest_content ⇒ Types::AutomatedReasoningPolicyIngestContentAnnotation
An operation to process and incorporate new content into the policy, extracting additional rules and concepts.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#update_from_rules_feedback ⇒ Types::AutomatedReasoningPolicyUpdateFromRuleFeedbackAnnotation
An operation to update the policy based on feedback about how specific rules performed during testing or validation.
-
#update_from_scenario_feedback ⇒ Types::AutomatedReasoningPolicyUpdateFromScenarioFeedbackAnnotation
An operation to update the policy based on feedback about how it performed on specific test scenarios.
-
#update_rule ⇒ Types::AutomatedReasoningPolicyUpdateRuleAnnotation
An operation to modify an existing rule in the policy, such as changing its logical expression or conditions.
-
#update_type ⇒ Types::AutomatedReasoningPolicyUpdateTypeAnnotation
An operation to modify an existing custom type in the policy, such as changing its name, description, or allowed values.
-
#update_variable ⇒ Types::AutomatedReasoningPolicyUpdateVariableAnnotation
An operation to modify an existing variable in the policy, such as changing its name, type, or description.
Instance Attribute Details
#add_rule ⇒ Types::AutomatedReasoningPolicyAddRuleAnnotation
An operation to add a new logical rule to the policy using formal mathematical expressions.
983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-bedrock/types.rb', line 983 class AutomatedReasoningPolicyAnnotation < Struct.new( :add_type, :update_type, :delete_type, :add_variable, :update_variable, :delete_variable, :add_rule, :update_rule, :delete_rule, :add_rule_from_natural_language, :update_from_rules_feedback, :update_from_scenario_feedback, :ingest_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddType < AutomatedReasoningPolicyAnnotation; end class UpdateType < AutomatedReasoningPolicyAnnotation; end class DeleteType < AutomatedReasoningPolicyAnnotation; end class AddVariable < AutomatedReasoningPolicyAnnotation; end class UpdateVariable < AutomatedReasoningPolicyAnnotation; end class DeleteVariable < AutomatedReasoningPolicyAnnotation; end class AddRule < AutomatedReasoningPolicyAnnotation; end class UpdateRule < AutomatedReasoningPolicyAnnotation; end class DeleteRule < AutomatedReasoningPolicyAnnotation; end class AddRuleFromNaturalLanguage < AutomatedReasoningPolicyAnnotation; end class UpdateFromRulesFeedback < AutomatedReasoningPolicyAnnotation; end class UpdateFromScenarioFeedback < AutomatedReasoningPolicyAnnotation; end class IngestContent < AutomatedReasoningPolicyAnnotation; end class Unknown < AutomatedReasoningPolicyAnnotation; end end |
#add_rule_from_natural_language ⇒ Types::AutomatedReasoningPolicyAddRuleFromNaturalLanguageAnnotation
An operation to add a new rule by converting natural language descriptions into formal logical expressions.
983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-bedrock/types.rb', line 983 class AutomatedReasoningPolicyAnnotation < Struct.new( :add_type, :update_type, :delete_type, :add_variable, :update_variable, :delete_variable, :add_rule, :update_rule, :delete_rule, :add_rule_from_natural_language, :update_from_rules_feedback, :update_from_scenario_feedback, :ingest_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddType < AutomatedReasoningPolicyAnnotation; end class UpdateType < AutomatedReasoningPolicyAnnotation; end class DeleteType < AutomatedReasoningPolicyAnnotation; end class AddVariable < AutomatedReasoningPolicyAnnotation; end class UpdateVariable < AutomatedReasoningPolicyAnnotation; end class DeleteVariable < AutomatedReasoningPolicyAnnotation; end class AddRule < AutomatedReasoningPolicyAnnotation; end class UpdateRule < AutomatedReasoningPolicyAnnotation; end class DeleteRule < AutomatedReasoningPolicyAnnotation; end class AddRuleFromNaturalLanguage < AutomatedReasoningPolicyAnnotation; end class UpdateFromRulesFeedback < AutomatedReasoningPolicyAnnotation; end class UpdateFromScenarioFeedback < AutomatedReasoningPolicyAnnotation; end class IngestContent < AutomatedReasoningPolicyAnnotation; end class Unknown < AutomatedReasoningPolicyAnnotation; end end |
#add_type ⇒ Types::AutomatedReasoningPolicyAddTypeAnnotation
An operation to add a new custom type to the policy, defining a set of possible values for policy variables.
983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-bedrock/types.rb', line 983 class AutomatedReasoningPolicyAnnotation < Struct.new( :add_type, :update_type, :delete_type, :add_variable, :update_variable, :delete_variable, :add_rule, :update_rule, :delete_rule, :add_rule_from_natural_language, :update_from_rules_feedback, :update_from_scenario_feedback, :ingest_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddType < AutomatedReasoningPolicyAnnotation; end class UpdateType < AutomatedReasoningPolicyAnnotation; end class DeleteType < AutomatedReasoningPolicyAnnotation; end class AddVariable < AutomatedReasoningPolicyAnnotation; end class UpdateVariable < AutomatedReasoningPolicyAnnotation; end class DeleteVariable < AutomatedReasoningPolicyAnnotation; end class AddRule < AutomatedReasoningPolicyAnnotation; end class UpdateRule < AutomatedReasoningPolicyAnnotation; end class DeleteRule < AutomatedReasoningPolicyAnnotation; end class AddRuleFromNaturalLanguage < AutomatedReasoningPolicyAnnotation; end class UpdateFromRulesFeedback < AutomatedReasoningPolicyAnnotation; end class UpdateFromScenarioFeedback < AutomatedReasoningPolicyAnnotation; end class IngestContent < AutomatedReasoningPolicyAnnotation; end class Unknown < AutomatedReasoningPolicyAnnotation; end end |
#add_variable ⇒ Types::AutomatedReasoningPolicyAddVariableAnnotation
An operation to add a new variable to the policy, which can be used in rule expressions to represent dynamic values.
983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-bedrock/types.rb', line 983 class AutomatedReasoningPolicyAnnotation < Struct.new( :add_type, :update_type, :delete_type, :add_variable, :update_variable, :delete_variable, :add_rule, :update_rule, :delete_rule, :add_rule_from_natural_language, :update_from_rules_feedback, :update_from_scenario_feedback, :ingest_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddType < AutomatedReasoningPolicyAnnotation; end class UpdateType < AutomatedReasoningPolicyAnnotation; end class DeleteType < AutomatedReasoningPolicyAnnotation; end class AddVariable < AutomatedReasoningPolicyAnnotation; end class UpdateVariable < AutomatedReasoningPolicyAnnotation; end class DeleteVariable < AutomatedReasoningPolicyAnnotation; end class AddRule < AutomatedReasoningPolicyAnnotation; end class UpdateRule < AutomatedReasoningPolicyAnnotation; end class DeleteRule < AutomatedReasoningPolicyAnnotation; end class AddRuleFromNaturalLanguage < AutomatedReasoningPolicyAnnotation; end class UpdateFromRulesFeedback < AutomatedReasoningPolicyAnnotation; end class UpdateFromScenarioFeedback < AutomatedReasoningPolicyAnnotation; end class IngestContent < AutomatedReasoningPolicyAnnotation; end class Unknown < AutomatedReasoningPolicyAnnotation; end end |
#delete_rule ⇒ Types::AutomatedReasoningPolicyDeleteRuleAnnotation
An operation to remove a rule from the policy.
983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-bedrock/types.rb', line 983 class AutomatedReasoningPolicyAnnotation < Struct.new( :add_type, :update_type, :delete_type, :add_variable, :update_variable, :delete_variable, :add_rule, :update_rule, :delete_rule, :add_rule_from_natural_language, :update_from_rules_feedback, :update_from_scenario_feedback, :ingest_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddType < AutomatedReasoningPolicyAnnotation; end class UpdateType < AutomatedReasoningPolicyAnnotation; end class DeleteType < AutomatedReasoningPolicyAnnotation; end class AddVariable < AutomatedReasoningPolicyAnnotation; end class UpdateVariable < AutomatedReasoningPolicyAnnotation; end class DeleteVariable < AutomatedReasoningPolicyAnnotation; end class AddRule < AutomatedReasoningPolicyAnnotation; end class UpdateRule < AutomatedReasoningPolicyAnnotation; end class DeleteRule < AutomatedReasoningPolicyAnnotation; end class AddRuleFromNaturalLanguage < AutomatedReasoningPolicyAnnotation; end class UpdateFromRulesFeedback < AutomatedReasoningPolicyAnnotation; end class UpdateFromScenarioFeedback < AutomatedReasoningPolicyAnnotation; end class IngestContent < AutomatedReasoningPolicyAnnotation; end class Unknown < AutomatedReasoningPolicyAnnotation; end end |
#delete_type ⇒ Types::AutomatedReasoningPolicyDeleteTypeAnnotation
An operation to remove a custom type from the policy. The type must not be referenced by any variables or rules.
983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-bedrock/types.rb', line 983 class AutomatedReasoningPolicyAnnotation < Struct.new( :add_type, :update_type, :delete_type, :add_variable, :update_variable, :delete_variable, :add_rule, :update_rule, :delete_rule, :add_rule_from_natural_language, :update_from_rules_feedback, :update_from_scenario_feedback, :ingest_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddType < AutomatedReasoningPolicyAnnotation; end class UpdateType < AutomatedReasoningPolicyAnnotation; end class DeleteType < AutomatedReasoningPolicyAnnotation; end class AddVariable < AutomatedReasoningPolicyAnnotation; end class UpdateVariable < AutomatedReasoningPolicyAnnotation; end class DeleteVariable < AutomatedReasoningPolicyAnnotation; end class AddRule < AutomatedReasoningPolicyAnnotation; end class UpdateRule < AutomatedReasoningPolicyAnnotation; end class DeleteRule < AutomatedReasoningPolicyAnnotation; end class AddRuleFromNaturalLanguage < AutomatedReasoningPolicyAnnotation; end class UpdateFromRulesFeedback < AutomatedReasoningPolicyAnnotation; end class UpdateFromScenarioFeedback < AutomatedReasoningPolicyAnnotation; end class IngestContent < AutomatedReasoningPolicyAnnotation; end class Unknown < AutomatedReasoningPolicyAnnotation; end end |
#delete_variable ⇒ Types::AutomatedReasoningPolicyDeleteVariableAnnotation
An operation to remove a variable from the policy. The variable must not be referenced by any rules.
983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-bedrock/types.rb', line 983 class AutomatedReasoningPolicyAnnotation < Struct.new( :add_type, :update_type, :delete_type, :add_variable, :update_variable, :delete_variable, :add_rule, :update_rule, :delete_rule, :add_rule_from_natural_language, :update_from_rules_feedback, :update_from_scenario_feedback, :ingest_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddType < AutomatedReasoningPolicyAnnotation; end class UpdateType < AutomatedReasoningPolicyAnnotation; end class DeleteType < AutomatedReasoningPolicyAnnotation; end class AddVariable < AutomatedReasoningPolicyAnnotation; end class UpdateVariable < AutomatedReasoningPolicyAnnotation; end class DeleteVariable < AutomatedReasoningPolicyAnnotation; end class AddRule < AutomatedReasoningPolicyAnnotation; end class UpdateRule < AutomatedReasoningPolicyAnnotation; end class DeleteRule < AutomatedReasoningPolicyAnnotation; end class AddRuleFromNaturalLanguage < AutomatedReasoningPolicyAnnotation; end class UpdateFromRulesFeedback < AutomatedReasoningPolicyAnnotation; end class UpdateFromScenarioFeedback < AutomatedReasoningPolicyAnnotation; end class IngestContent < AutomatedReasoningPolicyAnnotation; end class Unknown < AutomatedReasoningPolicyAnnotation; end end |
#ingest_content ⇒ Types::AutomatedReasoningPolicyIngestContentAnnotation
An operation to process and incorporate new content into the policy, extracting additional rules and concepts.
983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-bedrock/types.rb', line 983 class AutomatedReasoningPolicyAnnotation < Struct.new( :add_type, :update_type, :delete_type, :add_variable, :update_variable, :delete_variable, :add_rule, :update_rule, :delete_rule, :add_rule_from_natural_language, :update_from_rules_feedback, :update_from_scenario_feedback, :ingest_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddType < AutomatedReasoningPolicyAnnotation; end class UpdateType < AutomatedReasoningPolicyAnnotation; end class DeleteType < AutomatedReasoningPolicyAnnotation; end class AddVariable < AutomatedReasoningPolicyAnnotation; end class UpdateVariable < AutomatedReasoningPolicyAnnotation; end class DeleteVariable < AutomatedReasoningPolicyAnnotation; end class AddRule < AutomatedReasoningPolicyAnnotation; end class UpdateRule < AutomatedReasoningPolicyAnnotation; end class DeleteRule < AutomatedReasoningPolicyAnnotation; end class AddRuleFromNaturalLanguage < AutomatedReasoningPolicyAnnotation; end class UpdateFromRulesFeedback < AutomatedReasoningPolicyAnnotation; end class UpdateFromScenarioFeedback < AutomatedReasoningPolicyAnnotation; end class IngestContent < AutomatedReasoningPolicyAnnotation; end class Unknown < AutomatedReasoningPolicyAnnotation; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
983 984 985 |
# File 'lib/aws-sdk-bedrock/types.rb', line 983 def unknown @unknown end |
#update_from_rules_feedback ⇒ Types::AutomatedReasoningPolicyUpdateFromRuleFeedbackAnnotation
An operation to update the policy based on feedback about how specific rules performed during testing or validation.
983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-bedrock/types.rb', line 983 class AutomatedReasoningPolicyAnnotation < Struct.new( :add_type, :update_type, :delete_type, :add_variable, :update_variable, :delete_variable, :add_rule, :update_rule, :delete_rule, :add_rule_from_natural_language, :update_from_rules_feedback, :update_from_scenario_feedback, :ingest_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddType < AutomatedReasoningPolicyAnnotation; end class UpdateType < AutomatedReasoningPolicyAnnotation; end class DeleteType < AutomatedReasoningPolicyAnnotation; end class AddVariable < AutomatedReasoningPolicyAnnotation; end class UpdateVariable < AutomatedReasoningPolicyAnnotation; end class DeleteVariable < AutomatedReasoningPolicyAnnotation; end class AddRule < AutomatedReasoningPolicyAnnotation; end class UpdateRule < AutomatedReasoningPolicyAnnotation; end class DeleteRule < AutomatedReasoningPolicyAnnotation; end class AddRuleFromNaturalLanguage < AutomatedReasoningPolicyAnnotation; end class UpdateFromRulesFeedback < AutomatedReasoningPolicyAnnotation; end class UpdateFromScenarioFeedback < AutomatedReasoningPolicyAnnotation; end class IngestContent < AutomatedReasoningPolicyAnnotation; end class Unknown < AutomatedReasoningPolicyAnnotation; end end |
#update_from_scenario_feedback ⇒ Types::AutomatedReasoningPolicyUpdateFromScenarioFeedbackAnnotation
An operation to update the policy based on feedback about how it performed on specific test scenarios.
983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-bedrock/types.rb', line 983 class AutomatedReasoningPolicyAnnotation < Struct.new( :add_type, :update_type, :delete_type, :add_variable, :update_variable, :delete_variable, :add_rule, :update_rule, :delete_rule, :add_rule_from_natural_language, :update_from_rules_feedback, :update_from_scenario_feedback, :ingest_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddType < AutomatedReasoningPolicyAnnotation; end class UpdateType < AutomatedReasoningPolicyAnnotation; end class DeleteType < AutomatedReasoningPolicyAnnotation; end class AddVariable < AutomatedReasoningPolicyAnnotation; end class UpdateVariable < AutomatedReasoningPolicyAnnotation; end class DeleteVariable < AutomatedReasoningPolicyAnnotation; end class AddRule < AutomatedReasoningPolicyAnnotation; end class UpdateRule < AutomatedReasoningPolicyAnnotation; end class DeleteRule < AutomatedReasoningPolicyAnnotation; end class AddRuleFromNaturalLanguage < AutomatedReasoningPolicyAnnotation; end class UpdateFromRulesFeedback < AutomatedReasoningPolicyAnnotation; end class UpdateFromScenarioFeedback < AutomatedReasoningPolicyAnnotation; end class IngestContent < AutomatedReasoningPolicyAnnotation; end class Unknown < AutomatedReasoningPolicyAnnotation; end end |
#update_rule ⇒ Types::AutomatedReasoningPolicyUpdateRuleAnnotation
An operation to modify an existing rule in the policy, such as changing its logical expression or conditions.
983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-bedrock/types.rb', line 983 class AutomatedReasoningPolicyAnnotation < Struct.new( :add_type, :update_type, :delete_type, :add_variable, :update_variable, :delete_variable, :add_rule, :update_rule, :delete_rule, :add_rule_from_natural_language, :update_from_rules_feedback, :update_from_scenario_feedback, :ingest_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddType < AutomatedReasoningPolicyAnnotation; end class UpdateType < AutomatedReasoningPolicyAnnotation; end class DeleteType < AutomatedReasoningPolicyAnnotation; end class AddVariable < AutomatedReasoningPolicyAnnotation; end class UpdateVariable < AutomatedReasoningPolicyAnnotation; end class DeleteVariable < AutomatedReasoningPolicyAnnotation; end class AddRule < AutomatedReasoningPolicyAnnotation; end class UpdateRule < AutomatedReasoningPolicyAnnotation; end class DeleteRule < AutomatedReasoningPolicyAnnotation; end class AddRuleFromNaturalLanguage < AutomatedReasoningPolicyAnnotation; end class UpdateFromRulesFeedback < AutomatedReasoningPolicyAnnotation; end class UpdateFromScenarioFeedback < AutomatedReasoningPolicyAnnotation; end class IngestContent < AutomatedReasoningPolicyAnnotation; end class Unknown < AutomatedReasoningPolicyAnnotation; end end |
#update_type ⇒ Types::AutomatedReasoningPolicyUpdateTypeAnnotation
An operation to modify an existing custom type in the policy, such as changing its name, description, or allowed values.
983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-bedrock/types.rb', line 983 class AutomatedReasoningPolicyAnnotation < Struct.new( :add_type, :update_type, :delete_type, :add_variable, :update_variable, :delete_variable, :add_rule, :update_rule, :delete_rule, :add_rule_from_natural_language, :update_from_rules_feedback, :update_from_scenario_feedback, :ingest_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddType < AutomatedReasoningPolicyAnnotation; end class UpdateType < AutomatedReasoningPolicyAnnotation; end class DeleteType < AutomatedReasoningPolicyAnnotation; end class AddVariable < AutomatedReasoningPolicyAnnotation; end class UpdateVariable < AutomatedReasoningPolicyAnnotation; end class DeleteVariable < AutomatedReasoningPolicyAnnotation; end class AddRule < AutomatedReasoningPolicyAnnotation; end class UpdateRule < AutomatedReasoningPolicyAnnotation; end class DeleteRule < AutomatedReasoningPolicyAnnotation; end class AddRuleFromNaturalLanguage < AutomatedReasoningPolicyAnnotation; end class UpdateFromRulesFeedback < AutomatedReasoningPolicyAnnotation; end class UpdateFromScenarioFeedback < AutomatedReasoningPolicyAnnotation; end class IngestContent < AutomatedReasoningPolicyAnnotation; end class Unknown < AutomatedReasoningPolicyAnnotation; end end |
#update_variable ⇒ Types::AutomatedReasoningPolicyUpdateVariableAnnotation
An operation to modify an existing variable in the policy, such as changing its name, type, or description.
983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-bedrock/types.rb', line 983 class AutomatedReasoningPolicyAnnotation < Struct.new( :add_type, :update_type, :delete_type, :add_variable, :update_variable, :delete_variable, :add_rule, :update_rule, :delete_rule, :add_rule_from_natural_language, :update_from_rules_feedback, :update_from_scenario_feedback, :ingest_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddType < AutomatedReasoningPolicyAnnotation; end class UpdateType < AutomatedReasoningPolicyAnnotation; end class DeleteType < AutomatedReasoningPolicyAnnotation; end class AddVariable < AutomatedReasoningPolicyAnnotation; end class UpdateVariable < AutomatedReasoningPolicyAnnotation; end class DeleteVariable < AutomatedReasoningPolicyAnnotation; end class AddRule < AutomatedReasoningPolicyAnnotation; end class UpdateRule < AutomatedReasoningPolicyAnnotation; end class DeleteRule < AutomatedReasoningPolicyAnnotation; end class AddRuleFromNaturalLanguage < AutomatedReasoningPolicyAnnotation; end class UpdateFromRulesFeedback < AutomatedReasoningPolicyAnnotation; end class UpdateFromScenarioFeedback < AutomatedReasoningPolicyAnnotation; end class IngestContent < AutomatedReasoningPolicyAnnotation; end class Unknown < AutomatedReasoningPolicyAnnotation; end end |