Class: Aws::Bedrock::Types::AutomatedReasoningPolicyBuildResultAssetManifest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

A catalog of all artifacts produced by a build workflow, providing a comprehensive list of available assets including their types and identifiers.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#entriesArray<Types::AutomatedReasoningPolicyBuildResultAssetManifestEntry>

The list of asset entries in the manifest, each describing an available artifact that can be retrieved.



1101
1102
1103
1104
1105
# File 'lib/aws-sdk-bedrock/types.rb', line 1101

class AutomatedReasoningPolicyBuildResultAssetManifest < Struct.new(
  :entries)
  SENSITIVE = []
  include Aws::Structure
end