Class: Aws::Bedrock::Types::AutomatedReasoningPolicyGeneratedTestCases
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::AutomatedReasoningPolicyGeneratedTestCases
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Contains a comprehensive test suite generated by the build workflow, providing validation capabilities for automated reasoning policies.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#generated_test_cases ⇒ Array<Types::AutomatedReasoningPolicyGeneratedTestCase>
Represents a collection of generated test cases.
Instance Attribute Details
#generated_test_cases ⇒ Array<Types::AutomatedReasoningPolicyGeneratedTestCase>
Represents a collection of generated test cases.
1931 1932 1933 1934 1935 |
# File 'lib/aws-sdk-bedrock/types.rb', line 1931 class AutomatedReasoningPolicyGeneratedTestCases < Struct.new( :generated_test_cases) SENSITIVE = [] include Aws::Structure end |