Class: Aws::Bedrock::Types::AutomatedReasoningPolicyIngestContentAnnotation
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::AutomatedReasoningPolicyIngestContentAnnotation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
An annotation for processing and incorporating new content into an Automated Reasoning policy.
Constant Summary collapse
- SENSITIVE =
[:content]
Instance Attribute Summary collapse
-
#content ⇒ String
The new content to be analyzed and incorporated into the policy, such as additional documents or rule descriptions.
Instance Attribute Details
#content ⇒ String
The new content to be analyzed and incorporated into the policy, such as additional documents or rule descriptions.
1947 1948 1949 1950 1951 |
# File 'lib/aws-sdk-bedrock/types.rb', line 1947 class AutomatedReasoningPolicyIngestContentAnnotation < Struct.new( :content) SENSITIVE = [:content] include Aws::Structure end |