Class: Aws::Bedrock::Types::AutomatedReasoningPolicyIterativeRefinementContent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Configuration for an iterative policy refinement workflow, including source documents to process and optional feedback to guide the refinement.

Constant Summary collapse

SENSITIVE =
[:feedback]

Instance Attribute Summary collapse

Instance Attribute Details

#documentsArray<Types::AutomatedReasoningPolicyBuildWorkflowDocument>

Source documents used for iterative policy refinement. These documents provide context for refining the policy definition.



1972
1973
1974
1975
1976
1977
# File 'lib/aws-sdk-bedrock/types.rb', line 1972

class AutomatedReasoningPolicyIterativeRefinementContent < Struct.new(
  :documents,
  :feedback)
  SENSITIVE = [:feedback]
  include Aws::Structure
end

#feedbackString

Optional feedback to guide the iterative refinement workflow. Provide specific instructions or constraints for policy refinement.

Returns:

  • (String)


1972
1973
1974
1975
1976
1977
# File 'lib/aws-sdk-bedrock/types.rb', line 1972

class AutomatedReasoningPolicyIterativeRefinementContent < Struct.new(
  :documents,
  :feedback)
  SENSITIVE = [:feedback]
  include Aws::Structure
end