Class: Aws::Bedrock::Types::AutomatedReasoningPolicyStatementLocation
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::AutomatedReasoningPolicyStatementLocation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Describes the location of a statement within a source document using line numbers.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lines ⇒ Array<Integer>
The line numbers in the source document where this statement appears.
Instance Attribute Details
#lines ⇒ Array<Integer>
The line numbers in the source document where this statement appears.
2208 2209 2210 2211 2212 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2208 class AutomatedReasoningPolicyStatementLocation < Struct.new( :lines) SENSITIVE = [] include Aws::Structure end |