Class: Aws::Bedrock::Types::AutomatedReasoningPolicyStatementReference

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

References a specific atomic statement within a source document, used to link policy elements back to their source material.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#document_idString

The unique identifier of the document containing the referenced statement.

Returns:

  • (String)


2229
2230
2231
2232
2233
2234
# File 'lib/aws-sdk-bedrock/types.rb', line 2229

class AutomatedReasoningPolicyStatementReference < Struct.new(
  :document_id,
  :statement_id)
  SENSITIVE = []
  include Aws::Structure
end

#statement_idString

The unique identifier of the specific atomic statement being referenced.

Returns:

  • (String)


2229
2230
2231
2232
2233
2234
# File 'lib/aws-sdk-bedrock/types.rb', line 2229

class AutomatedReasoningPolicyStatementReference < Struct.new(
  :document_id,
  :statement_id)
  SENSITIVE = []
  include Aws::Structure
end