Class: Aws::Bedrock::Types::AutomatedReasoningPolicyTypeValueAnnotation
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::AutomatedReasoningPolicyTypeValueAnnotation
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
AutomatedReasoningPolicyTypeValueAnnotation is a union - when making an API calls you must set exactly one of the members.
AutomatedReasoningPolicyTypeValueAnnotation is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AutomatedReasoningPolicyTypeValueAnnotation corresponding to the set member.
An annotation for managing values within custom types, including adding, updating, or removing specific type values.
Direct Known Subclasses
Defined Under Namespace
Classes: AddTypeValue, DeleteTypeValue, Unknown, UpdateTypeValue
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#add_type_value ⇒ Types::AutomatedReasoningPolicyAddTypeValue
An operation to add a new value to an existing custom type.
-
#delete_type_value ⇒ Types::AutomatedReasoningPolicyDeleteTypeValue
An operation to remove a value from an existing custom type.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#update_type_value ⇒ Types::AutomatedReasoningPolicyUpdateTypeValue
An operation to modify an existing value within a custom type.
Instance Attribute Details
#add_type_value ⇒ Types::AutomatedReasoningPolicyAddTypeValue
An operation to add a new value to an existing custom type.
2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2402 class AutomatedReasoningPolicyTypeValueAnnotation < Struct.new( :add_type_value, :update_type_value, :delete_type_value, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddTypeValue < AutomatedReasoningPolicyTypeValueAnnotation; end class UpdateTypeValue < AutomatedReasoningPolicyTypeValueAnnotation; end class DeleteTypeValue < AutomatedReasoningPolicyTypeValueAnnotation; end class Unknown < AutomatedReasoningPolicyTypeValueAnnotation; end end |
#delete_type_value ⇒ Types::AutomatedReasoningPolicyDeleteTypeValue
An operation to remove a value from an existing custom type.
2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2402 class AutomatedReasoningPolicyTypeValueAnnotation < Struct.new( :add_type_value, :update_type_value, :delete_type_value, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddTypeValue < AutomatedReasoningPolicyTypeValueAnnotation; end class UpdateTypeValue < AutomatedReasoningPolicyTypeValueAnnotation; end class DeleteTypeValue < AutomatedReasoningPolicyTypeValueAnnotation; end class Unknown < AutomatedReasoningPolicyTypeValueAnnotation; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2402 2403 2404 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2402 def unknown @unknown end |
#update_type_value ⇒ Types::AutomatedReasoningPolicyUpdateTypeValue
An operation to modify an existing value within a custom type.
2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2402 class AutomatedReasoningPolicyTypeValueAnnotation < Struct.new( :add_type_value, :update_type_value, :delete_type_value, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddTypeValue < AutomatedReasoningPolicyTypeValueAnnotation; end class UpdateTypeValue < AutomatedReasoningPolicyTypeValueAnnotation; end class DeleteTypeValue < AutomatedReasoningPolicyTypeValueAnnotation; end class Unknown < AutomatedReasoningPolicyTypeValueAnnotation; end end |