Class: Aws::Bedrock::Types::AutomatedReasoningPolicyUpdateRuleMutation
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::AutomatedReasoningPolicyUpdateRuleMutation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
A mutation operation that modifies an existing rule in the policy definition during the build process.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#rule ⇒ Types::AutomatedReasoningPolicyDefinitionRule
The updated rule definition containing the modified formal logical expression and any changed metadata for the existing rule.
Instance Attribute Details
#rule ⇒ Types::AutomatedReasoningPolicyDefinitionRule
The updated rule definition containing the modified formal logical expression and any changed metadata for the existing rule.
2500 2501 2502 2503 2504 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2500 class AutomatedReasoningPolicyUpdateRuleMutation < Struct.new( :rule) SENSITIVE = [] include Aws::Structure end |