Class: Aws::Bedrock::Types::AutomatedReasoningPolicyUpdateTypeMutation
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::AutomatedReasoningPolicyUpdateTypeMutation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
A mutation operation that modifies an existing custom type in the policy definition during the build process.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#type ⇒ Types::AutomatedReasoningPolicyDefinitionType
The updated type definition containing the modified name, description, or values for the existing custom type.
Instance Attribute Details
#type ⇒ Types::AutomatedReasoningPolicyDefinitionType
The updated type definition containing the modified name, description, or values for the existing custom type.
2546 2547 2548 2549 2550 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2546 class AutomatedReasoningPolicyUpdateTypeMutation < Struct.new( :type) SENSITIVE = [] include Aws::Structure end |