Class: Aws::Bedrock::Types::AutomatedReasoningPolicyUpdateVariableMutation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

A mutation operation that modifies an existing variable in the policy definition during the build process.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#variableTypes::AutomatedReasoningPolicyDefinitionVariable

The updated variable definition containing the modified name, type, or description for the existing variable.



2615
2616
2617
2618
2619
# File 'lib/aws-sdk-bedrock/types.rb', line 2615

class AutomatedReasoningPolicyUpdateVariableMutation < Struct.new(
  :variable)
  SENSITIVE = []
  include Aws::Structure
end