Class: Aws::Bedrock::Types::AutomatedReasoningPolicyVariableReport

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Provides detailed fidelity analysis for a specific policy variable, including which source document statements support it and how accurate the variable definition is.

Constant Summary collapse

SENSITIVE =
[:policy_variable, :grounding_justifications, :accuracy_justification]

Instance Attribute Summary collapse

Instance Attribute Details

#accuracy_justificationString

A textual explanation of the accuracy score, describing why the variable received this particular accuracy rating.

Returns:

  • (String)


2651
2652
2653
2654
2655
2656
2657
2658
2659
# File 'lib/aws-sdk-bedrock/types.rb', line 2651

class AutomatedReasoningPolicyVariableReport < Struct.new(
  :policy_variable,
  :grounding_statements,
  :grounding_justifications,
  :accuracy_score,
  :accuracy_justification)
  SENSITIVE = [:policy_variable, :grounding_justifications, :accuracy_justification]
  include Aws::Structure
end

#accuracy_scoreFloat

A score from 0.0 to 1.0 indicating how accurately this variable represents concepts from the source material.

Returns:

  • (Float)


2651
2652
2653
2654
2655
2656
2657
2658
2659
# File 'lib/aws-sdk-bedrock/types.rb', line 2651

class AutomatedReasoningPolicyVariableReport < Struct.new(
  :policy_variable,
  :grounding_statements,
  :grounding_justifications,
  :accuracy_score,
  :accuracy_justification)
  SENSITIVE = [:policy_variable, :grounding_justifications, :accuracy_justification]
  include Aws::Structure
end

#grounding_justificationsArray<String>

Explanations describing how the source statements support and justify this specific variable definition.

Returns:

  • (Array<String>)


2651
2652
2653
2654
2655
2656
2657
2658
2659
# File 'lib/aws-sdk-bedrock/types.rb', line 2651

class AutomatedReasoningPolicyVariableReport < Struct.new(
  :policy_variable,
  :grounding_statements,
  :grounding_justifications,
  :accuracy_score,
  :accuracy_justification)
  SENSITIVE = [:policy_variable, :grounding_justifications, :accuracy_justification]
  include Aws::Structure
end

#grounding_statementsArray<Types::AutomatedReasoningPolicyStatementReference>

References to statements from the source documents that provide the basis or justification for this variable.



2651
2652
2653
2654
2655
2656
2657
2658
2659
# File 'lib/aws-sdk-bedrock/types.rb', line 2651

class AutomatedReasoningPolicyVariableReport < Struct.new(
  :policy_variable,
  :grounding_statements,
  :grounding_justifications,
  :accuracy_score,
  :accuracy_justification)
  SENSITIVE = [:policy_variable, :grounding_justifications, :accuracy_justification]
  include Aws::Structure
end

#policy_variableString

The name of the policy variable being analyzed in this report.

Returns:

  • (String)


2651
2652
2653
2654
2655
2656
2657
2658
2659
# File 'lib/aws-sdk-bedrock/types.rb', line 2651

class AutomatedReasoningPolicyVariableReport < Struct.new(
  :policy_variable,
  :grounding_statements,
  :grounding_justifications,
  :accuracy_score,
  :accuracy_justification)
  SENSITIVE = [:policy_variable, :grounding_justifications, :accuracy_justification]
  include Aws::Structure
end