Class: Aws::Bedrock::Types::BatchDeleteAdvancedPromptOptimizationJobError

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Contains information about an error that occurred when deleting an advanced prompt optimization job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

The error code for the deletion failure.

Returns:

  • (String)


2750
2751
2752
2753
2754
2755
2756
# File 'lib/aws-sdk-bedrock/types.rb', line 2750

class BatchDeleteAdvancedPromptOptimizationJobError < Struct.new(
  :job_identifier,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#job_identifierString

The identifier of the job that could not be deleted.

Returns:

  • (String)


2750
2751
2752
2753
2754
2755
2756
# File 'lib/aws-sdk-bedrock/types.rb', line 2750

class BatchDeleteAdvancedPromptOptimizationJobError < Struct.new(
  :job_identifier,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

A message describing the error.

Returns:

  • (String)


2750
2751
2752
2753
2754
2755
2756
# File 'lib/aws-sdk-bedrock/types.rb', line 2750

class BatchDeleteAdvancedPromptOptimizationJobError < Struct.new(
  :job_identifier,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end