Class: Aws::Bedrock::Types::CreateAdvancedPromptOptimizationJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::CreateAdvancedPromptOptimizationJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Create Advanced Prompt Optimization Job Request
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the API request completes no more than one time.
-
#encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key used for encrypting the output data.
-
#input_config ⇒ Types::AdvancedPromptOptimizationInputConfig
Specifies the S3 location of your JSONL input file containing prompt templates and evaluation samples.
-
#job_description ⇒ String
A description of the advanced prompt optimization job.
-
#job_name ⇒ String
A name for the advanced prompt optimization job.
-
#model_configurations ⇒ Array<Types::ModelConfiguration>
A list of model configurations specifying the target models for prompt optimization.
-
#output_config ⇒ Types::AdvancedPromptOptimizationOutputConfig
Specifies the S3 location where optimization results will be stored.
-
#tags ⇒ Array<Types::Tag>
Tags to associate with the advanced prompt optimization job.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request but does not return an error.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3006 class CreateAdvancedPromptOptimizationJobRequest < Struct.new( :job_name, :job_description, :client_token, :input_config, :output_config, :encryption_key_arn, :tags, :model_configurations) SENSITIVE = [] include Aws::Structure end |
#encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key used for encrypting the output data. If not specified, the output is encrypted with an Amazon-owned KMS key.
3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3006 class CreateAdvancedPromptOptimizationJobRequest < Struct.new( :job_name, :job_description, :client_token, :input_config, :output_config, :encryption_key_arn, :tags, :model_configurations) SENSITIVE = [] include Aws::Structure end |
#input_config ⇒ Types::AdvancedPromptOptimizationInputConfig
Specifies the S3 location of your JSONL input file containing prompt templates and evaluation samples.
3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3006 class CreateAdvancedPromptOptimizationJobRequest < Struct.new( :job_name, :job_description, :client_token, :input_config, :output_config, :encryption_key_arn, :tags, :model_configurations) SENSITIVE = [] include Aws::Structure end |
#job_description ⇒ String
A description of the advanced prompt optimization job.
3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3006 class CreateAdvancedPromptOptimizationJobRequest < Struct.new( :job_name, :job_description, :client_token, :input_config, :output_config, :encryption_key_arn, :tags, :model_configurations) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
A name for the advanced prompt optimization job.
3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3006 class CreateAdvancedPromptOptimizationJobRequest < Struct.new( :job_name, :job_description, :client_token, :input_config, :output_config, :encryption_key_arn, :tags, :model_configurations) SENSITIVE = [] include Aws::Structure end |
#model_configurations ⇒ Array<Types::ModelConfiguration>
A list of model configurations specifying the target models for prompt optimization. You can specify up to 5 models.
3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3006 class CreateAdvancedPromptOptimizationJobRequest < Struct.new( :job_name, :job_description, :client_token, :input_config, :output_config, :encryption_key_arn, :tags, :model_configurations) SENSITIVE = [] include Aws::Structure end |
#output_config ⇒ Types::AdvancedPromptOptimizationOutputConfig
Specifies the S3 location where optimization results will be stored.
3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3006 class CreateAdvancedPromptOptimizationJobRequest < Struct.new( :job_name, :job_description, :client_token, :input_config, :output_config, :encryption_key_arn, :tags, :model_configurations) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Tags to associate with the advanced prompt optimization job.
3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3006 class CreateAdvancedPromptOptimizationJobRequest < Struct.new( :job_name, :job_description, :client_token, :input_config, :output_config, :encryption_key_arn, :tags, :model_configurations) SENSITIVE = [] include Aws::Structure end |