Class: Aws::Bedrock::Types::CreateAutomatedReasoningPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#client_request_tokenString

A unique, case-sensitive identifier to ensure that the operation completes no more than once. If this token matches a previous request, Amazon Bedrock ignores the request but doesn’t return an error.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


3108
3109
3110
3111
3112
3113
3114
3115
3116
3117
# File 'lib/aws-sdk-bedrock/types.rb', line 3108

class CreateAutomatedReasoningPolicyRequest < Struct.new(
  :name,
  :description,
  :client_request_token,
  :policy_definition,
  :kms_key_id,
  :tags)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#descriptionString

A description of the Automated Reasoning policy. Use this to provide context about the policy’s purpose and the types of validations it performs.

Returns:

  • (String)


3108
3109
3110
3111
3112
3113
3114
3115
3116
3117
# File 'lib/aws-sdk-bedrock/types.rb', line 3108

class CreateAutomatedReasoningPolicyRequest < Struct.new(
  :name,
  :description,
  :client_request_token,
  :policy_definition,
  :kms_key_id,
  :tags)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#kms_key_idString

The identifier of the KMS key to use for encrypting the automated reasoning policy and its associated artifacts. If you don’t specify a KMS key, Amazon Bedrock uses an KMS managed key for encryption. For enhanced security and control, you can specify a customer managed KMS key.

Returns:

  • (String)


3108
3109
3110
3111
3112
3113
3114
3115
3116
3117
# File 'lib/aws-sdk-bedrock/types.rb', line 3108

class CreateAutomatedReasoningPolicyRequest < Struct.new(
  :name,
  :description,
  :client_request_token,
  :policy_definition,
  :kms_key_id,
  :tags)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#nameString

A unique name for the Automated Reasoning policy. The name must be between 1 and 63 characters and can contain letters, numbers, hyphens, and underscores.

Returns:

  • (String)


3108
3109
3110
3111
3112
3113
3114
3115
3116
3117
# File 'lib/aws-sdk-bedrock/types.rb', line 3108

class CreateAutomatedReasoningPolicyRequest < Struct.new(
  :name,
  :description,
  :client_request_token,
  :policy_definition,
  :kms_key_id,
  :tags)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#policy_definitionTypes::AutomatedReasoningPolicyDefinition

The policy definition that contains the formal logic rules, variables, and custom variable types used to validate foundation model responses in your application.



3108
3109
3110
3111
3112
3113
3114
3115
3116
3117
# File 'lib/aws-sdk-bedrock/types.rb', line 3108

class CreateAutomatedReasoningPolicyRequest < Struct.new(
  :name,
  :description,
  :client_request_token,
  :policy_definition,
  :kms_key_id,
  :tags)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of tags to associate with the Automated Reasoning policy. Tags help you organize and manage your policies.

Returns:



3108
3109
3110
3111
3112
3113
3114
3115
3116
3117
# File 'lib/aws-sdk-bedrock/types.rb', line 3108

class CreateAutomatedReasoningPolicyRequest < Struct.new(
  :name,
  :description,
  :client_request_token,
  :policy_definition,
  :kms_key_id,
  :tags)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end