Class: Aws::Bedrock::Types::CreateCustomModelDeploymentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::CreateCustomModelDeploymentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_request_token ⇒ String
A unique, case-sensitive identifier to ensure that the operation completes no more than one time.
-
#description ⇒ String
A description for the custom model deployment to help you identify its purpose.
-
#model_arn ⇒ String
The Amazon Resource Name (ARN) of the custom model to deploy for on-demand inference.
-
#model_deployment_name ⇒ String
The name for the custom model deployment.
-
#tags ⇒ Array<Types::Tag>
Tags to assign to the custom model deployment.
Instance Attribute Details
#client_request_token ⇒ String
A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request, but does not return an error. For more information, see [Ensuring idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/bedrock/latest/userguide/model-customization-idempotency.html
3382 3383 3384 3385 3386 3387 3388 3389 3390 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3382 class CreateCustomModelDeploymentRequest < Struct.new( :model_deployment_name, :model_arn, :description, :tags, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the custom model deployment to help you identify its purpose.
3382 3383 3384 3385 3386 3387 3388 3389 3390 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3382 class CreateCustomModelDeploymentRequest < Struct.new( :model_deployment_name, :model_arn, :description, :tags, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#model_arn ⇒ String
The Amazon Resource Name (ARN) of the custom model to deploy for on-demand inference. The custom model must be in the ‘Active` state.
3382 3383 3384 3385 3386 3387 3388 3389 3390 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3382 class CreateCustomModelDeploymentRequest < Struct.new( :model_deployment_name, :model_arn, :description, :tags, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#model_deployment_name ⇒ String
The name for the custom model deployment. The name must be unique within your Amazon Web Services account and Region.
3382 3383 3384 3385 3386 3387 3388 3389 3390 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3382 class CreateCustomModelDeploymentRequest < Struct.new( :model_deployment_name, :model_arn, :description, :tags, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Tags to assign to the custom model deployment. You can use tags to organize and track your Amazon Web Services resources for cost allocation and management purposes.
3382 3383 3384 3385 3386 3387 3388 3389 3390 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3382 class CreateCustomModelDeploymentRequest < Struct.new( :model_deployment_name, :model_arn, :description, :tags, :client_request_token) SENSITIVE = [] include Aws::Structure end |