Class: Aws::Bedrock::Types::CreateCustomModelRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_request_tokenString

A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request, but does not return an error. For more information, see [Ensuring idempotency].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html

Returns:

  • (String)


3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
# File 'lib/aws-sdk-bedrock/types.rb', line 3458

class CreateCustomModelRequest < Struct.new(
  :model_name,
  :model_source_config,
  :custom_model_data_source,
  :model_kms_key_arn,
  :role_arn,
  :model_tags,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#custom_model_data_sourceTypes::CustomModelDataSource

The data source for the custom model. Use this field to specify a SageMaker AI model package ARN as the source for your custom model. Amazon Bedrock resolves the model package to retrieve the model artifacts.

You can specify either ‘customModelDataSource` or `modelSourceConfig`, but not both.



3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
# File 'lib/aws-sdk-bedrock/types.rb', line 3458

class CreateCustomModelRequest < Struct.new(
  :model_name,
  :model_source_config,
  :custom_model_data_source,
  :model_kms_key_arn,
  :role_arn,
  :model_tags,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#model_kms_key_arnString

The Amazon Resource Name (ARN) of the customer managed KMS key to encrypt the custom model. If you don’t provide a KMS key, Amazon Bedrock uses an Amazon Web Services-managed KMS key to encrypt the model.

If you provide a customer managed KMS key, your Amazon Bedrock service role must have permissions to use it. For more information see [Encryption of imported models].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/encryption-import-model.html

Returns:

  • (String)


3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
# File 'lib/aws-sdk-bedrock/types.rb', line 3458

class CreateCustomModelRequest < Struct.new(
  :model_name,
  :model_source_config,
  :custom_model_data_source,
  :model_kms_key_arn,
  :role_arn,
  :model_tags,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#model_nameString

A unique name for the custom model.

Returns:

  • (String)


3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
# File 'lib/aws-sdk-bedrock/types.rb', line 3458

class CreateCustomModelRequest < Struct.new(
  :model_name,
  :model_source_config,
  :custom_model_data_source,
  :model_kms_key_arn,
  :role_arn,
  :model_tags,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#model_source_configTypes::ModelDataSource

The data source for the model. The Amazon S3 URI in the model source must be for the Amazon-managed Amazon S3 bucket containing your model artifacts.



3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
# File 'lib/aws-sdk-bedrock/types.rb', line 3458

class CreateCustomModelRequest < Struct.new(
  :model_name,
  :model_source_config,
  :custom_model_data_source,
  :model_kms_key_arn,
  :role_arn,
  :model_tags,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#model_tagsArray<Types::Tag>

A list of key-value pairs to associate with the custom model resource. You can use these tags to organize and identify your resources.

For more information, see [Tagging resources] in the [Amazon Bedrock User Guide].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/tagging.html [2]: docs.aws.amazon.com/bedrock/latest/userguide/what-is-service.html

Returns:



3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
# File 'lib/aws-sdk-bedrock/types.rb', line 3458

class CreateCustomModelRequest < Struct.new(
  :model_name,
  :model_source_config,
  :custom_model_data_source,
  :model_kms_key_arn,
  :role_arn,
  :model_tags,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of an IAM service role that Amazon Bedrock assumes to perform tasks on your behalf. This role must have permissions to access the Amazon S3 bucket containing your model artifacts and the KMS key (if specified). For more information, see

Setting up an IAM service role for importing models][1

in the

Amazon Bedrock User Guide.

This field is required when you use ‘modelSourceConfig` with an Amazon S3 data source. It is not required when you use `customModelDataSource` with a model package ARN, because Amazon Bedrock uses its own credentials to access the model artifacts.

[1]: docs.aws.amazon.com/bedrock/latest/userguide/model-import-iam-role.html

Returns:

  • (String)


3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
# File 'lib/aws-sdk-bedrock/types.rb', line 3458

class CreateCustomModelRequest < Struct.new(
  :model_name,
  :model_source_config,
  :custom_model_data_source,
  :model_kms_key_arn,
  :role_arn,
  :model_tags,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end