Class: Aws::Bedrock::Types::CreateGuardrailResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::CreateGuardrailResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The time at which the guardrail was created.
-
#guardrail_arn ⇒ String
The ARN of the guardrail.
-
#guardrail_id ⇒ String
The unique identifier of the guardrail that was created.
-
#version ⇒ String
The version of the guardrail that was created.
Instance Attribute Details
#created_at ⇒ Time
The time at which the guardrail was created.
3730 3731 3732 3733 3734 3735 3736 3737 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3730 class CreateGuardrailResponse < Struct.new( :guardrail_id, :guardrail_arn, :version, :created_at) SENSITIVE = [] include Aws::Structure end |
#guardrail_arn ⇒ String
The ARN of the guardrail.
3730 3731 3732 3733 3734 3735 3736 3737 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3730 class CreateGuardrailResponse < Struct.new( :guardrail_id, :guardrail_arn, :version, :created_at) SENSITIVE = [] include Aws::Structure end |
#guardrail_id ⇒ String
The unique identifier of the guardrail that was created.
3730 3731 3732 3733 3734 3735 3736 3737 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3730 class CreateGuardrailResponse < Struct.new( :guardrail_id, :guardrail_arn, :version, :created_at) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The version of the guardrail that was created. This value will always be ‘DRAFT`.
3730 3731 3732 3733 3734 3735 3736 3737 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3730 class CreateGuardrailResponse < Struct.new( :guardrail_id, :guardrail_arn, :version, :created_at) SENSITIVE = [] include Aws::Structure end |