Class: Aws::Bedrock::Types::CreateInferenceProfileRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#client_request_tokenString

A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request, but does not return an error. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


3860
3861
3862
3863
3864
3865
3866
3867
3868
# File 'lib/aws-sdk-bedrock/types.rb', line 3860

class CreateInferenceProfileRequest < Struct.new(
  :inference_profile_name,
  :description,
  :client_request_token,
  :model_source,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

A description for the inference profile.

Returns:

  • (String)


3860
3861
3862
3863
3864
3865
3866
3867
3868
# File 'lib/aws-sdk-bedrock/types.rb', line 3860

class CreateInferenceProfileRequest < Struct.new(
  :inference_profile_name,
  :description,
  :client_request_token,
  :model_source,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#inference_profile_nameString

A name for the inference profile.

Returns:

  • (String)


3860
3861
3862
3863
3864
3865
3866
3867
3868
# File 'lib/aws-sdk-bedrock/types.rb', line 3860

class CreateInferenceProfileRequest < Struct.new(
  :inference_profile_name,
  :description,
  :client_request_token,
  :model_source,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#model_sourceTypes::InferenceProfileModelSource

The foundation model or system-defined inference profile that the inference profile will track metrics and costs for.



3860
3861
3862
3863
3864
3865
3866
3867
3868
# File 'lib/aws-sdk-bedrock/types.rb', line 3860

class CreateInferenceProfileRequest < Struct.new(
  :inference_profile_name,
  :description,
  :client_request_token,
  :model_source,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#tagsArray<Types::Tag>

An array of objects, each of which contains a tag and its value. For more information, see Tagging resources in the Amazon Bedrock User Guide.

Returns:



3860
3861
3862
3863
3864
3865
3866
3867
3868
# File 'lib/aws-sdk-bedrock/types.rb', line 3860

class CreateInferenceProfileRequest < Struct.new(
  :inference_profile_name,
  :description,
  :client_request_token,
  :model_source,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end