Class: Aws::Bedrock::Types::CustomMetricBedrockEvaluatorModel

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Defines the model you want to evaluate custom metrics in an Amazon Bedrock evaluation job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#model_identifierString

The Amazon Resource Name (ARN) of the evaluator model for custom metrics. For a list of supported evaluator models, see Evaluate model performance using another LLM as a judge and Evaluate the performance of RAG sources using Amazon Bedrock evaluations.

Returns:

  • (String)


4482
4483
4484
4485
4486
# File 'lib/aws-sdk-bedrock/types.rb', line 4482

class CustomMetricBedrockEvaluatorModel < Struct.new(
  :model_identifier)
  SENSITIVE = []
  include Aws::Structure
end