Class: Aws::Bedrock::Types::CustomModelDeploymentUpdateDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::CustomModelDeploymentUpdateDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Details about an update to a custom model deployment, including the new custom model resource ARN and current update status.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#model_arn ⇒ String
ARN of the new custom model being deployed as part of the update.
-
#update_status ⇒ String
Current status of the deployment update.
Instance Attribute Details
#model_arn ⇒ String
ARN of the new custom model being deployed as part of the update.
4614 4615 4616 4617 4618 4619 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4614 class CustomModelDeploymentUpdateDetails < Struct.new( :model_arn, :update_status) SENSITIVE = [] include Aws::Structure end |
#update_status ⇒ String
Current status of the deployment update.
4614 4615 4616 4617 4618 4619 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4614 class CustomModelDeploymentUpdateDetails < Struct.new( :model_arn, :update_status) SENSITIVE = [] include Aws::Structure end |