Class: Aws::Bedrock::Types::CustomizationConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::CustomizationConfig
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
CustomizationConfig is a union - when making an API calls you must set exactly one of the members.
CustomizationConfig is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of CustomizationConfig corresponding to the set member.
A model customization configuration
Direct Known Subclasses
Defined Under Namespace
Classes: DistillationConfig, RftConfig, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#distillation_config ⇒ Types::DistillationConfig
The Distillation configuration for the custom model.
-
#rft_config ⇒ Types::RFTConfig
Configuration settings for reinforcement fine-tuning (RFT) model customization, including grader configuration and hyperparameters.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#distillation_config ⇒ Types::DistillationConfig
The Distillation configuration for the custom model.
4670 4671 4672 4673 4674 4675 4676 4677 4678 4679 4680 4681 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4670 class CustomizationConfig < Struct.new( :distillation_config, :rft_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DistillationConfig < CustomizationConfig; end class RftConfig < CustomizationConfig; end class Unknown < CustomizationConfig; end end |
#rft_config ⇒ Types::RFTConfig
Configuration settings for reinforcement fine-tuning (RFT) model customization, including grader configuration and hyperparameters.
4670 4671 4672 4673 4674 4675 4676 4677 4678 4679 4680 4681 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4670 class CustomizationConfig < Struct.new( :distillation_config, :rft_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DistillationConfig < CustomizationConfig; end class RftConfig < CustomizationConfig; end class Unknown < CustomizationConfig; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
4670 4671 4672 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4670 def unknown @unknown end |