Class: Aws::Bedrock::Types::DeleteAutomatedReasoningPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#forceBoolean

Specifies whether to force delete the automated reasoning policy even if it has active resources. When false, Amazon Bedrock validates if all artifacts have been deleted (e.g. policy version, test case, test result) for a policy before deletion. When true, Amazon Bedrock will delete the policy and all its artifacts without validation. Default is false.

Returns:

  • (Boolean)


4843
4844
4845
4846
4847
4848
# File 'lib/aws-sdk-bedrock/types.rb', line 4843

class DeleteAutomatedReasoningPolicyRequest < Struct.new(
  :policy_arn,
  :force)
  SENSITIVE = []
  include Aws::Structure
end

#policy_arnString

The Amazon Resource Name (ARN) of the Automated Reasoning policy to delete.

Returns:

  • (String)


4843
4844
4845
4846
4847
4848
# File 'lib/aws-sdk-bedrock/types.rb', line 4843

class DeleteAutomatedReasoningPolicyRequest < Struct.new(
  :policy_arn,
  :force)
  SENSITIVE = []
  include Aws::Structure
end