Class: Aws::Bedrock::Types::DeleteResourcePolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::DeleteResourcePolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
The ARN of the Bedrock resource to which this resource policy applies.
Instance Attribute Details
#resource_arn ⇒ String
The ARN of the Bedrock resource to which this resource policy applies.
4978 4979 4980 4981 4982 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4978 class DeleteResourcePolicyRequest < Struct.new( :resource_arn) SENSITIVE = [] include Aws::Structure end |