Class: Aws::Bedrock::Types::EndpointConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::EndpointConfig
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Note:
EndpointConfig is a union - when making an API calls you must set exactly one of the members.
Note:
EndpointConfig is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of EndpointConfig corresponding to the set member.
Specifies the configuration for the endpoint.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#sage_maker ⇒ Types::SageMakerEndpoint
The configuration specific to Amazon SageMaker for the endpoint.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#sage_maker ⇒ Types::SageMakerEndpoint
The configuration specific to Amazon SageMaker for the endpoint.
5061 5062 5063 5064 5065 5066 5067 5068 5069 5070 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5061 class EndpointConfig < Struct.new( :sage_maker, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class SageMaker < EndpointConfig; end class Unknown < EndpointConfig; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
5061 5062 5063 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5061 def unknown @unknown end |