Class: Aws::Bedrock::Types::EvaluationModelConfigSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::EvaluationModelConfigSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
A summary of the models used in an Amazon Bedrock model evaluation job. These resources can be models in Amazon Bedrock or models outside of Amazon Bedrock that you use to generate your own inference response data.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bedrock_model_identifiers ⇒ Array<String>
The Amazon Resource Names (ARNs) of the models used for the evaluation job.
-
#precomputed_inference_source_identifiers ⇒ Array<String>
A label that identifies the models used for a model evaluation job where you provide your own inference response data.
Instance Attribute Details
#bedrock_model_identifiers ⇒ Array<String>
The Amazon Resource Names (ARNs) of the models used for the evaluation job.
5418 5419 5420 5421 5422 5423 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5418 class EvaluationModelConfigSummary < Struct.new( :bedrock_model_identifiers, :precomputed_inference_source_identifiers) SENSITIVE = [] include Aws::Structure end |
#precomputed_inference_source_identifiers ⇒ Array<String>
A label that identifies the models used for a model evaluation job where you provide your own inference response data.
5418 5419 5420 5421 5422 5423 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5418 class EvaluationModelConfigSummary < Struct.new( :bedrock_model_identifiers, :precomputed_inference_source_identifiers) SENSITIVE = [] include Aws::Structure end |