Class: Aws::Bedrock::Types::EvaluationOutputDataConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::EvaluationOutputDataConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
The Amazon S3 location where the results of your evaluation job are saved.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#s3_uri ⇒ String
The Amazon S3 URI where the results of the evaluation job are saved.
Instance Attribute Details
#s3_uri ⇒ String
The Amazon S3 URI where the results of the evaluation job are saved.
5375 5376 5377 5378 5379 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5375 class EvaluationOutputDataConfig < Struct.new( :s3_uri) SENSITIVE = [] include Aws::Structure end |