Class: Aws::Bedrock::Types::EvaluationPrecomputedInferenceSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::EvaluationPrecomputedInferenceSource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
A summary of a model used for a model evaluation job where you provide your own inference response data.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#inference_source_identifier ⇒ String
A label that identifies a model used in a model evaluation job where you provide your own inference response data.
Instance Attribute Details
#inference_source_identifier ⇒ String
A label that identifies a model used in a model evaluation job where you provide your own inference response data.
5391 5392 5393 5394 5395 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5391 class EvaluationPrecomputedInferenceSource < Struct.new( :inference_source_identifier) SENSITIVE = [] include Aws::Structure end |