Class: Aws::Bedrock::Types::EvaluationRagConfigSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::EvaluationRagConfigSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
A summary of the RAG resources used in an Amazon Bedrock Knowledge Base evaluation job. These resources can be Knowledge Bases in Amazon Bedrock or RAG sources outside of Amazon Bedrock that you use to generate your own inference response data.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bedrock_knowledge_base_identifiers ⇒ Array<String>
The Amazon Resource Names (ARNs) of the Knowledge Base resources used for a Knowledge Base evaluation job where Amazon Bedrock invokes the Knowledge Base for you.
-
#precomputed_rag_source_identifiers ⇒ Array<String>
A label that identifies the RAG sources used for a Knowledge Base evaluation job where you provide your own inference response data.
Instance Attribute Details
#bedrock_knowledge_base_identifiers ⇒ Array<String>
The Amazon Resource Names (ARNs) of the Knowledge Base resources used for a Knowledge Base evaluation job where Amazon Bedrock invokes the Knowledge Base for you.
5573 5574 5575 5576 5577 5578 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5573 class EvaluationRagConfigSummary < Struct.new( :bedrock_knowledge_base_identifiers, :precomputed_rag_source_identifiers) SENSITIVE = [] include Aws::Structure end |
#precomputed_rag_source_identifiers ⇒ Array<String>
A label that identifies the RAG sources used for a Knowledge Base evaluation job where you provide your own inference response data.
5573 5574 5575 5576 5577 5578 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5573 class EvaluationRagConfigSummary < Struct.new( :bedrock_knowledge_base_identifiers, :precomputed_rag_source_identifiers) SENSITIVE = [] include Aws::Structure end |