Class: Aws::Bedrock::Types::EvaluationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::EvaluationSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Summary information of an evaluation job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_type ⇒ String
Specifies whether the evaluation job is for evaluating a model or evaluating a knowledge base (retrieval and response generation).
-
#creation_time ⇒ Time
The time the evaluation job was created.
-
#custom_metrics_evaluator_model_identifiers ⇒ Array<String>
The Amazon Resource Names (ARNs) of the models used to compute custom metrics in an Amazon Bedrock evaluation job.
-
#evaluation_task_types ⇒ Array<String>
The type of task for model evaluation.
-
#evaluator_model_identifiers ⇒ Array<String>
The Amazon Resource Names (ARNs) of the models used to compute the metrics for a knowledge base evaluation job.
-
#inference_config_summary ⇒ Types::EvaluationInferenceConfigSummary
Identifies the models, Knowledge Bases, or other RAG sources evaluated in a model or Knowledge Base evaluation job.
-
#job_arn ⇒ String
The Amazon Resource Name (ARN) of the evaluation job.
-
#job_name ⇒ String
The name for the evaluation job.
-
#job_type ⇒ String
Specifies whether the evaluation job is automated or human-based.
-
#model_identifiers ⇒ Array<String>
The Amazon Resource Names (ARNs) of the model(s) used for the evaluation job.
-
#rag_identifiers ⇒ Array<String>
The Amazon Resource Names (ARNs) of the knowledge base resources used for a knowledge base evaluation job.
-
#status ⇒ String
The current status of the evaluation job.
Instance Attribute Details
#application_type ⇒ String
Specifies whether the evaluation job is for evaluating a model or evaluating a knowledge base (retrieval and response generation).
5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5638 class EvaluationSummary < Struct.new( :job_arn, :job_name, :status, :creation_time, :job_type, :evaluation_task_types, :model_identifiers, :rag_identifiers, :evaluator_model_identifiers, :custom_metrics_evaluator_model_identifiers, :inference_config_summary, :application_type) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time the evaluation job was created.
5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5638 class EvaluationSummary < Struct.new( :job_arn, :job_name, :status, :creation_time, :job_type, :evaluation_task_types, :model_identifiers, :rag_identifiers, :evaluator_model_identifiers, :custom_metrics_evaluator_model_identifiers, :inference_config_summary, :application_type) SENSITIVE = [] include Aws::Structure end |
#custom_metrics_evaluator_model_identifiers ⇒ Array<String>
The Amazon Resource Names (ARNs) of the models used to compute custom metrics in an Amazon Bedrock evaluation job.
5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5638 class EvaluationSummary < Struct.new( :job_arn, :job_name, :status, :creation_time, :job_type, :evaluation_task_types, :model_identifiers, :rag_identifiers, :evaluator_model_identifiers, :custom_metrics_evaluator_model_identifiers, :inference_config_summary, :application_type) SENSITIVE = [] include Aws::Structure end |
#evaluation_task_types ⇒ Array<String>
The type of task for model evaluation.
5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5638 class EvaluationSummary < Struct.new( :job_arn, :job_name, :status, :creation_time, :job_type, :evaluation_task_types, :model_identifiers, :rag_identifiers, :evaluator_model_identifiers, :custom_metrics_evaluator_model_identifiers, :inference_config_summary, :application_type) SENSITIVE = [] include Aws::Structure end |
#evaluator_model_identifiers ⇒ Array<String>
The Amazon Resource Names (ARNs) of the models used to compute the metrics for a knowledge base evaluation job.
5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5638 class EvaluationSummary < Struct.new( :job_arn, :job_name, :status, :creation_time, :job_type, :evaluation_task_types, :model_identifiers, :rag_identifiers, :evaluator_model_identifiers, :custom_metrics_evaluator_model_identifiers, :inference_config_summary, :application_type) SENSITIVE = [] include Aws::Structure end |
#inference_config_summary ⇒ Types::EvaluationInferenceConfigSummary
Identifies the models, Knowledge Bases, or other RAG sources evaluated in a model or Knowledge Base evaluation job.
5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5638 class EvaluationSummary < Struct.new( :job_arn, :job_name, :status, :creation_time, :job_type, :evaluation_task_types, :model_identifiers, :rag_identifiers, :evaluator_model_identifiers, :custom_metrics_evaluator_model_identifiers, :inference_config_summary, :application_type) SENSITIVE = [] include Aws::Structure end |
#job_arn ⇒ String
The Amazon Resource Name (ARN) of the evaluation job.
5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5638 class EvaluationSummary < Struct.new( :job_arn, :job_name, :status, :creation_time, :job_type, :evaluation_task_types, :model_identifiers, :rag_identifiers, :evaluator_model_identifiers, :custom_metrics_evaluator_model_identifiers, :inference_config_summary, :application_type) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The name for the evaluation job.
5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5638 class EvaluationSummary < Struct.new( :job_arn, :job_name, :status, :creation_time, :job_type, :evaluation_task_types, :model_identifiers, :rag_identifiers, :evaluator_model_identifiers, :custom_metrics_evaluator_model_identifiers, :inference_config_summary, :application_type) SENSITIVE = [] include Aws::Structure end |
#job_type ⇒ String
Specifies whether the evaluation job is automated or human-based.
5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5638 class EvaluationSummary < Struct.new( :job_arn, :job_name, :status, :creation_time, :job_type, :evaluation_task_types, :model_identifiers, :rag_identifiers, :evaluator_model_identifiers, :custom_metrics_evaluator_model_identifiers, :inference_config_summary, :application_type) SENSITIVE = [] include Aws::Structure end |
#model_identifiers ⇒ Array<String>
The Amazon Resource Names (ARNs) of the model(s) used for the evaluation job.
5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5638 class EvaluationSummary < Struct.new( :job_arn, :job_name, :status, :creation_time, :job_type, :evaluation_task_types, :model_identifiers, :rag_identifiers, :evaluator_model_identifiers, :custom_metrics_evaluator_model_identifiers, :inference_config_summary, :application_type) SENSITIVE = [] include Aws::Structure end |
#rag_identifiers ⇒ Array<String>
The Amazon Resource Names (ARNs) of the knowledge base resources used for a knowledge base evaluation job.
5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5638 class EvaluationSummary < Struct.new( :job_arn, :job_name, :status, :creation_time, :job_type, :evaluation_task_types, :model_identifiers, :rag_identifiers, :evaluator_model_identifiers, :custom_metrics_evaluator_model_identifiers, :inference_config_summary, :application_type) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the evaluation job.
5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5638 class EvaluationSummary < Struct.new( :job_arn, :job_name, :status, :creation_time, :job_type, :evaluation_task_types, :model_identifiers, :rag_identifiers, :evaluator_model_identifiers, :custom_metrics_evaluator_model_identifiers, :inference_config_summary, :application_type) SENSITIVE = [] include Aws::Structure end |