Class: Aws::Bedrock::Types::ExportAutomatedReasoningPolicyVersionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::ExportAutomatedReasoningPolicyVersionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy_definition ⇒ Types::AutomatedReasoningPolicyDefinition
The exported policy definition containing the formal logic rules, variables, and custom variable types.
Instance Attribute Details
#policy_definition ⇒ Types::AutomatedReasoningPolicyDefinition
The exported policy definition containing the formal logic rules, variables, and custom variable types.
5673 5674 5675 5676 5677 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5673 class ExportAutomatedReasoningPolicyVersionResponse < Struct.new( :policy_definition) SENSITIVE = [] include Aws::Structure end |