Class: Aws::Bedrock::Types::ExternalSourcesGenerationConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

The response generation configuration of the external source wrapper object.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_model_request_fieldsHash<String,Hash,Array,String,Numeric,Boolean>

Additional model parameters and their corresponding values not included in the text inference configuration for an external source. Takes in custom model parameters specific to the language model being used.

Returns:

  • (Hash<String,Hash,Array,String,Numeric,Boolean>)


5672
5673
5674
5675
5676
5677
5678
5679
# File 'lib/aws-sdk-bedrock/types.rb', line 5672

class ExternalSourcesGenerationConfiguration < Struct.new(
  :prompt_template,
  :guardrail_configuration,
  :kb_inference_config,
  :additional_model_request_fields)
  SENSITIVE = []
  include Aws::Structure
end

#guardrail_configurationTypes::GuardrailConfiguration

Configuration details for the guardrail.



5672
5673
5674
5675
5676
5677
5678
5679
# File 'lib/aws-sdk-bedrock/types.rb', line 5672

class ExternalSourcesGenerationConfiguration < Struct.new(
  :prompt_template,
  :guardrail_configuration,
  :kb_inference_config,
  :additional_model_request_fields)
  SENSITIVE = []
  include Aws::Structure
end

#kb_inference_configTypes::KbInferenceConfig

Configuration details for inference when using ‘RetrieveAndGenerate` to generate responses while using an external source.



5672
5673
5674
5675
5676
5677
5678
5679
# File 'lib/aws-sdk-bedrock/types.rb', line 5672

class ExternalSourcesGenerationConfiguration < Struct.new(
  :prompt_template,
  :guardrail_configuration,
  :kb_inference_config,
  :additional_model_request_fields)
  SENSITIVE = []
  include Aws::Structure
end

#prompt_templateTypes::PromptTemplate

Contains the template for the prompt for the external source wrapper object.



5672
5673
5674
5675
5676
5677
5678
5679
# File 'lib/aws-sdk-bedrock/types.rb', line 5672

class ExternalSourcesGenerationConfiguration < Struct.new(
  :prompt_template,
  :guardrail_configuration,
  :kb_inference_config,
  :additional_model_request_fields)
  SENSITIVE = []
  include Aws::Structure
end