Class: Aws::Bedrock::Types::FoundationModelLifecycle
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::FoundationModelLifecycle
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Details about whether a model version is available or deprecated.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_of_life_time ⇒ Time
Time when the model is no longer available for use.
-
#legacy_time ⇒ Time
Time when the model enters legacy state.
-
#public_extended_access_time ⇒ Time
Public extended access portion of the legacy period, when users should expect higher pricing.
-
#start_of_life_time ⇒ Time
Launch time when the model first becomes available.
-
#status ⇒ String
Specifies whether a model version is available (‘ACTIVE`) or deprecated (`LEGACY`..
Instance Attribute Details
#end_of_life_time ⇒ Time
Time when the model is no longer available for use
5931 5932 5933 5934 5935 5936 5937 5938 5939 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5931 class FoundationModelLifecycle < Struct.new( :status, :start_of_life_time, :end_of_life_time, :legacy_time, :public_extended_access_time) SENSITIVE = [] include Aws::Structure end |
#legacy_time ⇒ Time
Time when the model enters legacy state. Models in legacy state can still be used, but users should plan to transition to an Active model before the end of life time
5931 5932 5933 5934 5935 5936 5937 5938 5939 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5931 class FoundationModelLifecycle < Struct.new( :status, :start_of_life_time, :end_of_life_time, :legacy_time, :public_extended_access_time) SENSITIVE = [] include Aws::Structure end |
#public_extended_access_time ⇒ Time
Public extended access portion of the legacy period, when users should expect higher pricing
5931 5932 5933 5934 5935 5936 5937 5938 5939 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5931 class FoundationModelLifecycle < Struct.new( :status, :start_of_life_time, :end_of_life_time, :legacy_time, :public_extended_access_time) SENSITIVE = [] include Aws::Structure end |
#start_of_life_time ⇒ Time
Launch time when the model first becomes available
5931 5932 5933 5934 5935 5936 5937 5938 5939 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5931 class FoundationModelLifecycle < Struct.new( :status, :start_of_life_time, :end_of_life_time, :legacy_time, :public_extended_access_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Specifies whether a model version is available (‘ACTIVE`) or deprecated (`LEGACY`.
5931 5932 5933 5934 5935 5936 5937 5938 5939 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5931 class FoundationModelLifecycle < Struct.new( :status, :start_of_life_time, :end_of_life_time, :legacy_time, :public_extended_access_time) SENSITIVE = [] include Aws::Structure end |