Class: Aws::Bedrock::Types::FoundationModelSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::FoundationModelSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Summary information for a foundation model.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#customizations_supported ⇒ Array<String>
Whether the model supports fine-tuning or continual pre-training.
-
#inference_types_supported ⇒ Array<String>
The inference types that the model supports.
-
#input_modalities ⇒ Array<String>
The input modalities that the model supports.
-
#model_arn ⇒ String
The Amazon Resource Name (ARN) of the foundation model.
-
#model_id ⇒ String
The model ID of the foundation model.
-
#model_lifecycle ⇒ Types::FoundationModelLifecycle
Contains details about whether a model version is available or deprecated.
-
#model_name ⇒ String
The name of the model.
-
#output_modalities ⇒ Array<String>
The output modalities that the model supports.
-
#provider_name ⇒ String
The model’s provider name.
-
#response_streaming_supported ⇒ Boolean
Indicates whether the model supports streaming.
Instance Attribute Details
#customizations_supported ⇒ Array<String>
Whether the model supports fine-tuning or continual pre-training.
5896 5897 5898 5899 5900 5901 5902 5903 5904 5905 5906 5907 5908 5909 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5896 class FoundationModelSummary < Struct.new( :model_arn, :model_id, :model_name, :provider_name, :input_modalities, :output_modalities, :response_streaming_supported, :customizations_supported, :inference_types_supported, :model_lifecycle) SENSITIVE = [] include Aws::Structure end |
#inference_types_supported ⇒ Array<String>
The inference types that the model supports.
5896 5897 5898 5899 5900 5901 5902 5903 5904 5905 5906 5907 5908 5909 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5896 class FoundationModelSummary < Struct.new( :model_arn, :model_id, :model_name, :provider_name, :input_modalities, :output_modalities, :response_streaming_supported, :customizations_supported, :inference_types_supported, :model_lifecycle) SENSITIVE = [] include Aws::Structure end |
#input_modalities ⇒ Array<String>
The input modalities that the model supports.
5896 5897 5898 5899 5900 5901 5902 5903 5904 5905 5906 5907 5908 5909 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5896 class FoundationModelSummary < Struct.new( :model_arn, :model_id, :model_name, :provider_name, :input_modalities, :output_modalities, :response_streaming_supported, :customizations_supported, :inference_types_supported, :model_lifecycle) SENSITIVE = [] include Aws::Structure end |
#model_arn ⇒ String
The Amazon Resource Name (ARN) of the foundation model.
5896 5897 5898 5899 5900 5901 5902 5903 5904 5905 5906 5907 5908 5909 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5896 class FoundationModelSummary < Struct.new( :model_arn, :model_id, :model_name, :provider_name, :input_modalities, :output_modalities, :response_streaming_supported, :customizations_supported, :inference_types_supported, :model_lifecycle) SENSITIVE = [] include Aws::Structure end |
#model_id ⇒ String
The model ID of the foundation model.
5896 5897 5898 5899 5900 5901 5902 5903 5904 5905 5906 5907 5908 5909 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5896 class FoundationModelSummary < Struct.new( :model_arn, :model_id, :model_name, :provider_name, :input_modalities, :output_modalities, :response_streaming_supported, :customizations_supported, :inference_types_supported, :model_lifecycle) SENSITIVE = [] include Aws::Structure end |
#model_lifecycle ⇒ Types::FoundationModelLifecycle
Contains details about whether a model version is available or deprecated.
5896 5897 5898 5899 5900 5901 5902 5903 5904 5905 5906 5907 5908 5909 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5896 class FoundationModelSummary < Struct.new( :model_arn, :model_id, :model_name, :provider_name, :input_modalities, :output_modalities, :response_streaming_supported, :customizations_supported, :inference_types_supported, :model_lifecycle) SENSITIVE = [] include Aws::Structure end |
#model_name ⇒ String
The name of the model.
5896 5897 5898 5899 5900 5901 5902 5903 5904 5905 5906 5907 5908 5909 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5896 class FoundationModelSummary < Struct.new( :model_arn, :model_id, :model_name, :provider_name, :input_modalities, :output_modalities, :response_streaming_supported, :customizations_supported, :inference_types_supported, :model_lifecycle) SENSITIVE = [] include Aws::Structure end |
#output_modalities ⇒ Array<String>
The output modalities that the model supports.
5896 5897 5898 5899 5900 5901 5902 5903 5904 5905 5906 5907 5908 5909 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5896 class FoundationModelSummary < Struct.new( :model_arn, :model_id, :model_name, :provider_name, :input_modalities, :output_modalities, :response_streaming_supported, :customizations_supported, :inference_types_supported, :model_lifecycle) SENSITIVE = [] include Aws::Structure end |
#provider_name ⇒ String
The model’s provider name.
5896 5897 5898 5899 5900 5901 5902 5903 5904 5905 5906 5907 5908 5909 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5896 class FoundationModelSummary < Struct.new( :model_arn, :model_id, :model_name, :provider_name, :input_modalities, :output_modalities, :response_streaming_supported, :customizations_supported, :inference_types_supported, :model_lifecycle) SENSITIVE = [] include Aws::Structure end |
#response_streaming_supported ⇒ Boolean
Indicates whether the model supports streaming.
5896 5897 5898 5899 5900 5901 5902 5903 5904 5905 5906 5907 5908 5909 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5896 class FoundationModelSummary < Struct.new( :model_arn, :model_id, :model_name, :provider_name, :input_modalities, :output_modalities, :response_streaming_supported, :customizations_supported, :inference_types_supported, :model_lifecycle) SENSITIVE = [] include Aws::Structure end |