Class: Aws::Bedrock::Types::GetAccountDataRetentionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::GetAccountDataRetentionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#mode ⇒ String
The data retention mode configured for the account.
-
#updated_at ⇒ Time
The time at which the data retention mode was last updated.
Instance Attribute Details
#mode ⇒ String
The data retention mode configured for the account.
6052 6053 6054 6055 6056 6057 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6052 class GetAccountDataRetentionResponse < Struct.new( :mode, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The time at which the data retention mode was last updated.
6052 6053 6054 6055 6056 6057 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6052 class GetAccountDataRetentionResponse < Struct.new( :mode, :updated_at) SENSITIVE = [] include Aws::Structure end |