Class: Aws::Bedrock::Types::GetAutomatedReasoningPolicyBuildWorkflowResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:document_name, :document_description]

Instance Attribute Summary collapse

Instance Attribute Details

#build_workflow_idString

The unique identifier of the build workflow.

Returns:

  • (String)


6144
6145
6146
6147
6148
6149
6150
6151
6152
6153
6154
6155
6156
# File 'lib/aws-sdk-bedrock/types.rb', line 6144

class GetAutomatedReasoningPolicyBuildWorkflowResponse < Struct.new(
  :policy_arn,
  :build_workflow_id,
  :status,
  :build_workflow_type,
  :document_name,
  :document_content_type,
  :document_description,
  :created_at,
  :updated_at)
  SENSITIVE = [:document_name, :document_description]
  include Aws::Structure
end

#build_workflow_typeString

The type of build workflow being executed (e.g., DOCUMENT_INGESTION, POLICY_REPAIR).

Returns:

  • (String)


6144
6145
6146
6147
6148
6149
6150
6151
6152
6153
6154
6155
6156
# File 'lib/aws-sdk-bedrock/types.rb', line 6144

class GetAutomatedReasoningPolicyBuildWorkflowResponse < Struct.new(
  :policy_arn,
  :build_workflow_id,
  :status,
  :build_workflow_type,
  :document_name,
  :document_content_type,
  :document_description,
  :created_at,
  :updated_at)
  SENSITIVE = [:document_name, :document_description]
  include Aws::Structure
end

#created_atTime

The timestamp when the build workflow was created.

Returns:

  • (Time)


6144
6145
6146
6147
6148
6149
6150
6151
6152
6153
6154
6155
6156
# File 'lib/aws-sdk-bedrock/types.rb', line 6144

class GetAutomatedReasoningPolicyBuildWorkflowResponse < Struct.new(
  :policy_arn,
  :build_workflow_id,
  :status,
  :build_workflow_type,
  :document_name,
  :document_content_type,
  :document_description,
  :created_at,
  :updated_at)
  SENSITIVE = [:document_name, :document_description]
  include Aws::Structure
end

#document_content_typeString

The content type of the source document (e.g., text/plain, application/pdf).

Returns:

  • (String)


6144
6145
6146
6147
6148
6149
6150
6151
6152
6153
6154
6155
6156
# File 'lib/aws-sdk-bedrock/types.rb', line 6144

class GetAutomatedReasoningPolicyBuildWorkflowResponse < Struct.new(
  :policy_arn,
  :build_workflow_id,
  :status,
  :build_workflow_type,
  :document_name,
  :document_content_type,
  :document_description,
  :created_at,
  :updated_at)
  SENSITIVE = [:document_name, :document_description]
  include Aws::Structure
end

#document_descriptionString

A detailed description of the document’s content and how it should be used in the policy generation process.

Returns:

  • (String)


6144
6145
6146
6147
6148
6149
6150
6151
6152
6153
6154
6155
6156
# File 'lib/aws-sdk-bedrock/types.rb', line 6144

class GetAutomatedReasoningPolicyBuildWorkflowResponse < Struct.new(
  :policy_arn,
  :build_workflow_id,
  :status,
  :build_workflow_type,
  :document_name,
  :document_content_type,
  :document_description,
  :created_at,
  :updated_at)
  SENSITIVE = [:document_name, :document_description]
  include Aws::Structure
end

#document_nameString

The name of the source document used in the build workflow.

Returns:

  • (String)


6144
6145
6146
6147
6148
6149
6150
6151
6152
6153
6154
6155
6156
# File 'lib/aws-sdk-bedrock/types.rb', line 6144

class GetAutomatedReasoningPolicyBuildWorkflowResponse < Struct.new(
  :policy_arn,
  :build_workflow_id,
  :status,
  :build_workflow_type,
  :document_name,
  :document_content_type,
  :document_description,
  :created_at,
  :updated_at)
  SENSITIVE = [:document_name, :document_description]
  include Aws::Structure
end

#policy_arnString

The Amazon Resource Name (ARN) of the Automated Reasoning policy.

Returns:

  • (String)


6144
6145
6146
6147
6148
6149
6150
6151
6152
6153
6154
6155
6156
# File 'lib/aws-sdk-bedrock/types.rb', line 6144

class GetAutomatedReasoningPolicyBuildWorkflowResponse < Struct.new(
  :policy_arn,
  :build_workflow_id,
  :status,
  :build_workflow_type,
  :document_name,
  :document_content_type,
  :document_description,
  :created_at,
  :updated_at)
  SENSITIVE = [:document_name, :document_description]
  include Aws::Structure
end

#statusString

The current status of the build workflow (e.g., RUNNING, COMPLETED, FAILED, CANCELLED).

Returns:

  • (String)


6144
6145
6146
6147
6148
6149
6150
6151
6152
6153
6154
6155
6156
# File 'lib/aws-sdk-bedrock/types.rb', line 6144

class GetAutomatedReasoningPolicyBuildWorkflowResponse < Struct.new(
  :policy_arn,
  :build_workflow_id,
  :status,
  :build_workflow_type,
  :document_name,
  :document_content_type,
  :document_description,
  :created_at,
  :updated_at)
  SENSITIVE = [:document_name, :document_description]
  include Aws::Structure
end

#updated_atTime

The timestamp when the build workflow was last updated.

Returns:

  • (Time)


6144
6145
6146
6147
6148
6149
6150
6151
6152
6153
6154
6155
6156
# File 'lib/aws-sdk-bedrock/types.rb', line 6144

class GetAutomatedReasoningPolicyBuildWorkflowResponse < Struct.new(
  :policy_arn,
  :build_workflow_id,
  :status,
  :build_workflow_type,
  :document_name,
  :document_content_type,
  :document_description,
  :created_at,
  :updated_at)
  SENSITIVE = [:document_name, :document_description]
  include Aws::Structure
end