Class: Aws::Bedrock::Types::GetAutomatedReasoningPolicyTestResultResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::GetAutomatedReasoningPolicyTestResultResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#test_result ⇒ Types::AutomatedReasoningPolicyTestResult
The test result containing validation findings, execution status, and detailed analysis.
Instance Attribute Details
#test_result ⇒ Types::AutomatedReasoningPolicyTestResult
The test result containing validation findings, execution status, and detailed analysis.
6391 6392 6393 6394 6395 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6391 class GetAutomatedReasoningPolicyTestResultResponse < Struct.new( :test_result) SENSITIVE = [] include Aws::Structure end |