Class: Aws::Bedrock::Types::GetCustomModelDeploymentResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The date and time when the custom model deployment was created.

Returns:

  • (Time)


6576
6577
6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
# File 'lib/aws-sdk-bedrock/types.rb', line 6576

class GetCustomModelDeploymentResponse < Struct.new(
  :custom_model_deployment_arn,
  :model_deployment_name,
  :model_arn,
  :created_at,
  :status,
  :description,
  :update_details,
  :failure_message,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#custom_model_deployment_arnString

The Amazon Resource Name (ARN) of the custom model deployment.

Returns:

  • (String)


6576
6577
6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
# File 'lib/aws-sdk-bedrock/types.rb', line 6576

class GetCustomModelDeploymentResponse < Struct.new(
  :custom_model_deployment_arn,
  :model_deployment_name,
  :model_arn,
  :created_at,
  :status,
  :description,
  :update_details,
  :failure_message,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the custom model deployment.

Returns:

  • (String)


6576
6577
6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
# File 'lib/aws-sdk-bedrock/types.rb', line 6576

class GetCustomModelDeploymentResponse < Struct.new(
  :custom_model_deployment_arn,
  :model_deployment_name,
  :model_arn,
  :created_at,
  :status,
  :description,
  :update_details,
  :failure_message,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#failure_messageString

If the deployment status is ‘FAILED`, this field contains a message describing the failure reason.

Returns:

  • (String)


6576
6577
6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
# File 'lib/aws-sdk-bedrock/types.rb', line 6576

class GetCustomModelDeploymentResponse < Struct.new(
  :custom_model_deployment_arn,
  :model_deployment_name,
  :model_arn,
  :created_at,
  :status,
  :description,
  :update_details,
  :failure_message,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

The date and time when the custom model deployment was last updated.

Returns:

  • (Time)


6576
6577
6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
# File 'lib/aws-sdk-bedrock/types.rb', line 6576

class GetCustomModelDeploymentResponse < Struct.new(
  :custom_model_deployment_arn,
  :model_deployment_name,
  :model_arn,
  :created_at,
  :status,
  :description,
  :update_details,
  :failure_message,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#model_arnString

The Amazon Resource Name (ARN) of the custom model associated with this deployment.

Returns:

  • (String)


6576
6577
6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
# File 'lib/aws-sdk-bedrock/types.rb', line 6576

class GetCustomModelDeploymentResponse < Struct.new(
  :custom_model_deployment_arn,
  :model_deployment_name,
  :model_arn,
  :created_at,
  :status,
  :description,
  :update_details,
  :failure_message,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#model_deployment_nameString

The name of the custom model deployment.

Returns:

  • (String)


6576
6577
6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
# File 'lib/aws-sdk-bedrock/types.rb', line 6576

class GetCustomModelDeploymentResponse < Struct.new(
  :custom_model_deployment_arn,
  :model_deployment_name,
  :model_arn,
  :created_at,
  :status,
  :description,
  :update_details,
  :failure_message,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the custom model deployment. Possible values are:

  • ‘CREATING` - The deployment is being set up and prepared for inference.

  • ‘ACTIVE` - The deployment is ready and available for inference requests.

  • ‘FAILED` - The deployment failed to be created or became unavailable.

Returns:

  • (String)


6576
6577
6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
# File 'lib/aws-sdk-bedrock/types.rb', line 6576

class GetCustomModelDeploymentResponse < Struct.new(
  :custom_model_deployment_arn,
  :model_deployment_name,
  :model_arn,
  :created_at,
  :status,
  :description,
  :update_details,
  :failure_message,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#update_detailsTypes::CustomModelDeploymentUpdateDetails

Details about any pending or completed updates to the custom model deployment, including the new model ARN and update status.



6576
6577
6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
# File 'lib/aws-sdk-bedrock/types.rb', line 6576

class GetCustomModelDeploymentResponse < Struct.new(
  :custom_model_deployment_arn,
  :model_deployment_name,
  :model_arn,
  :created_at,
  :status,
  :description,
  :update_details,
  :failure_message,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end