Class: Aws::Bedrock::Types::GetEvaluationJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::GetEvaluationJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:job_description]
Instance Attribute Summary collapse
-
#application_type ⇒ String
Specifies whether the evaluation job is for evaluating a model or evaluating a knowledge base (retrieval and response generation).
-
#creation_time ⇒ Time
The time the evaluation job was created.
-
#customer_encryption_key_id ⇒ String
The Amazon Resource Name (ARN) of the customer managed encryption key specified when the evaluation job was created.
-
#evaluation_config ⇒ Types::EvaluationConfig
Contains the configuration details of either an automated or human-based evaluation job.
-
#failure_messages ⇒ Array<String>
A list of strings that specify why the evaluation job failed to create.
-
#inference_config ⇒ Types::EvaluationInferenceConfig
Contains the configuration details of the inference model used for the evaluation job.
-
#job_arn ⇒ String
The Amazon Resource Name (ARN) of the evaluation job.
-
#job_description ⇒ String
The description of the evaluation job.
-
#job_name ⇒ String
The name for the evaluation job.
-
#job_type ⇒ String
Specifies whether the evaluation job is automated or human-based.
-
#last_modified_time ⇒ Time
The time the evaluation job was last modified.
-
#output_data_config ⇒ Types::EvaluationOutputDataConfig
Contains the configuration details of the Amazon S3 bucket for storing the results of the evaluation job.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM service role used in the evaluation job.
-
#status ⇒ String
The current status of the evaluation job.
Instance Attribute Details
#application_type ⇒ String
Specifies whether the evaluation job is for evaluating a model or evaluating a knowledge base (retrieval and response generation).
6793 6794 6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6793 class GetEvaluationJobResponse < Struct.new( :job_name, :status, :job_arn, :job_description, :role_arn, :customer_encryption_key_id, :job_type, :application_type, :evaluation_config, :inference_config, :output_data_config, :creation_time, :last_modified_time, :failure_messages) SENSITIVE = [:job_description] include Aws::Structure end |
#creation_time ⇒ Time
The time the evaluation job was created.
6793 6794 6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6793 class GetEvaluationJobResponse < Struct.new( :job_name, :status, :job_arn, :job_description, :role_arn, :customer_encryption_key_id, :job_type, :application_type, :evaluation_config, :inference_config, :output_data_config, :creation_time, :last_modified_time, :failure_messages) SENSITIVE = [:job_description] include Aws::Structure end |
#customer_encryption_key_id ⇒ String
The Amazon Resource Name (ARN) of the customer managed encryption key specified when the evaluation job was created.
6793 6794 6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6793 class GetEvaluationJobResponse < Struct.new( :job_name, :status, :job_arn, :job_description, :role_arn, :customer_encryption_key_id, :job_type, :application_type, :evaluation_config, :inference_config, :output_data_config, :creation_time, :last_modified_time, :failure_messages) SENSITIVE = [:job_description] include Aws::Structure end |
#evaluation_config ⇒ Types::EvaluationConfig
Contains the configuration details of either an automated or human-based evaluation job.
6793 6794 6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6793 class GetEvaluationJobResponse < Struct.new( :job_name, :status, :job_arn, :job_description, :role_arn, :customer_encryption_key_id, :job_type, :application_type, :evaluation_config, :inference_config, :output_data_config, :creation_time, :last_modified_time, :failure_messages) SENSITIVE = [:job_description] include Aws::Structure end |
#failure_messages ⇒ Array<String>
A list of strings that specify why the evaluation job failed to create.
6793 6794 6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6793 class GetEvaluationJobResponse < Struct.new( :job_name, :status, :job_arn, :job_description, :role_arn, :customer_encryption_key_id, :job_type, :application_type, :evaluation_config, :inference_config, :output_data_config, :creation_time, :last_modified_time, :failure_messages) SENSITIVE = [:job_description] include Aws::Structure end |
#inference_config ⇒ Types::EvaluationInferenceConfig
Contains the configuration details of the inference model used for the evaluation job.
6793 6794 6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6793 class GetEvaluationJobResponse < Struct.new( :job_name, :status, :job_arn, :job_description, :role_arn, :customer_encryption_key_id, :job_type, :application_type, :evaluation_config, :inference_config, :output_data_config, :creation_time, :last_modified_time, :failure_messages) SENSITIVE = [:job_description] include Aws::Structure end |
#job_arn ⇒ String
The Amazon Resource Name (ARN) of the evaluation job.
6793 6794 6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6793 class GetEvaluationJobResponse < Struct.new( :job_name, :status, :job_arn, :job_description, :role_arn, :customer_encryption_key_id, :job_type, :application_type, :evaluation_config, :inference_config, :output_data_config, :creation_time, :last_modified_time, :failure_messages) SENSITIVE = [:job_description] include Aws::Structure end |
#job_description ⇒ String
The description of the evaluation job.
6793 6794 6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6793 class GetEvaluationJobResponse < Struct.new( :job_name, :status, :job_arn, :job_description, :role_arn, :customer_encryption_key_id, :job_type, :application_type, :evaluation_config, :inference_config, :output_data_config, :creation_time, :last_modified_time, :failure_messages) SENSITIVE = [:job_description] include Aws::Structure end |
#job_name ⇒ String
The name for the evaluation job.
6793 6794 6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6793 class GetEvaluationJobResponse < Struct.new( :job_name, :status, :job_arn, :job_description, :role_arn, :customer_encryption_key_id, :job_type, :application_type, :evaluation_config, :inference_config, :output_data_config, :creation_time, :last_modified_time, :failure_messages) SENSITIVE = [:job_description] include Aws::Structure end |
#job_type ⇒ String
Specifies whether the evaluation job is automated or human-based.
6793 6794 6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6793 class GetEvaluationJobResponse < Struct.new( :job_name, :status, :job_arn, :job_description, :role_arn, :customer_encryption_key_id, :job_type, :application_type, :evaluation_config, :inference_config, :output_data_config, :creation_time, :last_modified_time, :failure_messages) SENSITIVE = [:job_description] include Aws::Structure end |
#last_modified_time ⇒ Time
The time the evaluation job was last modified.
6793 6794 6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6793 class GetEvaluationJobResponse < Struct.new( :job_name, :status, :job_arn, :job_description, :role_arn, :customer_encryption_key_id, :job_type, :application_type, :evaluation_config, :inference_config, :output_data_config, :creation_time, :last_modified_time, :failure_messages) SENSITIVE = [:job_description] include Aws::Structure end |
#output_data_config ⇒ Types::EvaluationOutputDataConfig
Contains the configuration details of the Amazon S3 bucket for storing the results of the evaluation job.
6793 6794 6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6793 class GetEvaluationJobResponse < Struct.new( :job_name, :status, :job_arn, :job_description, :role_arn, :customer_encryption_key_id, :job_type, :application_type, :evaluation_config, :inference_config, :output_data_config, :creation_time, :last_modified_time, :failure_messages) SENSITIVE = [:job_description] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM service role used in the evaluation job.
6793 6794 6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6793 class GetEvaluationJobResponse < Struct.new( :job_name, :status, :job_arn, :job_description, :role_arn, :customer_encryption_key_id, :job_type, :application_type, :evaluation_config, :inference_config, :output_data_config, :creation_time, :last_modified_time, :failure_messages) SENSITIVE = [:job_description] include Aws::Structure end |
#status ⇒ String
The current status of the evaluation job.
6793 6794 6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6793 class GetEvaluationJobResponse < Struct.new( :job_name, :status, :job_arn, :job_description, :role_arn, :customer_encryption_key_id, :job_type, :application_type, :evaluation_config, :inference_config, :output_data_config, :creation_time, :last_modified_time, :failure_messages) SENSITIVE = [:job_description] include Aws::Structure end |