Class: Aws::Bedrock::Types::GetInferenceProfileResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::GetInferenceProfileResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The time at which the inference profile was created.
-
#description ⇒ String
The description of the inference profile.
-
#inference_profile_arn ⇒ String
The Amazon Resource Name (ARN) of the inference profile.
-
#inference_profile_id ⇒ String
The unique identifier of the inference profile.
-
#inference_profile_name ⇒ String
The name of the inference profile.
-
#models ⇒ Array<Types::InferenceProfileModel>
A list of information about each model in the inference profile.
-
#status ⇒ String
The status of the inference profile.
-
#type ⇒ String
The type of the inference profile.
-
#updated_at ⇒ Time
The time at which the inference profile was last updated.
Instance Attribute Details
#created_at ⇒ Time
The time at which the inference profile was created.
7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 7101 7102 |
# File 'lib/aws-sdk-bedrock/types.rb', line 7090 class GetInferenceProfileResponse < Struct.new( :inference_profile_name, :description, :created_at, :updated_at, :inference_profile_arn, :models, :inference_profile_id, :status, :type) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The description of the inference profile.
7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 7101 7102 |
# File 'lib/aws-sdk-bedrock/types.rb', line 7090 class GetInferenceProfileResponse < Struct.new( :inference_profile_name, :description, :created_at, :updated_at, :inference_profile_arn, :models, :inference_profile_id, :status, :type) SENSITIVE = [:description] include Aws::Structure end |
#inference_profile_arn ⇒ String
The Amazon Resource Name (ARN) of the inference profile.
7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 7101 7102 |
# File 'lib/aws-sdk-bedrock/types.rb', line 7090 class GetInferenceProfileResponse < Struct.new( :inference_profile_name, :description, :created_at, :updated_at, :inference_profile_arn, :models, :inference_profile_id, :status, :type) SENSITIVE = [:description] include Aws::Structure end |
#inference_profile_id ⇒ String
The unique identifier of the inference profile.
7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 7101 7102 |
# File 'lib/aws-sdk-bedrock/types.rb', line 7090 class GetInferenceProfileResponse < Struct.new( :inference_profile_name, :description, :created_at, :updated_at, :inference_profile_arn, :models, :inference_profile_id, :status, :type) SENSITIVE = [:description] include Aws::Structure end |
#inference_profile_name ⇒ String
The name of the inference profile.
7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 7101 7102 |
# File 'lib/aws-sdk-bedrock/types.rb', line 7090 class GetInferenceProfileResponse < Struct.new( :inference_profile_name, :description, :created_at, :updated_at, :inference_profile_arn, :models, :inference_profile_id, :status, :type) SENSITIVE = [:description] include Aws::Structure end |
#models ⇒ Array<Types::InferenceProfileModel>
A list of information about each model in the inference profile.
7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 7101 7102 |
# File 'lib/aws-sdk-bedrock/types.rb', line 7090 class GetInferenceProfileResponse < Struct.new( :inference_profile_name, :description, :created_at, :updated_at, :inference_profile_arn, :models, :inference_profile_id, :status, :type) SENSITIVE = [:description] include Aws::Structure end |
#status ⇒ String
The status of the inference profile. ‘ACTIVE` means that the inference profile is ready to be used.
7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 7101 7102 |
# File 'lib/aws-sdk-bedrock/types.rb', line 7090 class GetInferenceProfileResponse < Struct.new( :inference_profile_name, :description, :created_at, :updated_at, :inference_profile_arn, :models, :inference_profile_id, :status, :type) SENSITIVE = [:description] include Aws::Structure end |
#type ⇒ String
The type of the inference profile. The following types are possible:
-
‘SYSTEM_DEFINED` – The inference profile is defined by Amazon Bedrock. You can route inference requests across regions with these inference profiles.
-
‘APPLICATION` – The inference profile was created by a user. This type of inference profile can track metrics and costs when invoking the model in it. The inference profile may route requests to one or multiple regions.
7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 7101 7102 |
# File 'lib/aws-sdk-bedrock/types.rb', line 7090 class GetInferenceProfileResponse < Struct.new( :inference_profile_name, :description, :created_at, :updated_at, :inference_profile_arn, :models, :inference_profile_id, :status, :type) SENSITIVE = [:description] include Aws::Structure end |
#updated_at ⇒ Time
The time at which the inference profile was last updated.
7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 7101 7102 |
# File 'lib/aws-sdk-bedrock/types.rb', line 7090 class GetInferenceProfileResponse < Struct.new( :inference_profile_name, :description, :created_at, :updated_at, :inference_profile_arn, :models, :inference_profile_id, :status, :type) SENSITIVE = [:description] include Aws::Structure end |