Class: Aws::Bedrock::Types::GetProvisionedModelThroughputResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#commitment_durationString

Commitment duration of the Provisioned Throughput.

Returns:

  • (String)


7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
# File 'lib/aws-sdk-bedrock/types.rb', line 7797

class GetProvisionedModelThroughputResponse < Struct.new(
  :model_units,
  :desired_model_units,
  :provisioned_model_name,
  :provisioned_model_arn,
  :model_arn,
  :desired_model_arn,
  :foundation_model_arn,
  :status,
  :creation_time,
  :last_modified_time,
  :failure_message,
  :commitment_duration,
  :commitment_expiration_time)
  SENSITIVE = []
  include Aws::Structure
end

#commitment_expiration_timeTime

The timestamp for when the commitment term for the Provisioned Throughput expires.

Returns:

  • (Time)


7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
# File 'lib/aws-sdk-bedrock/types.rb', line 7797

class GetProvisionedModelThroughputResponse < Struct.new(
  :model_units,
  :desired_model_units,
  :provisioned_model_name,
  :provisioned_model_arn,
  :model_arn,
  :desired_model_arn,
  :foundation_model_arn,
  :status,
  :creation_time,
  :last_modified_time,
  :failure_message,
  :commitment_duration,
  :commitment_expiration_time)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The timestamp of the creation time for this Provisioned Throughput.

Returns:

  • (Time)


7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
# File 'lib/aws-sdk-bedrock/types.rb', line 7797

class GetProvisionedModelThroughputResponse < Struct.new(
  :model_units,
  :desired_model_units,
  :provisioned_model_name,
  :provisioned_model_arn,
  :model_arn,
  :desired_model_arn,
  :foundation_model_arn,
  :status,
  :creation_time,
  :last_modified_time,
  :failure_message,
  :commitment_duration,
  :commitment_expiration_time)
  SENSITIVE = []
  include Aws::Structure
end

#desired_model_arnString

The Amazon Resource Name (ARN) of the model requested to be associated to this Provisioned Throughput. This value differs from the ‘modelArn` if updating hasn’t completed.

Returns:

  • (String)


7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
# File 'lib/aws-sdk-bedrock/types.rb', line 7797

class GetProvisionedModelThroughputResponse < Struct.new(
  :model_units,
  :desired_model_units,
  :provisioned_model_name,
  :provisioned_model_arn,
  :model_arn,
  :desired_model_arn,
  :foundation_model_arn,
  :status,
  :creation_time,
  :last_modified_time,
  :failure_message,
  :commitment_duration,
  :commitment_expiration_time)
  SENSITIVE = []
  include Aws::Structure
end

#desired_model_unitsInteger

The number of model units that was requested for this Provisioned Throughput.

Returns:

  • (Integer)


7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
# File 'lib/aws-sdk-bedrock/types.rb', line 7797

class GetProvisionedModelThroughputResponse < Struct.new(
  :model_units,
  :desired_model_units,
  :provisioned_model_name,
  :provisioned_model_arn,
  :model_arn,
  :desired_model_arn,
  :foundation_model_arn,
  :status,
  :creation_time,
  :last_modified_time,
  :failure_message,
  :commitment_duration,
  :commitment_expiration_time)
  SENSITIVE = []
  include Aws::Structure
end

#failure_messageString

A failure message for any issues that occurred during creation, updating, or deletion of the Provisioned Throughput.

Returns:

  • (String)


7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
# File 'lib/aws-sdk-bedrock/types.rb', line 7797

class GetProvisionedModelThroughputResponse < Struct.new(
  :model_units,
  :desired_model_units,
  :provisioned_model_name,
  :provisioned_model_arn,
  :model_arn,
  :desired_model_arn,
  :foundation_model_arn,
  :status,
  :creation_time,
  :last_modified_time,
  :failure_message,
  :commitment_duration,
  :commitment_expiration_time)
  SENSITIVE = []
  include Aws::Structure
end

#foundation_model_arnString

The Amazon Resource Name (ARN) of the base model for which the Provisioned Throughput was created, or of the base model that the custom model for which the Provisioned Throughput was created was customized.

Returns:

  • (String)


7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
# File 'lib/aws-sdk-bedrock/types.rb', line 7797

class GetProvisionedModelThroughputResponse < Struct.new(
  :model_units,
  :desired_model_units,
  :provisioned_model_name,
  :provisioned_model_arn,
  :model_arn,
  :desired_model_arn,
  :foundation_model_arn,
  :status,
  :creation_time,
  :last_modified_time,
  :failure_message,
  :commitment_duration,
  :commitment_expiration_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The timestamp of the last time that this Provisioned Throughput was modified.

Returns:

  • (Time)


7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
# File 'lib/aws-sdk-bedrock/types.rb', line 7797

class GetProvisionedModelThroughputResponse < Struct.new(
  :model_units,
  :desired_model_units,
  :provisioned_model_name,
  :provisioned_model_arn,
  :model_arn,
  :desired_model_arn,
  :foundation_model_arn,
  :status,
  :creation_time,
  :last_modified_time,
  :failure_message,
  :commitment_duration,
  :commitment_expiration_time)
  SENSITIVE = []
  include Aws::Structure
end

#model_arnString

The Amazon Resource Name (ARN) of the model associated with this Provisioned Throughput.

Returns:

  • (String)


7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
# File 'lib/aws-sdk-bedrock/types.rb', line 7797

class GetProvisionedModelThroughputResponse < Struct.new(
  :model_units,
  :desired_model_units,
  :provisioned_model_name,
  :provisioned_model_arn,
  :model_arn,
  :desired_model_arn,
  :foundation_model_arn,
  :status,
  :creation_time,
  :last_modified_time,
  :failure_message,
  :commitment_duration,
  :commitment_expiration_time)
  SENSITIVE = []
  include Aws::Structure
end

#model_unitsInteger

The number of model units allocated to this Provisioned Throughput.

Returns:

  • (Integer)


7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
# File 'lib/aws-sdk-bedrock/types.rb', line 7797

class GetProvisionedModelThroughputResponse < Struct.new(
  :model_units,
  :desired_model_units,
  :provisioned_model_name,
  :provisioned_model_arn,
  :model_arn,
  :desired_model_arn,
  :foundation_model_arn,
  :status,
  :creation_time,
  :last_modified_time,
  :failure_message,
  :commitment_duration,
  :commitment_expiration_time)
  SENSITIVE = []
  include Aws::Structure
end

#provisioned_model_arnString

The Amazon Resource Name (ARN) of the Provisioned Throughput.

Returns:

  • (String)


7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
# File 'lib/aws-sdk-bedrock/types.rb', line 7797

class GetProvisionedModelThroughputResponse < Struct.new(
  :model_units,
  :desired_model_units,
  :provisioned_model_name,
  :provisioned_model_arn,
  :model_arn,
  :desired_model_arn,
  :foundation_model_arn,
  :status,
  :creation_time,
  :last_modified_time,
  :failure_message,
  :commitment_duration,
  :commitment_expiration_time)
  SENSITIVE = []
  include Aws::Structure
end

#provisioned_model_nameString

The name of the Provisioned Throughput.

Returns:

  • (String)


7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
# File 'lib/aws-sdk-bedrock/types.rb', line 7797

class GetProvisionedModelThroughputResponse < Struct.new(
  :model_units,
  :desired_model_units,
  :provisioned_model_name,
  :provisioned_model_arn,
  :model_arn,
  :desired_model_arn,
  :foundation_model_arn,
  :status,
  :creation_time,
  :last_modified_time,
  :failure_message,
  :commitment_duration,
  :commitment_expiration_time)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the Provisioned Throughput.

Returns:

  • (String)


7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
# File 'lib/aws-sdk-bedrock/types.rb', line 7797

class GetProvisionedModelThroughputResponse < Struct.new(
  :model_units,
  :desired_model_units,
  :provisioned_model_name,
  :provisioned_model_arn,
  :model_arn,
  :desired_model_arn,
  :foundation_model_arn,
  :status,
  :creation_time,
  :last_modified_time,
  :failure_message,
  :commitment_duration,
  :commitment_expiration_time)
  SENSITIVE = []
  include Aws::Structure
end