Class: Aws::Bedrock::Types::GuardrailContentPolicy
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::GuardrailContentPolicy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Contains details about how to handle harmful content.
This data type is used in the following API operations:
- GetGuardrail response body][1
^
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::GuardrailContentFilter>
Contains the type of the content filter and how strongly it should apply to prompts and model responses.
-
#tier ⇒ Types::GuardrailContentFiltersTier
The tier that your guardrail uses for content filters.
Instance Attribute Details
#filters ⇒ Array<Types::GuardrailContentFilter>
Contains the type of the content filter and how strongly it should apply to prompts and model responses.
8199 8200 8201 8202 8203 8204 |
# File 'lib/aws-sdk-bedrock/types.rb', line 8199 class GuardrailContentPolicy < Struct.new( :filters, :tier) SENSITIVE = [] include Aws::Structure end |
#tier ⇒ Types::GuardrailContentFiltersTier
The tier that your guardrail uses for content filters.
8199 8200 8201 8202 8203 8204 |
# File 'lib/aws-sdk-bedrock/types.rb', line 8199 class GuardrailContentPolicy < Struct.new( :filters, :tier) SENSITIVE = [] include Aws::Structure end |