Class: Aws::Bedrock::Types::GuardrailContentPolicyConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::GuardrailContentPolicyConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Contains details about how to handle harmful content.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters_config ⇒ Array<Types::GuardrailContentFilterConfig>
Contains the type of the content filter and how strongly it should apply to prompts and model responses.
-
#tier_config ⇒ Types::GuardrailContentFiltersTierConfig
The tier that your guardrail uses for content filters.
Instance Attribute Details
#filters_config ⇒ Array<Types::GuardrailContentFilterConfig>
Contains the type of the content filter and how strongly it should apply to prompts and model responses.
8219 8220 8221 8222 8223 8224 |
# File 'lib/aws-sdk-bedrock/types.rb', line 8219 class GuardrailContentPolicyConfig < Struct.new( :filters_config, :tier_config) SENSITIVE = [] include Aws::Structure end |
#tier_config ⇒ Types::GuardrailContentFiltersTierConfig
The tier that your guardrail uses for content filters.
8219 8220 8221 8222 8223 8224 |
# File 'lib/aws-sdk-bedrock/types.rb', line 8219 class GuardrailContentPolicyConfig < Struct.new( :filters_config, :tier_config) SENSITIVE = [] include Aws::Structure end |