Class: Aws::Bedrock::Types::GuardrailCrossRegionConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::GuardrailCrossRegionConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
The system-defined guardrail profile that you’re using with your guardrail. Guardrail profiles define the destination Amazon Web Services Regions where guardrail inference requests can be automatically routed. Using guardrail profiles helps maintain guardrail performance and reliability when demand increases.
For more information, see the [Amazon Bedrock User Guide].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/guardrails-cross-region.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#guardrail_profile_identifier ⇒ String
The ID or Amazon Resource Name (ARN) of the guardrail profile that your guardrail is using.
Instance Attribute Details
#guardrail_profile_identifier ⇒ String
The ID or Amazon Resource Name (ARN) of the guardrail profile that your guardrail is using. Guardrail profile availability depends on your current Amazon Web Services Region. For more information, see the [Amazon Bedrock User Guide].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/guardrails-cross-region-support.html
8452 8453 8454 8455 8456 |
# File 'lib/aws-sdk-bedrock/types.rb', line 8452 class GuardrailCrossRegionConfig < Struct.new( :guardrail_profile_identifier) SENSITIVE = [] include Aws::Structure end |