Class: Aws::Bedrock::Types::GuardrailCrossRegionDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Contains details about the system-defined guardrail profile that you're using with your guardrail for cross-Region inference.

For more information, see the Amazon Bedrock User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#guardrail_profile_arnString

The Amazon Resource Name (ARN) of the guardrail profile that you're using with your guardrail.

Returns:

  • (String)


8508
8509
8510
8511
8512
8513
# File 'lib/aws-sdk-bedrock/types.rb', line 8508

class GuardrailCrossRegionDetails < Struct.new(
  :guardrail_profile_id,
  :guardrail_profile_arn)
  SENSITIVE = []
  include Aws::Structure
end

#guardrail_profile_idString

The ID of the guardrail profile that your guardrail is using. Profile availability depends on your current Amazon Web Services Region. For more information, see the Amazon Bedrock User Guide.

Returns:

  • (String)


8508
8509
8510
8511
8512
8513
# File 'lib/aws-sdk-bedrock/types.rb', line 8508

class GuardrailCrossRegionDetails < Struct.new(
  :guardrail_profile_id,
  :guardrail_profile_arn)
  SENSITIVE = []
  include Aws::Structure
end