Class: Aws::Bedrock::Types::GuardrailManagedWords
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::GuardrailManagedWords
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
The managed word list that was configured for the guardrail. (This is a list of words that are pre-defined and managed by guardrails only.)
Constant Summary collapse
- SENSITIVE =
[:input_action, :output_action]
Instance Attribute Summary collapse
-
#input_action ⇒ String
The action to take when harmful content is detected in the input.
-
#input_enabled ⇒ Boolean
Indicates whether guardrail evaluation is enabled on the input.
-
#output_action ⇒ String
The action to take when harmful content is detected in the output.
-
#output_enabled ⇒ Boolean
Indicates whether guardrail evaluation is enabled on the output.
-
#type ⇒ String
ManagedWords$type The managed word type that was configured for the guardrail.
Instance Attribute Details
#input_action ⇒ String
The action to take when harmful content is detected in the input. Supported values include:
-
‘BLOCK` – Block the content and replace it with blocked messaging.
-
‘NONE` – Take no action but return detection information in the trace response.
8534 8535 8536 8537 8538 8539 8540 8541 8542 |
# File 'lib/aws-sdk-bedrock/types.rb', line 8534 class GuardrailManagedWords < Struct.new( :type, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:input_action, :output_action] include Aws::Structure end |
#input_enabled ⇒ Boolean
Indicates whether guardrail evaluation is enabled on the input. When disabled, you aren’t charged for the evaluation. The evaluation doesn’t appear in the response.
8534 8535 8536 8537 8538 8539 8540 8541 8542 |
# File 'lib/aws-sdk-bedrock/types.rb', line 8534 class GuardrailManagedWords < Struct.new( :type, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:input_action, :output_action] include Aws::Structure end |
#output_action ⇒ String
The action to take when harmful content is detected in the output. Supported values include:
-
‘BLOCK` – Block the content and replace it with blocked messaging.
-
‘NONE` – Take no action but return detection information in the trace response.
8534 8535 8536 8537 8538 8539 8540 8541 8542 |
# File 'lib/aws-sdk-bedrock/types.rb', line 8534 class GuardrailManagedWords < Struct.new( :type, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:input_action, :output_action] include Aws::Structure end |
#output_enabled ⇒ Boolean
Indicates whether guardrail evaluation is enabled on the output. When disabled, you aren’t charged for the evaluation. The evaluation doesn’t appear in the response.
8534 8535 8536 8537 8538 8539 8540 8541 8542 |
# File 'lib/aws-sdk-bedrock/types.rb', line 8534 class GuardrailManagedWords < Struct.new( :type, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:input_action, :output_action] include Aws::Structure end |
#type ⇒ String
ManagedWords$type The managed word type that was configured for the guardrail. (For now, we only offer profanity word list)
8534 8535 8536 8537 8538 8539 8540 8541 8542 |
# File 'lib/aws-sdk-bedrock/types.rb', line 8534 class GuardrailManagedWords < Struct.new( :type, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:input_action, :output_action] include Aws::Structure end |