Class: Aws::Bedrock::Types::GuardrailManagedWordsConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::GuardrailManagedWordsConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
The managed word list to configure for the guardrail.
Constant Summary collapse
- SENSITIVE =
[:input_action, :output_action]
Instance Attribute Summary collapse
-
#input_action ⇒ String
Specifies the action to take when harmful content is detected in the input.
-
#input_enabled ⇒ Boolean
Specifies whether to enable guardrail evaluation on the input.
-
#output_action ⇒ String
Specifies the action to take when harmful content is detected in the output.
-
#output_enabled ⇒ Boolean
Specifies whether to enable guardrail evaluation on the output.
-
#type ⇒ String
The managed word type to configure for the guardrail.
Instance Attribute Details
#input_action ⇒ String
Specifies the action to take when harmful content is detected in the input. Supported values include:
-
‘BLOCK` – Block the content and replace it with blocked messaging.
-
‘NONE` – Take no action but return detection information in the trace response.
8584 8585 8586 8587 8588 8589 8590 8591 8592 |
# File 'lib/aws-sdk-bedrock/types.rb', line 8584 class GuardrailManagedWordsConfig < Struct.new( :type, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:input_action, :output_action] include Aws::Structure end |
#input_enabled ⇒ Boolean
Specifies whether to enable guardrail evaluation on the input. When disabled, you aren’t charged for the evaluation. The evaluation doesn’t appear in the response.
8584 8585 8586 8587 8588 8589 8590 8591 8592 |
# File 'lib/aws-sdk-bedrock/types.rb', line 8584 class GuardrailManagedWordsConfig < Struct.new( :type, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:input_action, :output_action] include Aws::Structure end |
#output_action ⇒ String
Specifies the action to take when harmful content is detected in the output. Supported values include:
-
‘BLOCK` – Block the content and replace it with blocked messaging.
-
‘NONE` – Take no action but return detection information in the trace response.
8584 8585 8586 8587 8588 8589 8590 8591 8592 |
# File 'lib/aws-sdk-bedrock/types.rb', line 8584 class GuardrailManagedWordsConfig < Struct.new( :type, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:input_action, :output_action] include Aws::Structure end |
#output_enabled ⇒ Boolean
Specifies whether to enable guardrail evaluation on the output. When disabled, you aren’t charged for the evaluation. The evaluation doesn’t appear in the response.
8584 8585 8586 8587 8588 8589 8590 8591 8592 |
# File 'lib/aws-sdk-bedrock/types.rb', line 8584 class GuardrailManagedWordsConfig < Struct.new( :type, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:input_action, :output_action] include Aws::Structure end |
#type ⇒ String
The managed word type to configure for the guardrail.
8584 8585 8586 8587 8588 8589 8590 8591 8592 |
# File 'lib/aws-sdk-bedrock/types.rb', line 8584 class GuardrailManagedWordsConfig < Struct.new( :type, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:input_action, :output_action] include Aws::Structure end |