Class: Aws::Bedrock::Types::GuardrailPiiEntity
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::GuardrailPiiEntity
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
The PII entity configured for the guardrail.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The configured guardrail action when PII entity is detected.
-
#input_action ⇒ String
The action to take when harmful content is detected in the input.
-
#input_enabled ⇒ Boolean
Indicates whether guardrail evaluation is enabled on the input.
-
#output_action ⇒ String
The action to take when harmful content is detected in the output.
-
#output_enabled ⇒ Boolean
Indicates whether guardrail evaluation is enabled on the output.
-
#type ⇒ String
The type of PII entity.
Instance Attribute Details
#action ⇒ String
The configured guardrail action when PII entity is detected.
8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 |
# File 'lib/aws-sdk-bedrock/types.rb', line 8613 class GuardrailPiiEntity < Struct.new( :type, :action, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [] include Aws::Structure end |
#input_action ⇒ String
The action to take when harmful content is detected in the input. Supported values include:
-
‘BLOCK` – Block the content and replace it with blocked messaging.
-
‘ANONYMIZE` – Mask the content and replace it with identifier tags.
-
‘NONE` – Take no action but return detection information in the trace response.
8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 |
# File 'lib/aws-sdk-bedrock/types.rb', line 8613 class GuardrailPiiEntity < Struct.new( :type, :action, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [] include Aws::Structure end |
#input_enabled ⇒ Boolean
Indicates whether guardrail evaluation is enabled on the input. When disabled, you aren’t charged for the evaluation. The evaluation doesn’t appear in the response.
8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 |
# File 'lib/aws-sdk-bedrock/types.rb', line 8613 class GuardrailPiiEntity < Struct.new( :type, :action, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [] include Aws::Structure end |
#output_action ⇒ String
The action to take when harmful content is detected in the output. Supported values include:
-
‘BLOCK` – Block the content and replace it with blocked messaging.
-
‘ANONYMIZE` – Mask the content and replace it with identifier tags.
-
‘NONE` – Take no action but return detection information in the trace response.
8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 |
# File 'lib/aws-sdk-bedrock/types.rb', line 8613 class GuardrailPiiEntity < Struct.new( :type, :action, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [] include Aws::Structure end |
#output_enabled ⇒ Boolean
Indicates whether guardrail evaluation is enabled on the output. When disabled, you aren’t charged for the evaluation. The evaluation doesn’t appear in the response.
8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 |
# File 'lib/aws-sdk-bedrock/types.rb', line 8613 class GuardrailPiiEntity < Struct.new( :type, :action, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of PII entity. For example, Social Security Number.
8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 |
# File 'lib/aws-sdk-bedrock/types.rb', line 8613 class GuardrailPiiEntity < Struct.new( :type, :action, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [] include Aws::Structure end |