Class: Aws::Bedrock::Types::GuardrailRegex
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::GuardrailRegex
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
The regular expression configured for the guardrail.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The action taken when a match to the regular expression is detected.
-
#description ⇒ String
The description of the regular expression for the guardrail.
-
#input_action ⇒ String
The action to take when harmful content is detected in the input.
-
#input_enabled ⇒ Boolean
Indicates whether guardrail evaluation is enabled on the input.
-
#name ⇒ String
The name of the regular expression for the guardrail.
-
#output_action ⇒ String
The action to take when harmful content is detected in the output.
-
#output_enabled ⇒ Boolean
Indicates whether guardrail evaluation is enabled on the output.
-
#pattern ⇒ String
The pattern of the regular expression configured for the guardrail.
Instance Attribute Details
#action ⇒ String
The action taken when a match to the regular expression is detected.
9010 9011 9012 9013 9014 9015 9016 9017 9018 9019 9020 9021 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9010 class GuardrailRegex < Struct.new( :name, :description, :pattern, :action, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the regular expression for the guardrail.
9010 9011 9012 9013 9014 9015 9016 9017 9018 9019 9020 9021 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9010 class GuardrailRegex < Struct.new( :name, :description, :pattern, :action, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [] include Aws::Structure end |
#input_action ⇒ String
The action to take when harmful content is detected in the input. Supported values include:
-
‘BLOCK` – Block the content and replace it with blocked messaging.
-
‘NONE` – Take no action but return detection information in the trace response.
9010 9011 9012 9013 9014 9015 9016 9017 9018 9019 9020 9021 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9010 class GuardrailRegex < Struct.new( :name, :description, :pattern, :action, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [] include Aws::Structure end |
#input_enabled ⇒ Boolean
Indicates whether guardrail evaluation is enabled on the input. When disabled, you aren’t charged for the evaluation. The evaluation doesn’t appear in the response.
9010 9011 9012 9013 9014 9015 9016 9017 9018 9019 9020 9021 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9010 class GuardrailRegex < Struct.new( :name, :description, :pattern, :action, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the regular expression for the guardrail.
9010 9011 9012 9013 9014 9015 9016 9017 9018 9019 9020 9021 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9010 class GuardrailRegex < Struct.new( :name, :description, :pattern, :action, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [] include Aws::Structure end |
#output_action ⇒ String
The action to take when harmful content is detected in the output. Supported values include:
-
‘BLOCK` – Block the content and replace it with blocked messaging.
-
‘NONE` – Take no action but return detection information in the trace response.
9010 9011 9012 9013 9014 9015 9016 9017 9018 9019 9020 9021 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9010 class GuardrailRegex < Struct.new( :name, :description, :pattern, :action, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [] include Aws::Structure end |
#output_enabled ⇒ Boolean
Indicates whether guardrail evaluation is enabled on the output. When disabled, you aren’t charged for the evaluation. The evaluation doesn’t appear in the response.
9010 9011 9012 9013 9014 9015 9016 9017 9018 9019 9020 9021 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9010 class GuardrailRegex < Struct.new( :name, :description, :pattern, :action, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [] include Aws::Structure end |
#pattern ⇒ String
The pattern of the regular expression configured for the guardrail.
9010 9011 9012 9013 9014 9015 9016 9017 9018 9019 9020 9021 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9010 class GuardrailRegex < Struct.new( :name, :description, :pattern, :action, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [] include Aws::Structure end |