Class: Aws::Bedrock::Types::GuardrailRegexConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::GuardrailRegexConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
The regular expression to configure for the guardrail.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The guardrail action to configure when matching regular expression is detected.
-
#description ⇒ String
The description of the regular expression to configure for the guardrail.
-
#input_action ⇒ String
Specifies the action to take when harmful content is detected in the input.
-
#input_enabled ⇒ Boolean
Specifies whether to enable guardrail evaluation on the input.
-
#name ⇒ String
The name of the regular expression to configure for the guardrail.
-
#output_action ⇒ String
Specifies the action to take when harmful content is detected in the output.
-
#output_enabled ⇒ Boolean
Specifies whether to enable guardrail evaluation on the output.
-
#pattern ⇒ String
The regular expression pattern to configure for the guardrail.
Instance Attribute Details
#action ⇒ String
The guardrail action to configure when matching regular expression is detected.
9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9077 class GuardrailRegexConfig < Struct.new( :name, :description, :pattern, :action, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the regular expression to configure for the guardrail.
9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9077 class GuardrailRegexConfig < Struct.new( :name, :description, :pattern, :action, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [] include Aws::Structure end |
#input_action ⇒ String
Specifies the action to take when harmful content is detected in the input. Supported values include:
-
‘BLOCK` – Block the content and replace it with blocked messaging.
-
‘NONE` – Take no action but return detection information in the trace response.
9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9077 class GuardrailRegexConfig < Struct.new( :name, :description, :pattern, :action, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [] include Aws::Structure end |
#input_enabled ⇒ Boolean
Specifies whether to enable guardrail evaluation on the input. When disabled, you aren’t charged for the evaluation. The evaluation doesn’t appear in the response.
9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9077 class GuardrailRegexConfig < Struct.new( :name, :description, :pattern, :action, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the regular expression to configure for the guardrail.
9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9077 class GuardrailRegexConfig < Struct.new( :name, :description, :pattern, :action, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [] include Aws::Structure end |
#output_action ⇒ String
Specifies the action to take when harmful content is detected in the output. Supported values include:
-
‘BLOCK` – Block the content and replace it with blocked messaging.
-
‘NONE` – Take no action but return detection information in the trace response.
9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9077 class GuardrailRegexConfig < Struct.new( :name, :description, :pattern, :action, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [] include Aws::Structure end |
#output_enabled ⇒ Boolean
Specifies whether to enable guardrail evaluation on the output. When disabled, you aren’t charged for the evaluation. The evaluation doesn’t appear in the response.
9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9077 class GuardrailRegexConfig < Struct.new( :name, :description, :pattern, :action, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [] include Aws::Structure end |
#pattern ⇒ String
The regular expression pattern to configure for the guardrail.
9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9077 class GuardrailRegexConfig < Struct.new( :name, :description, :pattern, :action, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [] include Aws::Structure end |