Class: Aws::Bedrock::Types::GuardrailSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::GuardrailSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Contains details about a guardrail.
This data type is used in the following API operations:
- ListGuardrails response body][1
^
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the guardrail.
-
#created_at ⇒ Time
The date and time at which the guardrail was created.
-
#cross_region_details ⇒ Types::GuardrailCrossRegionDetails
Details about the system-defined guardrail profile that you’re using with your guardrail, including the guardrail profile ID and Amazon Resource Name (ARN).
-
#description ⇒ String
A description of the guardrail.
-
#id ⇒ String
The unique identifier of the guardrail.
-
#name ⇒ String
The name of the guardrail.
-
#status ⇒ String
The status of the guardrail.
-
#updated_at ⇒ Time
The date and time at which the guardrail was last updated.
-
#version ⇒ String
The version of the guardrail.
Instance Attribute Details
#arn ⇒ String
The ARN of the guardrail.
9182 9183 9184 9185 9186 9187 9188 9189 9190 9191 9192 9193 9194 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9182 class GuardrailSummary < Struct.new( :id, :arn, :status, :name, :description, :version, :created_at, :updated_at, :cross_region_details) SENSITIVE = [:name, :description] include Aws::Structure end |
#created_at ⇒ Time
The date and time at which the guardrail was created.
9182 9183 9184 9185 9186 9187 9188 9189 9190 9191 9192 9193 9194 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9182 class GuardrailSummary < Struct.new( :id, :arn, :status, :name, :description, :version, :created_at, :updated_at, :cross_region_details) SENSITIVE = [:name, :description] include Aws::Structure end |
#cross_region_details ⇒ Types::GuardrailCrossRegionDetails
Details about the system-defined guardrail profile that you’re using with your guardrail, including the guardrail profile ID and Amazon Resource Name (ARN).
9182 9183 9184 9185 9186 9187 9188 9189 9190 9191 9192 9193 9194 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9182 class GuardrailSummary < Struct.new( :id, :arn, :status, :name, :description, :version, :created_at, :updated_at, :cross_region_details) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
A description of the guardrail.
9182 9183 9184 9185 9186 9187 9188 9189 9190 9191 9192 9193 9194 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9182 class GuardrailSummary < Struct.new( :id, :arn, :status, :name, :description, :version, :created_at, :updated_at, :cross_region_details) SENSITIVE = [:name, :description] include Aws::Structure end |
#id ⇒ String
The unique identifier of the guardrail.
9182 9183 9184 9185 9186 9187 9188 9189 9190 9191 9192 9193 9194 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9182 class GuardrailSummary < Struct.new( :id, :arn, :status, :name, :description, :version, :created_at, :updated_at, :cross_region_details) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of the guardrail.
9182 9183 9184 9185 9186 9187 9188 9189 9190 9191 9192 9193 9194 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9182 class GuardrailSummary < Struct.new( :id, :arn, :status, :name, :description, :version, :created_at, :updated_at, :cross_region_details) SENSITIVE = [:name, :description] include Aws::Structure end |
#status ⇒ String
The status of the guardrail.
9182 9183 9184 9185 9186 9187 9188 9189 9190 9191 9192 9193 9194 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9182 class GuardrailSummary < Struct.new( :id, :arn, :status, :name, :description, :version, :created_at, :updated_at, :cross_region_details) SENSITIVE = [:name, :description] include Aws::Structure end |
#updated_at ⇒ Time
The date and time at which the guardrail was last updated.
9182 9183 9184 9185 9186 9187 9188 9189 9190 9191 9192 9193 9194 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9182 class GuardrailSummary < Struct.new( :id, :arn, :status, :name, :description, :version, :created_at, :updated_at, :cross_region_details) SENSITIVE = [:name, :description] include Aws::Structure end |
#version ⇒ String
The version of the guardrail.
9182 9183 9184 9185 9186 9187 9188 9189 9190 9191 9192 9193 9194 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9182 class GuardrailSummary < Struct.new( :id, :arn, :status, :name, :description, :version, :created_at, :updated_at, :cross_region_details) SENSITIVE = [:name, :description] include Aws::Structure end |