Class: Aws::Bedrock::Types::GuardrailTopicConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::GuardrailTopicConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Details about topics for the guardrail to identify and deny.
Constant Summary collapse
- SENSITIVE =
[:name, :definition, :examples, :input_action, :output_action]
Instance Attribute Summary collapse
-
#definition ⇒ String
A definition of the topic to deny.
-
#examples ⇒ Array<String>
A list of prompts, each of which is an example of a prompt that can be categorized as belonging to the topic.
-
#input_action ⇒ String
Specifies the action to take when harmful content is detected in the input.
-
#input_enabled ⇒ Boolean
Specifies whether to enable guardrail evaluation on the input.
-
#name ⇒ String
The name of the topic to deny.
-
#output_action ⇒ String
Specifies the action to take when harmful content is detected in the output.
-
#output_enabled ⇒ Boolean
Specifies whether to enable guardrail evaluation on the output.
-
#type ⇒ String
Specifies to deny the topic.
Instance Attribute Details
#definition ⇒ String
A definition of the topic to deny.
9325 9326 9327 9328 9329 9330 9331 9332 9333 9334 9335 9336 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9325 class GuardrailTopicConfig < Struct.new( :name, :definition, :examples, :type, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:name, :definition, :examples, :input_action, :output_action] include Aws::Structure end |
#examples ⇒ Array<String>
A list of prompts, each of which is an example of a prompt that can be categorized as belonging to the topic.
9325 9326 9327 9328 9329 9330 9331 9332 9333 9334 9335 9336 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9325 class GuardrailTopicConfig < Struct.new( :name, :definition, :examples, :type, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:name, :definition, :examples, :input_action, :output_action] include Aws::Structure end |
#input_action ⇒ String
Specifies the action to take when harmful content is detected in the input. Supported values include:
-
‘BLOCK` – Block the content and replace it with blocked messaging.
-
‘NONE` – Take no action but return detection information in the trace response.
9325 9326 9327 9328 9329 9330 9331 9332 9333 9334 9335 9336 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9325 class GuardrailTopicConfig < Struct.new( :name, :definition, :examples, :type, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:name, :definition, :examples, :input_action, :output_action] include Aws::Structure end |
#input_enabled ⇒ Boolean
Specifies whether to enable guardrail evaluation on the input. When disabled, you aren’t charged for the evaluation. The evaluation doesn’t appear in the response.
9325 9326 9327 9328 9329 9330 9331 9332 9333 9334 9335 9336 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9325 class GuardrailTopicConfig < Struct.new( :name, :definition, :examples, :type, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:name, :definition, :examples, :input_action, :output_action] include Aws::Structure end |
#name ⇒ String
The name of the topic to deny.
9325 9326 9327 9328 9329 9330 9331 9332 9333 9334 9335 9336 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9325 class GuardrailTopicConfig < Struct.new( :name, :definition, :examples, :type, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:name, :definition, :examples, :input_action, :output_action] include Aws::Structure end |
#output_action ⇒ String
Specifies the action to take when harmful content is detected in the output. Supported values include:
-
‘BLOCK` – Block the content and replace it with blocked messaging.
-
‘NONE` – Take no action but return detection information in the trace response.
9325 9326 9327 9328 9329 9330 9331 9332 9333 9334 9335 9336 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9325 class GuardrailTopicConfig < Struct.new( :name, :definition, :examples, :type, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:name, :definition, :examples, :input_action, :output_action] include Aws::Structure end |
#output_enabled ⇒ Boolean
Specifies whether to enable guardrail evaluation on the output. When disabled, you aren’t charged for the evaluation. The evaluation doesn’t appear in the response.
9325 9326 9327 9328 9329 9330 9331 9332 9333 9334 9335 9336 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9325 class GuardrailTopicConfig < Struct.new( :name, :definition, :examples, :type, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:name, :definition, :examples, :input_action, :output_action] include Aws::Structure end |
#type ⇒ String
Specifies to deny the topic.
9325 9326 9327 9328 9329 9330 9331 9332 9333 9334 9335 9336 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9325 class GuardrailTopicConfig < Struct.new( :name, :definition, :examples, :type, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:name, :definition, :examples, :input_action, :output_action] include Aws::Structure end |