Class: Aws::Bedrock::Types::GuardrailTopicPolicyConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Contains details about topics that the guardrail should identify and deny.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#tier_configTypes::GuardrailTopicsTierConfig

The tier that your guardrail uses for denied topic filters.



9358
9359
9360
9361
9362
9363
# File 'lib/aws-sdk-bedrock/types.rb', line 9358

class GuardrailTopicPolicyConfig < Struct.new(
  :topics_config,
  :tier_config)
  SENSITIVE = []
  include Aws::Structure
end

#topics_configArray<Types::GuardrailTopicConfig>

A list of policies related to topics that the guardrail should deny.

Returns:



9358
9359
9360
9361
9362
9363
# File 'lib/aws-sdk-bedrock/types.rb', line 9358

class GuardrailTopicPolicyConfig < Struct.new(
  :topics_config,
  :tier_config)
  SENSITIVE = []
  include Aws::Structure
end