Class: Aws::Bedrock::Types::GuardrailWordConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::GuardrailWordConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
A word to configure for the guardrail.
Constant Summary collapse
- SENSITIVE =
[:input_action, :output_action]
Instance Attribute Summary collapse
-
#input_action ⇒ String
Specifies the action to take when harmful content is detected in the input.
-
#input_enabled ⇒ Boolean
Specifies whether to enable guardrail evaluation on the intput.
-
#output_action ⇒ String
Specifies the action to take when harmful content is detected in the output.
-
#output_enabled ⇒ Boolean
Specifies whether to enable guardrail evaluation on the output.
-
#text ⇒ String
Text of the word configured for the guardrail to block.
Instance Attribute Details
#input_action ⇒ String
Specifies the action to take when harmful content is detected in the input. Supported values include:
-
‘BLOCK` – Block the content and replace it with blocked messaging.
-
‘NONE` – Take no action but return detection information in the trace response.
9416 9417 9418 9419 9420 9421 9422 9423 9424 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9416 class GuardrailWordConfig < Struct.new( :text, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:input_action, :output_action] include Aws::Structure end |
#input_enabled ⇒ Boolean
Specifies whether to enable guardrail evaluation on the intput. When disabled, you aren’t charged for the evaluation. The evaluation doesn’t appear in the response.
9416 9417 9418 9419 9420 9421 9422 9423 9424 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9416 class GuardrailWordConfig < Struct.new( :text, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:input_action, :output_action] include Aws::Structure end |
#output_action ⇒ String
Specifies the action to take when harmful content is detected in the output. Supported values include:
-
‘BLOCK` – Block the content and replace it with blocked messaging.
-
‘NONE` – Take no action but return detection information in the trace response.
9416 9417 9418 9419 9420 9421 9422 9423 9424 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9416 class GuardrailWordConfig < Struct.new( :text, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:input_action, :output_action] include Aws::Structure end |
#output_enabled ⇒ Boolean
Specifies whether to enable guardrail evaluation on the output. When disabled, you aren’t charged for the evaluation. The evaluation doesn’t appear in the response.
9416 9417 9418 9419 9420 9421 9422 9423 9424 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9416 class GuardrailWordConfig < Struct.new( :text, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:input_action, :output_action] include Aws::Structure end |
#text ⇒ String
Text of the word configured for the guardrail to block.
9416 9417 9418 9419 9420 9421 9422 9423 9424 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9416 class GuardrailWordConfig < Struct.new( :text, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:input_action, :output_action] include Aws::Structure end |