Class: Aws::Bedrock::Types::HumanEvaluationCustomMetric

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

In a model evaluation job that uses human workers you must define the name of the metric, and how you want that metric rated ratingMethod, and an optional description of the metric.

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

An optional description of the metric. Use this parameter to provide more details about the metric.

Returns:

  • (String)


9649
9650
9651
9652
9653
9654
9655
# File 'lib/aws-sdk-bedrock/types.rb', line 9649

class HumanEvaluationCustomMetric < Struct.new(
  :name,
  :description,
  :rating_method)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#nameString

The name of the metric. Your human evaluators will see this name in the evaluation UI.

Returns:

  • (String)


9649
9650
9651
9652
9653
9654
9655
# File 'lib/aws-sdk-bedrock/types.rb', line 9649

class HumanEvaluationCustomMetric < Struct.new(
  :name,
  :description,
  :rating_method)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#rating_methodString

Choose how you want your human workers to evaluation your model. Valid values for rating methods are ThumbsUpDown, IndividualLikertScale,ComparisonLikertScale, ComparisonChoice, and ComparisonRank

Returns:

  • (String)


9649
9650
9651
9652
9653
9654
9655
# File 'lib/aws-sdk-bedrock/types.rb', line 9649

class HumanEvaluationCustomMetric < Struct.new(
  :name,
  :description,
  :rating_method)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end