Class: Aws::Bedrock::Types::InferenceProfileModelSource

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Note:

InferenceProfileModelSource is a union - when making an API calls you must set exactly one of the members.

Contains information about the model or system-defined inference profile that is the source for an inference profile..

Direct Known Subclasses

CopyFrom, Unknown

Defined Under Namespace

Classes: CopyFrom, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#copy_fromString

The ARN of the model or system-defined inference profile that is the source for the inference profile.

Returns:

  • (String)


9676
9677
9678
9679
9680
9681
9682
9683
9684
9685
# File 'lib/aws-sdk-bedrock/types.rb', line 9676

class InferenceProfileModelSource < Struct.new(
  :copy_from,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CopyFrom < InferenceProfileModelSource; end
  class Unknown < InferenceProfileModelSource; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



9676
9677
9678
# File 'lib/aws-sdk-bedrock/types.rb', line 9676

def unknown
  @unknown
end