Class: Aws::Bedrock::Types::InvocationLogsConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Settings for using invocation logs to customize a model.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#invocation_log_sourceTypes::InvocationLogSource

The source of the invocation logs.



9880
9881
9882
9883
9884
9885
9886
# File 'lib/aws-sdk-bedrock/types.rb', line 9880

class InvocationLogsConfig < Struct.new(
  :use_prompt_response,
  :invocation_log_source,
  :request_metadata_filters)
  SENSITIVE = []
  include Aws::Structure
end

#request_metadata_filtersTypes::RequestMetadataFilters

Rules for filtering invocation logs based on request metadata.



9880
9881
9882
9883
9884
9885
9886
# File 'lib/aws-sdk-bedrock/types.rb', line 9880

class InvocationLogsConfig < Struct.new(
  :use_prompt_response,
  :invocation_log_source,
  :request_metadata_filters)
  SENSITIVE = []
  include Aws::Structure
end

#use_prompt_responseBoolean

Whether to use the model’s response for training, or just the prompt. The default value is ‘False`.

Returns:

  • (Boolean)


9880
9881
9882
9883
9884
9885
9886
# File 'lib/aws-sdk-bedrock/types.rb', line 9880

class InvocationLogsConfig < Struct.new(
  :use_prompt_response,
  :invocation_log_source,
  :request_metadata_filters)
  SENSITIVE = []
  include Aws::Structure
end