Class: Aws::Bedrock::Types::LambdaGraderConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Configuration for using an AWS Lambda function to grade model responses during reinforcement fine-tuning training.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#lambda_arnString

ARN of the AWS Lambda function that will evaluate model responses and return reward scores for RFT training.

Returns:

  • (String)


9976
9977
9978
9979
9980
# File 'lib/aws-sdk-bedrock/types.rb', line 9976

class LambdaGraderConfig < Struct.new(
  :lambda_arn)
  SENSITIVE = []
  include Aws::Structure
end