Class: Aws::Bedrock::Types::MetadataConfigurationForReranking

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Configuration for how metadata should be used during the reranking process in Knowledge Base vector searches. This determines which metadata fields are included or excluded when reordering search results.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#selection_modeString

The mode for selecting which metadata fields to include in the reranking process. Valid values are ALL (use all available metadata fields) or SELECTIVE (use only specified fields).

Returns:

  • (String)


11628
11629
11630
11631
11632
11633
# File 'lib/aws-sdk-bedrock/types.rb', line 11628

class MetadataConfigurationForReranking < Struct.new(
  :selection_mode,
  :selective_mode_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#selective_mode_configurationTypes::RerankingMetadataSelectiveModeConfiguration

Configuration for selective mode, which allows you to explicitly include or exclude specific metadata fields during reranking. This is only used when selectionMode is set to SELECTIVE.



11628
11629
11630
11631
11632
11633
# File 'lib/aws-sdk-bedrock/types.rb', line 11628

class MetadataConfigurationForReranking < Struct.new(
  :selection_mode,
  :selective_mode_configuration)
  SENSITIVE = []
  include Aws::Structure
end