Class: Aws::Bedrock::Types::ModelInvocationJobInputDataConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::ModelInvocationJobInputDataConfig
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Note:
ModelInvocationJobInputDataConfig is a union - when making an API calls you must set exactly one of the members.
Note:
ModelInvocationJobInputDataConfig is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ModelInvocationJobInputDataConfig corresponding to the set member.
Details about the location of the input to the batch inference job.
Direct Known Subclasses
Defined Under Namespace
Classes: S3InputDataConfig, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#s3_input_data_config ⇒ Types::ModelInvocationJobS3InputDataConfig
Contains the configuration of the S3 location of the input data.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#s3_input_data_config ⇒ Types::ModelInvocationJobS3InputDataConfig
Contains the configuration of the S3 location of the input data.
11798 11799 11800 11801 11802 11803 11804 11805 11806 11807 |
# File 'lib/aws-sdk-bedrock/types.rb', line 11798 class ModelInvocationJobInputDataConfig < Struct.new( :s3_input_data_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class S3InputDataConfig < ModelInvocationJobInputDataConfig; end class Unknown < ModelInvocationJobInputDataConfig; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
11798 11799 11800 |
# File 'lib/aws-sdk-bedrock/types.rb', line 11798 def unknown @unknown end |