Class: Aws::Bedrock::Types::PutAccountDataRetentionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::PutAccountDataRetentionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#mode ⇒ String
The data retention mode set for the account.
-
#updated_at ⇒ Time
The time at which the data retention mode was last updated.
Instance Attribute Details
#mode ⇒ String
The data retention mode set for the account.
12517 12518 12519 12520 12521 12522 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12517 class PutAccountDataRetentionResponse < Struct.new( :mode, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The time at which the data retention mode was last updated.
12517 12518 12519 12520 12521 12522 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12517 class PutAccountDataRetentionResponse < Struct.new( :mode, :updated_at) SENSITIVE = [] include Aws::Structure end |