Class: Aws::Bedrock::Types::PutResourcePolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::PutResourcePolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
The ARN of the Bedrock resource to which this resource policy applies.
-
#resource_policy ⇒ String
The JSON string representing the Bedrock resource policy.
Instance Attribute Details
#resource_arn ⇒ String
The ARN of the Bedrock resource to which this resource policy applies.
12402 12403 12404 12405 12406 12407 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12402 class PutResourcePolicyRequest < Struct.new( :resource_arn, :resource_policy) SENSITIVE = [] include Aws::Structure end |
#resource_policy ⇒ String
The JSON string representing the Bedrock resource policy.
12402 12403 12404 12405 12406 12407 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12402 class PutResourcePolicyRequest < Struct.new( :resource_arn, :resource_policy) SENSITIVE = [] include Aws::Structure end |