Class: Aws::Bedrock::Types::PutResourcePolicyResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::PutResourcePolicyResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
The ARN of the Bedrock resource to which this resource policy applies.
Instance Attribute Details
#resource_arn ⇒ String
The ARN of the Bedrock resource to which this resource policy applies.
12416 12417 12418 12419 12420 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12416 class PutResourcePolicyResponse < Struct.new( :resource_arn) SENSITIVE = [] include Aws::Structure end |