Class: Aws::Bedrock::Types::RFTHyperParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::RFTHyperParameters
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Hyperparameters for controlling the reinforcement fine-tuning training process, including learning settings and evaluation intervals.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#batch_size ⇒ Integer
Number of training samples processed in each batch during reinforcement fine-tuning (RFT) training.
-
#epoch_count ⇒ Integer
Number of training epochs to run during reinforcement fine-tuning.
-
#eval_interval ⇒ Integer
Interval between evaluation runs during RFT training, measured in training steps.
-
#inference_max_tokens ⇒ Integer
Maximum number of tokens the model can generate in response to each prompt during RFT training.
-
#learning_rate ⇒ Float
Learning rate for the reinforcement fine-tuning.
-
#max_prompt_length ⇒ Integer
Maximum length of input prompts during RFT training, measured in tokens.
-
#reasoning_effort ⇒ String
Level of reasoning effort applied during RFT training.
-
#training_sample_per_prompt ⇒ Integer
Number of response samples generated per prompt during RFT training.
Instance Attribute Details
#batch_size ⇒ Integer
Number of training samples processed in each batch during reinforcement fine-tuning (RFT) training. Larger batches may improve training stability.
12553 12554 12555 12556 12557 12558 12559 12560 12561 12562 12563 12564 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12553 class RFTHyperParameters < Struct.new( :epoch_count, :batch_size, :learning_rate, :max_prompt_length, :training_sample_per_prompt, :inference_max_tokens, :reasoning_effort, :eval_interval) SENSITIVE = [] include Aws::Structure end |
#epoch_count ⇒ Integer
Number of training epochs to run during reinforcement fine-tuning. Higher values may improve performance but increase training time.
12553 12554 12555 12556 12557 12558 12559 12560 12561 12562 12563 12564 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12553 class RFTHyperParameters < Struct.new( :epoch_count, :batch_size, :learning_rate, :max_prompt_length, :training_sample_per_prompt, :inference_max_tokens, :reasoning_effort, :eval_interval) SENSITIVE = [] include Aws::Structure end |
#eval_interval ⇒ Integer
Interval between evaluation runs during RFT training, measured in training steps. More frequent evaluation provides better monitoring.
12553 12554 12555 12556 12557 12558 12559 12560 12561 12562 12563 12564 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12553 class RFTHyperParameters < Struct.new( :epoch_count, :batch_size, :learning_rate, :max_prompt_length, :training_sample_per_prompt, :inference_max_tokens, :reasoning_effort, :eval_interval) SENSITIVE = [] include Aws::Structure end |
#inference_max_tokens ⇒ Integer
Maximum number of tokens the model can generate in response to each prompt during RFT training.
12553 12554 12555 12556 12557 12558 12559 12560 12561 12562 12563 12564 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12553 class RFTHyperParameters < Struct.new( :epoch_count, :batch_size, :learning_rate, :max_prompt_length, :training_sample_per_prompt, :inference_max_tokens, :reasoning_effort, :eval_interval) SENSITIVE = [] include Aws::Structure end |
#learning_rate ⇒ Float
Learning rate for the reinforcement fine-tuning. Controls how quickly the model adapts to reward signals.
12553 12554 12555 12556 12557 12558 12559 12560 12561 12562 12563 12564 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12553 class RFTHyperParameters < Struct.new( :epoch_count, :batch_size, :learning_rate, :max_prompt_length, :training_sample_per_prompt, :inference_max_tokens, :reasoning_effort, :eval_interval) SENSITIVE = [] include Aws::Structure end |
#max_prompt_length ⇒ Integer
Maximum length of input prompts during RFT training, measured in tokens. Longer prompts allow more context but increase memory usage and training-time.
12553 12554 12555 12556 12557 12558 12559 12560 12561 12562 12563 12564 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12553 class RFTHyperParameters < Struct.new( :epoch_count, :batch_size, :learning_rate, :max_prompt_length, :training_sample_per_prompt, :inference_max_tokens, :reasoning_effort, :eval_interval) SENSITIVE = [] include Aws::Structure end |
#reasoning_effort ⇒ String
Level of reasoning effort applied during RFT training. Higher values may improve response quality but increase training time.
12553 12554 12555 12556 12557 12558 12559 12560 12561 12562 12563 12564 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12553 class RFTHyperParameters < Struct.new( :epoch_count, :batch_size, :learning_rate, :max_prompt_length, :training_sample_per_prompt, :inference_max_tokens, :reasoning_effort, :eval_interval) SENSITIVE = [] include Aws::Structure end |
#training_sample_per_prompt ⇒ Integer
Number of response samples generated per prompt during RFT training. More samples provide better reward signal estimation.
12553 12554 12555 12556 12557 12558 12559 12560 12561 12562 12563 12564 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12553 class RFTHyperParameters < Struct.new( :epoch_count, :batch_size, :learning_rate, :max_prompt_length, :training_sample_per_prompt, :inference_max_tokens, :reasoning_effort, :eval_interval) SENSITIVE = [] include Aws::Structure end |