Class: Aws::Bedrock::Types::RatingScaleItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Defines the value and corresponding definition for one rating in a custom metric rating scale.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#definitionString

Defines the definition for one rating in a custom metric rating scale.

Returns:

  • (String)


12716
12717
12718
12719
12720
12721
# File 'lib/aws-sdk-bedrock/types.rb', line 12716

class RatingScaleItem < Struct.new(
  :definition,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueTypes::RatingScaleItemValue

Defines the value for one rating in a custom metric rating scale.



12716
12717
12718
12719
12720
12721
# File 'lib/aws-sdk-bedrock/types.rb', line 12716

class RatingScaleItem < Struct.new(
  :definition,
  :value)
  SENSITIVE = []
  include Aws::Structure
end