Class: Aws::Bedrock::Types::RerankingMetadataSelectiveModeConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Note:

RerankingMetadataSelectiveModeConfiguration is a union - when making an API calls you must set exactly one of the members.

Note:

RerankingMetadataSelectiveModeConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of RerankingMetadataSelectiveModeConfiguration corresponding to the set member.

Configuration for selectively including or excluding metadata fields during the reranking process. This allows you to control which metadata attributes are considered when reordering search results.

Defined Under Namespace

Classes: FieldsToExclude, FieldsToInclude, Unknown

Constant Summary collapse

SENSITIVE =
[:fields_to_include, :fields_to_exclude]

Instance Attribute Summary collapse

Instance Attribute Details

#fields_to_excludeArray<Types::FieldForReranking>

A list of metadata field names to explicitly exclude from the reranking process. All metadata fields except these will be considered when reordering search results. This parameter cannot be used together with fieldsToInclude.

Returns:



12943
12944
12945
12946
12947
12948
12949
12950
12951
12952
12953
12954
# File 'lib/aws-sdk-bedrock/types.rb', line 12943

class RerankingMetadataSelectiveModeConfiguration < Struct.new(
  :fields_to_include,
  :fields_to_exclude,
  :unknown)
  SENSITIVE = [:fields_to_include, :fields_to_exclude]
  include Aws::Structure
  include Aws::Structure::Union

  class FieldsToInclude < RerankingMetadataSelectiveModeConfiguration; end
  class FieldsToExclude < RerankingMetadataSelectiveModeConfiguration; end
  class Unknown < RerankingMetadataSelectiveModeConfiguration; end
end

#fields_to_includeArray<Types::FieldForReranking>

A list of metadata field names to explicitly include in the reranking process. Only these fields will be considered when reordering search results. This parameter cannot be used together with fieldsToExclude.

Returns:



12943
12944
12945
12946
12947
12948
12949
12950
12951
12952
12953
12954
# File 'lib/aws-sdk-bedrock/types.rb', line 12943

class RerankingMetadataSelectiveModeConfiguration < Struct.new(
  :fields_to_include,
  :fields_to_exclude,
  :unknown)
  SENSITIVE = [:fields_to_include, :fields_to_exclude]
  include Aws::Structure
  include Aws::Structure::Union

  class FieldsToInclude < RerankingMetadataSelectiveModeConfiguration; end
  class FieldsToExclude < RerankingMetadataSelectiveModeConfiguration; end
  class Unknown < RerankingMetadataSelectiveModeConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



12943
12944
12945
# File 'lib/aws-sdk-bedrock/types.rb', line 12943

def unknown
  @unknown
end