Class: Aws::Bedrock::Types::ResourceInUseException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Thrown when attempting to delete or modify a resource that is currently being used by other resources or operations. For example, trying to delete an Automated Reasoning policy that is referenced by an active guardrail.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


12865
12866
12867
12868
12869
# File 'lib/aws-sdk-bedrock/types.rb', line 12865

class ResourceInUseException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end