Class: Aws::Bedrock::Types::UpdateAutomatedReasoningPolicyAnnotationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::UpdateAutomatedReasoningPolicyAnnotationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#annotation_set_hash ⇒ String
The new hash value representing the updated state of the annotations.
-
#build_workflow_id ⇒ String
The unique identifier of the build workflow.
-
#policy_arn ⇒ String
The Amazon Resource Name (ARN) of the Automated Reasoning policy.
-
#updated_at ⇒ Time
The timestamp when the annotations were updated.
Instance Attribute Details
#annotation_set_hash ⇒ String
The new hash value representing the updated state of the annotations.
13673 13674 13675 13676 13677 13678 13679 13680 |
# File 'lib/aws-sdk-bedrock/types.rb', line 13673 class UpdateAutomatedReasoningPolicyAnnotationsResponse < Struct.new( :policy_arn, :build_workflow_id, :annotation_set_hash, :updated_at) SENSITIVE = [] include Aws::Structure end |
#build_workflow_id ⇒ String
The unique identifier of the build workflow.
13673 13674 13675 13676 13677 13678 13679 13680 |
# File 'lib/aws-sdk-bedrock/types.rb', line 13673 class UpdateAutomatedReasoningPolicyAnnotationsResponse < Struct.new( :policy_arn, :build_workflow_id, :annotation_set_hash, :updated_at) SENSITIVE = [] include Aws::Structure end |
#policy_arn ⇒ String
The Amazon Resource Name (ARN) of the Automated Reasoning policy.
13673 13674 13675 13676 13677 13678 13679 13680 |
# File 'lib/aws-sdk-bedrock/types.rb', line 13673 class UpdateAutomatedReasoningPolicyAnnotationsResponse < Struct.new( :policy_arn, :build_workflow_id, :annotation_set_hash, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the annotations were updated.
13673 13674 13675 13676 13677 13678 13679 13680 |
# File 'lib/aws-sdk-bedrock/types.rb', line 13673 class UpdateAutomatedReasoningPolicyAnnotationsResponse < Struct.new( :policy_arn, :build_workflow_id, :annotation_set_hash, :updated_at) SENSITIVE = [] include Aws::Structure end |