Class: Aws::Bedrock::Types::VectorSearchBedrockRerankingConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Configuration for using Amazon Bedrock foundation models to rerank Knowledge Base vector search results. This enables more sophisticated relevance ranking using large language models.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#metadata_configurationTypes::MetadataConfigurationForReranking

Configuration for how document metadata should be used during the reranking process. This determines which metadata fields are included when reordering search results.



14290
14291
14292
14293
14294
14295
14296
# File 'lib/aws-sdk-bedrock/types.rb', line 14290

class VectorSearchBedrockRerankingConfiguration < Struct.new(
  :model_configuration,
  :number_of_reranked_results,
  :metadata_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#model_configurationTypes::VectorSearchBedrockRerankingModelConfiguration

Configuration for the Amazon Bedrock foundation model used for reranking. This includes the model ARN and any additional request fields required by the model.



14290
14291
14292
14293
14294
14295
14296
# File 'lib/aws-sdk-bedrock/types.rb', line 14290

class VectorSearchBedrockRerankingConfiguration < Struct.new(
  :model_configuration,
  :number_of_reranked_results,
  :metadata_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_reranked_resultsInteger

The maximum number of results to rerank. This limits how many of the initial vector search results will be processed by the reranking model. A smaller number improves performance but may exclude potentially relevant results.

Returns:

  • (Integer)


14290
14291
14292
14293
14294
14295
14296
# File 'lib/aws-sdk-bedrock/types.rb', line 14290

class VectorSearchBedrockRerankingConfiguration < Struct.new(
  :model_configuration,
  :number_of_reranked_results,
  :metadata_configuration)
  SENSITIVE = []
  include Aws::Structure
end