Class: Aws::Bedrock::Types::AutomatedReasoningPolicyAnnotatedChunk
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::AutomatedReasoningPolicyAnnotatedChunk
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Represents a portion of a source document with line number annotations. Chunks help organize document content for easier navigation and reference.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content ⇒ Array<Types::AutomatedReasoningPolicyAnnotatedContent>
The lines of text contained within this chunk, each annotated with its line number.
-
#page_number ⇒ Integer
The page number where this chunk begins, if the document is divided into pages.
Instance Attribute Details
#content ⇒ Array<Types::AutomatedReasoningPolicyAnnotatedContent>
The lines of text contained within this chunk, each annotated with its line number.
857 858 859 860 861 862 |
# File 'lib/aws-sdk-bedrock/types.rb', line 857 class AutomatedReasoningPolicyAnnotatedChunk < Struct.new( :page_number, :content) SENSITIVE = [] include Aws::Structure end |
#page_number ⇒ Integer
The page number where this chunk begins, if the document is divided into pages.
857 858 859 860 861 862 |
# File 'lib/aws-sdk-bedrock/types.rb', line 857 class AutomatedReasoningPolicyAnnotatedChunk < Struct.new( :page_number, :content) SENSITIVE = [] include Aws::Structure end |