Class: Aws::Bedrock::Types::AutomatedReasoningPolicyGenerateFidelityReportContent
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::AutomatedReasoningPolicyGenerateFidelityReportContent
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Note:
AutomatedReasoningPolicyGenerateFidelityReportContent is a union - when making an API calls you must set exactly one of the members.
Configuration for generating a fidelity report, which can either analyze new documents or update an existing fidelity report with a new policy definition.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#documents ⇒ Array<Types::AutomatedReasoningPolicyBuildWorkflowDocument>
Source documents to analyze for generating a new fidelity report.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#documents ⇒ Array<Types::AutomatedReasoningPolicyBuildWorkflowDocument>
Source documents to analyze for generating a new fidelity report. The documents will be processed to create atomic statements and grounding information.
1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 |
# File 'lib/aws-sdk-bedrock/types.rb', line 1860 class AutomatedReasoningPolicyGenerateFidelityReportContent < Struct.new( :documents, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Documents < AutomatedReasoningPolicyGenerateFidelityReportContent; end class Unknown < AutomatedReasoningPolicyGenerateFidelityReportContent; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1860 1861 1862 |
# File 'lib/aws-sdk-bedrock/types.rb', line 1860 def unknown @unknown end |