Class: Aws::Bedrock::Types::AutomatedReasoningPolicyGenerateFidelityReportContent

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Note:

AutomatedReasoningPolicyGenerateFidelityReportContent is a union - when making an API calls you must set exactly one of the members.

Configuration for generating a fidelity report, which can either analyze new documents or update an existing fidelity report with a new policy definition.

Direct Known Subclasses

Documents, Unknown

Defined Under Namespace

Classes: Documents, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#documentsArray<Types::AutomatedReasoningPolicyBuildWorkflowDocument>

Source documents to analyze for generating a new fidelity report. The documents will be processed to create atomic statements and grounding information.



1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
# File 'lib/aws-sdk-bedrock/types.rb', line 1798

class AutomatedReasoningPolicyGenerateFidelityReportContent < Struct.new(
  :documents,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Documents < AutomatedReasoningPolicyGenerateFidelityReportContent; end
  class Unknown < AutomatedReasoningPolicyGenerateFidelityReportContent; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



1798
1799
1800
# File 'lib/aws-sdk-bedrock/types.rb', line 1798

def unknown
  @unknown
end