Class: Aws::Bedrock::Types::AutomatedReasoningPolicyRuleReport
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::AutomatedReasoningPolicyRuleReport
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Provides detailed fidelity analysis for a specific policy rule, including which source document statements support it and how accurate the rule is.
Constant Summary collapse
- SENSITIVE =
[:grounding_justifications, :accuracy_justification]
Instance Attribute Summary collapse
-
#accuracy_justification ⇒ String
A textual explanation of the accuracy score, describing why the rule received this particular accuracy rating.
-
#accuracy_score ⇒ Float
A score from 0.0 to 1.0 indicating how accurately this rule represents the source material.
-
#grounding_justifications ⇒ Array<String>
Explanations describing how the source statements support and justify this specific rule.
-
#grounding_statements ⇒ Array<Types::AutomatedReasoningPolicyStatementReference>
References to statements from the source documents that provide the basis or justification for this rule.
-
#rule ⇒ String
The identifier of the policy rule being analyzed in this report.
Instance Attribute Details
#accuracy_justification ⇒ String
A textual explanation of the accuracy score, describing why the rule received this particular accuracy rating.
2101 2102 2103 2104 2105 2106 2107 2108 2109 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2101 class AutomatedReasoningPolicyRuleReport < Struct.new( :rule, :grounding_statements, :grounding_justifications, :accuracy_score, :accuracy_justification) SENSITIVE = [:grounding_justifications, :accuracy_justification] include Aws::Structure end |
#accuracy_score ⇒ Float
A score from 0.0 to 1.0 indicating how accurately this rule represents the source material.
2101 2102 2103 2104 2105 2106 2107 2108 2109 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2101 class AutomatedReasoningPolicyRuleReport < Struct.new( :rule, :grounding_statements, :grounding_justifications, :accuracy_score, :accuracy_justification) SENSITIVE = [:grounding_justifications, :accuracy_justification] include Aws::Structure end |
#grounding_justifications ⇒ Array<String>
Explanations describing how the source statements support and justify this specific rule.
2101 2102 2103 2104 2105 2106 2107 2108 2109 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2101 class AutomatedReasoningPolicyRuleReport < Struct.new( :rule, :grounding_statements, :grounding_justifications, :accuracy_score, :accuracy_justification) SENSITIVE = [:grounding_justifications, :accuracy_justification] include Aws::Structure end |
#grounding_statements ⇒ Array<Types::AutomatedReasoningPolicyStatementReference>
References to statements from the source documents that provide the basis or justification for this rule.
2101 2102 2103 2104 2105 2106 2107 2108 2109 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2101 class AutomatedReasoningPolicyRuleReport < Struct.new( :rule, :grounding_statements, :grounding_justifications, :accuracy_score, :accuracy_justification) SENSITIVE = [:grounding_justifications, :accuracy_justification] include Aws::Structure end |
#rule ⇒ String
The identifier of the policy rule being analyzed in this report.
2101 2102 2103 2104 2105 2106 2107 2108 2109 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2101 class AutomatedReasoningPolicyRuleReport < Struct.new( :rule, :grounding_statements, :grounding_justifications, :accuracy_score, :accuracy_justification) SENSITIVE = [:grounding_justifications, :accuracy_justification] include Aws::Structure end |