Class: Aws::Bedrock::Types::AutomatedReasoningPolicyStatementReference
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::AutomatedReasoningPolicyStatementReference
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
References a specific atomic statement within a source document, used to link policy elements back to their source material.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#document_id ⇒ String
The unique identifier of the document containing the referenced statement.
-
#statement_id ⇒ String
The unique identifier of the specific atomic statement being referenced.
Instance Attribute Details
#document_id ⇒ String
The unique identifier of the document containing the referenced statement.
2229 2230 2231 2232 2233 2234 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2229 class AutomatedReasoningPolicyStatementReference < Struct.new( :document_id, :statement_id) SENSITIVE = [] include Aws::Structure end |
#statement_id ⇒ String
The unique identifier of the specific atomic statement being referenced.
2229 2230 2231 2232 2233 2234 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2229 class AutomatedReasoningPolicyStatementReference < Struct.new( :document_id, :statement_id) SENSITIVE = [] include Aws::Structure end |