Class: Aws::Bedrock::Types::AutomatedReasoningPolicyVariableReport
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::AutomatedReasoningPolicyVariableReport
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Provides detailed fidelity analysis for a specific policy variable, including which source document statements support it and how accurate the variable definition is.
Constant Summary collapse
- SENSITIVE =
[:policy_variable, :grounding_justifications, :accuracy_justification]
Instance Attribute Summary collapse
-
#accuracy_justification ⇒ String
A textual explanation of the accuracy score, describing why the variable received this particular accuracy rating.
-
#accuracy_score ⇒ Float
A score from 0.0 to 1.0 indicating how accurately this variable represents concepts from the source material.
-
#grounding_justifications ⇒ Array<String>
Explanations describing how the source statements support and justify this specific variable definition.
-
#grounding_statements ⇒ Array<Types::AutomatedReasoningPolicyStatementReference>
References to statements from the source documents that provide the basis or justification for this variable.
-
#policy_variable ⇒ String
The name of the policy variable being analyzed in this report.
Instance Attribute Details
#accuracy_justification ⇒ String
A textual explanation of the accuracy score, describing why the variable received this particular accuracy rating.
2651 2652 2653 2654 2655 2656 2657 2658 2659 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2651 class AutomatedReasoningPolicyVariableReport < Struct.new( :policy_variable, :grounding_statements, :grounding_justifications, :accuracy_score, :accuracy_justification) SENSITIVE = [:policy_variable, :grounding_justifications, :accuracy_justification] include Aws::Structure end |
#accuracy_score ⇒ Float
A score from 0.0 to 1.0 indicating how accurately this variable represents concepts from the source material.
2651 2652 2653 2654 2655 2656 2657 2658 2659 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2651 class AutomatedReasoningPolicyVariableReport < Struct.new( :policy_variable, :grounding_statements, :grounding_justifications, :accuracy_score, :accuracy_justification) SENSITIVE = [:policy_variable, :grounding_justifications, :accuracy_justification] include Aws::Structure end |
#grounding_justifications ⇒ Array<String>
Explanations describing how the source statements support and justify this specific variable definition.
2651 2652 2653 2654 2655 2656 2657 2658 2659 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2651 class AutomatedReasoningPolicyVariableReport < Struct.new( :policy_variable, :grounding_statements, :grounding_justifications, :accuracy_score, :accuracy_justification) SENSITIVE = [:policy_variable, :grounding_justifications, :accuracy_justification] include Aws::Structure end |
#grounding_statements ⇒ Array<Types::AutomatedReasoningPolicyStatementReference>
References to statements from the source documents that provide the basis or justification for this variable.
2651 2652 2653 2654 2655 2656 2657 2658 2659 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2651 class AutomatedReasoningPolicyVariableReport < Struct.new( :policy_variable, :grounding_statements, :grounding_justifications, :accuracy_score, :accuracy_justification) SENSITIVE = [:policy_variable, :grounding_justifications, :accuracy_justification] include Aws::Structure end |
#policy_variable ⇒ String
The name of the policy variable being analyzed in this report.
2651 2652 2653 2654 2655 2656 2657 2658 2659 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2651 class AutomatedReasoningPolicyVariableReport < Struct.new( :policy_variable, :grounding_statements, :grounding_justifications, :accuracy_score, :accuracy_justification) SENSITIVE = [:policy_variable, :grounding_justifications, :accuracy_justification] include Aws::Structure end |