Class: Aws::Bedrock::Types::AutomatedReasoningPolicyWorkflowTypeContent
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::AutomatedReasoningPolicyWorkflowTypeContent
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
AutomatedReasoningPolicyWorkflowTypeContent is a union - when making an API calls you must set exactly one of the members.
Defines the content and configuration for different types of policy build workflows.
Direct Known Subclasses
Documents, GenerateFidelityReportContent, IterativeRefinementContent, PolicyRepairAssets, Unknown
Defined Under Namespace
Classes: Documents, GenerateFidelityReportContent, IterativeRefinementContent, PolicyRepairAssets, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#documents ⇒ Array<Types::AutomatedReasoningPolicyBuildWorkflowDocument>
The list of documents to be processed in a document ingestion workflow.
-
#generate_fidelity_report_content ⇒ Types::AutomatedReasoningPolicyGenerateFidelityReportContent
The content configuration for generating a fidelity report workflow.
-
#iterative_refinement_content ⇒ Types::AutomatedReasoningPolicyIterativeRefinementContent
Content configuration to start an iterative policy refinement workflow that uses generative AI to automatically make changes to the policy based on test results and the optional feedback provided.
-
#policy_repair_assets ⇒ Types::AutomatedReasoningPolicyBuildWorkflowRepairContent
The assets and instructions needed for a policy repair workflow, including repair annotations and guidance.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#documents ⇒ Array<Types::AutomatedReasoningPolicyBuildWorkflowDocument>
The list of documents to be processed in a document ingestion workflow.
2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2716 class AutomatedReasoningPolicyWorkflowTypeContent < Struct.new( :documents, :policy_repair_assets, :generate_fidelity_report_content, :iterative_refinement_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Documents < AutomatedReasoningPolicyWorkflowTypeContent; end class PolicyRepairAssets < AutomatedReasoningPolicyWorkflowTypeContent; end class GenerateFidelityReportContent < AutomatedReasoningPolicyWorkflowTypeContent; end class IterativeRefinementContent < AutomatedReasoningPolicyWorkflowTypeContent; end class Unknown < AutomatedReasoningPolicyWorkflowTypeContent; end end |
#generate_fidelity_report_content ⇒ Types::AutomatedReasoningPolicyGenerateFidelityReportContent
The content configuration for generating a fidelity report workflow. This can include source documents to analyze or an existing fidelity report to update with a new policy definition.
2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2716 class AutomatedReasoningPolicyWorkflowTypeContent < Struct.new( :documents, :policy_repair_assets, :generate_fidelity_report_content, :iterative_refinement_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Documents < AutomatedReasoningPolicyWorkflowTypeContent; end class PolicyRepairAssets < AutomatedReasoningPolicyWorkflowTypeContent; end class GenerateFidelityReportContent < AutomatedReasoningPolicyWorkflowTypeContent; end class IterativeRefinementContent < AutomatedReasoningPolicyWorkflowTypeContent; end class Unknown < AutomatedReasoningPolicyWorkflowTypeContent; end end |
#iterative_refinement_content ⇒ Types::AutomatedReasoningPolicyIterativeRefinementContent
Content configuration to start an iterative policy refinement workflow that uses generative AI to automatically make changes to the policy based on test results and the optional feedback provided.
2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2716 class AutomatedReasoningPolicyWorkflowTypeContent < Struct.new( :documents, :policy_repair_assets, :generate_fidelity_report_content, :iterative_refinement_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Documents < AutomatedReasoningPolicyWorkflowTypeContent; end class PolicyRepairAssets < AutomatedReasoningPolicyWorkflowTypeContent; end class GenerateFidelityReportContent < AutomatedReasoningPolicyWorkflowTypeContent; end class IterativeRefinementContent < AutomatedReasoningPolicyWorkflowTypeContent; end class Unknown < AutomatedReasoningPolicyWorkflowTypeContent; end end |
#policy_repair_assets ⇒ Types::AutomatedReasoningPolicyBuildWorkflowRepairContent
The assets and instructions needed for a policy repair workflow, including repair annotations and guidance.
2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2716 class AutomatedReasoningPolicyWorkflowTypeContent < Struct.new( :documents, :policy_repair_assets, :generate_fidelity_report_content, :iterative_refinement_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Documents < AutomatedReasoningPolicyWorkflowTypeContent; end class PolicyRepairAssets < AutomatedReasoningPolicyWorkflowTypeContent; end class GenerateFidelityReportContent < AutomatedReasoningPolicyWorkflowTypeContent; end class IterativeRefinementContent < AutomatedReasoningPolicyWorkflowTypeContent; end class Unknown < AutomatedReasoningPolicyWorkflowTypeContent; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2716 2717 2718 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2716 def unknown @unknown end |