Class: Aws::Bedrock::Types::AutomatedReasoningPolicyWorkflowTypeContent
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::AutomatedReasoningPolicyWorkflowTypeContent
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
AutomatedReasoningPolicyWorkflowTypeContent is a union - when making an API calls you must set exactly one of the members.
Defines the content and configuration for different types of policy build workflows.
Direct Known Subclasses
Documents, GenerateFidelityReportContent, PolicyRepairAssets, Unknown
Defined Under Namespace
Classes: Documents, GenerateFidelityReportContent, PolicyRepairAssets, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#documents ⇒ Array<Types::AutomatedReasoningPolicyBuildWorkflowDocument>
The list of documents to be processed in a document ingestion workflow.
-
#generate_fidelity_report_content ⇒ Types::AutomatedReasoningPolicyGenerateFidelityReportContent
The content configuration for generating a fidelity report workflow.
-
#policy_repair_assets ⇒ Types::AutomatedReasoningPolicyBuildWorkflowRepairContent
The assets and instructions needed for a policy repair workflow, including repair annotations and guidance.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#documents ⇒ Array<Types::AutomatedReasoningPolicyBuildWorkflowDocument>
The list of documents to be processed in a document ingestion workflow.
2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2684 class AutomatedReasoningPolicyWorkflowTypeContent < Struct.new( :documents, :policy_repair_assets, :generate_fidelity_report_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Documents < AutomatedReasoningPolicyWorkflowTypeContent; end class PolicyRepairAssets < AutomatedReasoningPolicyWorkflowTypeContent; end class GenerateFidelityReportContent < AutomatedReasoningPolicyWorkflowTypeContent; end class Unknown < AutomatedReasoningPolicyWorkflowTypeContent; end end |
#generate_fidelity_report_content ⇒ Types::AutomatedReasoningPolicyGenerateFidelityReportContent
The content configuration for generating a fidelity report workflow. This can include source documents to analyze or an existing fidelity report to update with a new policy definition.
2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2684 class AutomatedReasoningPolicyWorkflowTypeContent < Struct.new( :documents, :policy_repair_assets, :generate_fidelity_report_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Documents < AutomatedReasoningPolicyWorkflowTypeContent; end class PolicyRepairAssets < AutomatedReasoningPolicyWorkflowTypeContent; end class GenerateFidelityReportContent < AutomatedReasoningPolicyWorkflowTypeContent; end class Unknown < AutomatedReasoningPolicyWorkflowTypeContent; end end |
#policy_repair_assets ⇒ Types::AutomatedReasoningPolicyBuildWorkflowRepairContent
The assets and instructions needed for a policy repair workflow, including repair annotations and guidance.
2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2684 class AutomatedReasoningPolicyWorkflowTypeContent < Struct.new( :documents, :policy_repair_assets, :generate_fidelity_report_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Documents < AutomatedReasoningPolicyWorkflowTypeContent; end class PolicyRepairAssets < AutomatedReasoningPolicyWorkflowTypeContent; end class GenerateFidelityReportContent < AutomatedReasoningPolicyWorkflowTypeContent; end class Unknown < AutomatedReasoningPolicyWorkflowTypeContent; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2684 2685 2686 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2684 def unknown @unknown end |