Class: Aws::Bedrock::Types::BatchDeleteAdvancedPromptOptimizationJobError
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::BatchDeleteAdvancedPromptOptimizationJobError
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Contains information about an error that occurred when deleting an advanced prompt optimization job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The error code for the deletion failure.
-
#job_identifier ⇒ String
The identifier of the job that could not be deleted.
-
#message ⇒ String
A message describing the error.
Instance Attribute Details
#code ⇒ String
The error code for the deletion failure.
2750 2751 2752 2753 2754 2755 2756 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2750 class BatchDeleteAdvancedPromptOptimizationJobError < Struct.new( :job_identifier, :code, :message) SENSITIVE = [] include Aws::Structure end |
#job_identifier ⇒ String
The identifier of the job that could not be deleted.
2750 2751 2752 2753 2754 2755 2756 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2750 class BatchDeleteAdvancedPromptOptimizationJobError < Struct.new( :job_identifier, :code, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A message describing the error.
2750 2751 2752 2753 2754 2755 2756 |
# File 'lib/aws-sdk-bedrock/types.rb', line 2750 class BatchDeleteAdvancedPromptOptimizationJobError < Struct.new( :job_identifier, :code, :message) SENSITIVE = [] include Aws::Structure end |