Class: Aws::Bedrock::Types::CreateGuardrailRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::CreateGuardrailRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description, :blocked_input_messaging, :blocked_outputs_messaging]
Instance Attribute Summary collapse
-
#automated_reasoning_policy_config ⇒ Types::GuardrailAutomatedReasoningPolicyConfig
Optional configuration for integrating Automated Reasoning policies with the new guardrail.
-
#blocked_input_messaging ⇒ String
The message to return when the guardrail blocks a prompt.
-
#blocked_outputs_messaging ⇒ String
The message to return when the guardrail blocks a model response.
-
#client_request_token ⇒ String
A unique, case-sensitive identifier to ensure that the API request completes no more than once.
-
#content_policy_config ⇒ Types::GuardrailContentPolicyConfig
The content filter policies to configure for the guardrail.
-
#contextual_grounding_policy_config ⇒ Types::GuardrailContextualGroundingPolicyConfig
The contextual grounding policy configuration used to create a guardrail.
-
#cross_region_config ⇒ Types::GuardrailCrossRegionConfig
The system-defined guardrail profile that you’re using with your guardrail.
-
#description ⇒ String
A description of the guardrail.
-
#kms_key_id ⇒ String
The ARN of the KMS key that you use to encrypt the guardrail.
-
#name ⇒ String
The name to give the guardrail.
-
#sensitive_information_policy_config ⇒ Types::GuardrailSensitiveInformationPolicyConfig
The sensitive information policy to configure for the guardrail.
-
#tags ⇒ Array<Types::Tag>
The tags that you want to attach to the guardrail.
-
#topic_policy_config ⇒ Types::GuardrailTopicPolicyConfig
The topic policies to configure for the guardrail.
-
#word_policy_config ⇒ Types::GuardrailWordPolicyConfig
The word policy you configure for the guardrail.
Instance Attribute Details
#automated_reasoning_policy_config ⇒ Types::GuardrailAutomatedReasoningPolicyConfig
Optional configuration for integrating Automated Reasoning policies with the new guardrail.
3662 3663 3664 3665 3666 3667 3668 3669 3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3662 class CreateGuardrailRequest < Struct.new( :name, :description, :topic_policy_config, :content_policy_config, :word_policy_config, :sensitive_information_policy_config, :contextual_grounding_policy_config, :automated_reasoning_policy_config, :cross_region_config, :blocked_input_messaging, :blocked_outputs_messaging, :kms_key_id, :tags, :client_request_token) SENSITIVE = [:name, :description, :blocked_input_messaging, :blocked_outputs_messaging] include Aws::Structure end |
#blocked_input_messaging ⇒ String
The message to return when the guardrail blocks a prompt.
3662 3663 3664 3665 3666 3667 3668 3669 3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3662 class CreateGuardrailRequest < Struct.new( :name, :description, :topic_policy_config, :content_policy_config, :word_policy_config, :sensitive_information_policy_config, :contextual_grounding_policy_config, :automated_reasoning_policy_config, :cross_region_config, :blocked_input_messaging, :blocked_outputs_messaging, :kms_key_id, :tags, :client_request_token) SENSITIVE = [:name, :description, :blocked_input_messaging, :blocked_outputs_messaging] include Aws::Structure end |
#blocked_outputs_messaging ⇒ String
The message to return when the guardrail blocks a model response.
3662 3663 3664 3665 3666 3667 3668 3669 3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3662 class CreateGuardrailRequest < Struct.new( :name, :description, :topic_policy_config, :content_policy_config, :word_policy_config, :sensitive_information_policy_config, :contextual_grounding_policy_config, :automated_reasoning_policy_config, :cross_region_config, :blocked_input_messaging, :blocked_outputs_messaging, :kms_key_id, :tags, :client_request_token) SENSITIVE = [:name, :description, :blocked_input_messaging, :blocked_outputs_messaging] include Aws::Structure end |
#client_request_token ⇒ String
A unique, case-sensitive identifier to ensure that the API request completes no more than once. If this token matches a previous request, Amazon Bedrock ignores the request, but does not return an error. For more information, see [Ensuring idempotency] in the *Amazon S3 User Guide*.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html
3662 3663 3664 3665 3666 3667 3668 3669 3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3662 class CreateGuardrailRequest < Struct.new( :name, :description, :topic_policy_config, :content_policy_config, :word_policy_config, :sensitive_information_policy_config, :contextual_grounding_policy_config, :automated_reasoning_policy_config, :cross_region_config, :blocked_input_messaging, :blocked_outputs_messaging, :kms_key_id, :tags, :client_request_token) SENSITIVE = [:name, :description, :blocked_input_messaging, :blocked_outputs_messaging] include Aws::Structure end |
#content_policy_config ⇒ Types::GuardrailContentPolicyConfig
The content filter policies to configure for the guardrail.
3662 3663 3664 3665 3666 3667 3668 3669 3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3662 class CreateGuardrailRequest < Struct.new( :name, :description, :topic_policy_config, :content_policy_config, :word_policy_config, :sensitive_information_policy_config, :contextual_grounding_policy_config, :automated_reasoning_policy_config, :cross_region_config, :blocked_input_messaging, :blocked_outputs_messaging, :kms_key_id, :tags, :client_request_token) SENSITIVE = [:name, :description, :blocked_input_messaging, :blocked_outputs_messaging] include Aws::Structure end |
#contextual_grounding_policy_config ⇒ Types::GuardrailContextualGroundingPolicyConfig
The contextual grounding policy configuration used to create a guardrail.
3662 3663 3664 3665 3666 3667 3668 3669 3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3662 class CreateGuardrailRequest < Struct.new( :name, :description, :topic_policy_config, :content_policy_config, :word_policy_config, :sensitive_information_policy_config, :contextual_grounding_policy_config, :automated_reasoning_policy_config, :cross_region_config, :blocked_input_messaging, :blocked_outputs_messaging, :kms_key_id, :tags, :client_request_token) SENSITIVE = [:name, :description, :blocked_input_messaging, :blocked_outputs_messaging] include Aws::Structure end |
#cross_region_config ⇒ Types::GuardrailCrossRegionConfig
The system-defined guardrail profile that you’re using with your guardrail. Guardrail profiles define the destination Amazon Web Services Regions where guardrail inference requests can be automatically routed.
For more information, see the [Amazon Bedrock User Guide].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/guardrails-cross-region.html
3662 3663 3664 3665 3666 3667 3668 3669 3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3662 class CreateGuardrailRequest < Struct.new( :name, :description, :topic_policy_config, :content_policy_config, :word_policy_config, :sensitive_information_policy_config, :contextual_grounding_policy_config, :automated_reasoning_policy_config, :cross_region_config, :blocked_input_messaging, :blocked_outputs_messaging, :kms_key_id, :tags, :client_request_token) SENSITIVE = [:name, :description, :blocked_input_messaging, :blocked_outputs_messaging] include Aws::Structure end |
#description ⇒ String
A description of the guardrail.
3662 3663 3664 3665 3666 3667 3668 3669 3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3662 class CreateGuardrailRequest < Struct.new( :name, :description, :topic_policy_config, :content_policy_config, :word_policy_config, :sensitive_information_policy_config, :contextual_grounding_policy_config, :automated_reasoning_policy_config, :cross_region_config, :blocked_input_messaging, :blocked_outputs_messaging, :kms_key_id, :tags, :client_request_token) SENSITIVE = [:name, :description, :blocked_input_messaging, :blocked_outputs_messaging] include Aws::Structure end |
#kms_key_id ⇒ String
The ARN of the KMS key that you use to encrypt the guardrail.
3662 3663 3664 3665 3666 3667 3668 3669 3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3662 class CreateGuardrailRequest < Struct.new( :name, :description, :topic_policy_config, :content_policy_config, :word_policy_config, :sensitive_information_policy_config, :contextual_grounding_policy_config, :automated_reasoning_policy_config, :cross_region_config, :blocked_input_messaging, :blocked_outputs_messaging, :kms_key_id, :tags, :client_request_token) SENSITIVE = [:name, :description, :blocked_input_messaging, :blocked_outputs_messaging] include Aws::Structure end |
#name ⇒ String
The name to give the guardrail.
3662 3663 3664 3665 3666 3667 3668 3669 3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3662 class CreateGuardrailRequest < Struct.new( :name, :description, :topic_policy_config, :content_policy_config, :word_policy_config, :sensitive_information_policy_config, :contextual_grounding_policy_config, :automated_reasoning_policy_config, :cross_region_config, :blocked_input_messaging, :blocked_outputs_messaging, :kms_key_id, :tags, :client_request_token) SENSITIVE = [:name, :description, :blocked_input_messaging, :blocked_outputs_messaging] include Aws::Structure end |
#sensitive_information_policy_config ⇒ Types::GuardrailSensitiveInformationPolicyConfig
The sensitive information policy to configure for the guardrail.
3662 3663 3664 3665 3666 3667 3668 3669 3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3662 class CreateGuardrailRequest < Struct.new( :name, :description, :topic_policy_config, :content_policy_config, :word_policy_config, :sensitive_information_policy_config, :contextual_grounding_policy_config, :automated_reasoning_policy_config, :cross_region_config, :blocked_input_messaging, :blocked_outputs_messaging, :kms_key_id, :tags, :client_request_token) SENSITIVE = [:name, :description, :blocked_input_messaging, :blocked_outputs_messaging] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags that you want to attach to the guardrail.
3662 3663 3664 3665 3666 3667 3668 3669 3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3662 class CreateGuardrailRequest < Struct.new( :name, :description, :topic_policy_config, :content_policy_config, :word_policy_config, :sensitive_information_policy_config, :contextual_grounding_policy_config, :automated_reasoning_policy_config, :cross_region_config, :blocked_input_messaging, :blocked_outputs_messaging, :kms_key_id, :tags, :client_request_token) SENSITIVE = [:name, :description, :blocked_input_messaging, :blocked_outputs_messaging] include Aws::Structure end |
#topic_policy_config ⇒ Types::GuardrailTopicPolicyConfig
The topic policies to configure for the guardrail.
3662 3663 3664 3665 3666 3667 3668 3669 3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3662 class CreateGuardrailRequest < Struct.new( :name, :description, :topic_policy_config, :content_policy_config, :word_policy_config, :sensitive_information_policy_config, :contextual_grounding_policy_config, :automated_reasoning_policy_config, :cross_region_config, :blocked_input_messaging, :blocked_outputs_messaging, :kms_key_id, :tags, :client_request_token) SENSITIVE = [:name, :description, :blocked_input_messaging, :blocked_outputs_messaging] include Aws::Structure end |
#word_policy_config ⇒ Types::GuardrailWordPolicyConfig
The word policy you configure for the guardrail.
3662 3663 3664 3665 3666 3667 3668 3669 3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3662 class CreateGuardrailRequest < Struct.new( :name, :description, :topic_policy_config, :content_policy_config, :word_policy_config, :sensitive_information_policy_config, :contextual_grounding_policy_config, :automated_reasoning_policy_config, :cross_region_config, :blocked_input_messaging, :blocked_outputs_messaging, :kms_key_id, :tags, :client_request_token) SENSITIVE = [:name, :description, :blocked_input_messaging, :blocked_outputs_messaging] include Aws::Structure end |