Class: Aws::Bedrock::Types::CreateModelCustomizationJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::CreateModelCustomizationJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#base_model_identifier ⇒ String
Name of the base model.
-
#client_request_token ⇒ String
A unique, case-sensitive identifier to ensure that the API request completes no more than one time.
-
#custom_model_kms_key_id ⇒ String
The custom model is encrypted at rest using this key.
-
#custom_model_name ⇒ String
A name for the resulting custom model.
-
#custom_model_tags ⇒ Array<Types::Tag>
Tags to attach to the resulting custom model.
-
#customization_config ⇒ Types::CustomizationConfig
The customization configuration for the model customization job.
-
#customization_type ⇒ String
The customization type.
-
#hyper_parameters ⇒ Hash<String,String>
Parameters related to tuning the model.
-
#job_name ⇒ String
A name for the fine-tuning job.
-
#job_tags ⇒ Array<Types::Tag>
Tags to attach to the job.
-
#output_data_config ⇒ Types::OutputDataConfig
S3 location for the output data.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM service role that Amazon Bedrock can assume to perform tasks on your behalf.
-
#training_data_config ⇒ Types::TrainingDataConfig
Information about the training dataset.
-
#validation_data_config ⇒ Types::ValidationDataConfig
Information about the validation dataset.
-
#vpc_config ⇒ Types::VpcConfig
The configuration of the Virtual Private Cloud (VPC) that contains the resources that you’re using for this job.
Instance Attribute Details
#base_model_identifier ⇒ String
Name of the base model.
4037 4038 4039 4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 4050 4051 4052 4053 4054 4055 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4037 class CreateModelCustomizationJobRequest < Struct.new( :job_name, :custom_model_name, :role_arn, :client_request_token, :base_model_identifier, :customization_type, :custom_model_kms_key_id, :job_tags, :custom_model_tags, :training_data_config, :validation_data_config, :output_data_config, :hyper_parameters, :vpc_config, :customization_config) SENSITIVE = [] include Aws::Structure end |
#client_request_token ⇒ String
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request, but does not return an error. For more information, see [Ensuring idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html
4037 4038 4039 4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 4050 4051 4052 4053 4054 4055 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4037 class CreateModelCustomizationJobRequest < Struct.new( :job_name, :custom_model_name, :role_arn, :client_request_token, :base_model_identifier, :customization_type, :custom_model_kms_key_id, :job_tags, :custom_model_tags, :training_data_config, :validation_data_config, :output_data_config, :hyper_parameters, :vpc_config, :customization_config) SENSITIVE = [] include Aws::Structure end |
#custom_model_kms_key_id ⇒ String
The custom model is encrypted at rest using this key.
4037 4038 4039 4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 4050 4051 4052 4053 4054 4055 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4037 class CreateModelCustomizationJobRequest < Struct.new( :job_name, :custom_model_name, :role_arn, :client_request_token, :base_model_identifier, :customization_type, :custom_model_kms_key_id, :job_tags, :custom_model_tags, :training_data_config, :validation_data_config, :output_data_config, :hyper_parameters, :vpc_config, :customization_config) SENSITIVE = [] include Aws::Structure end |
#custom_model_name ⇒ String
A name for the resulting custom model.
4037 4038 4039 4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 4050 4051 4052 4053 4054 4055 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4037 class CreateModelCustomizationJobRequest < Struct.new( :job_name, :custom_model_name, :role_arn, :client_request_token, :base_model_identifier, :customization_type, :custom_model_kms_key_id, :job_tags, :custom_model_tags, :training_data_config, :validation_data_config, :output_data_config, :hyper_parameters, :vpc_config, :customization_config) SENSITIVE = [] include Aws::Structure end |
#custom_model_tags ⇒ Array<Types::Tag>
Tags to attach to the resulting custom model.
4037 4038 4039 4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 4050 4051 4052 4053 4054 4055 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4037 class CreateModelCustomizationJobRequest < Struct.new( :job_name, :custom_model_name, :role_arn, :client_request_token, :base_model_identifier, :customization_type, :custom_model_kms_key_id, :job_tags, :custom_model_tags, :training_data_config, :validation_data_config, :output_data_config, :hyper_parameters, :vpc_config, :customization_config) SENSITIVE = [] include Aws::Structure end |
#customization_config ⇒ Types::CustomizationConfig
The customization configuration for the model customization job.
4037 4038 4039 4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 4050 4051 4052 4053 4054 4055 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4037 class CreateModelCustomizationJobRequest < Struct.new( :job_name, :custom_model_name, :role_arn, :client_request_token, :base_model_identifier, :customization_type, :custom_model_kms_key_id, :job_tags, :custom_model_tags, :training_data_config, :validation_data_config, :output_data_config, :hyper_parameters, :vpc_config, :customization_config) SENSITIVE = [] include Aws::Structure end |
#customization_type ⇒ String
The customization type.
4037 4038 4039 4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 4050 4051 4052 4053 4054 4055 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4037 class CreateModelCustomizationJobRequest < Struct.new( :job_name, :custom_model_name, :role_arn, :client_request_token, :base_model_identifier, :customization_type, :custom_model_kms_key_id, :job_tags, :custom_model_tags, :training_data_config, :validation_data_config, :output_data_config, :hyper_parameters, :vpc_config, :customization_config) SENSITIVE = [] include Aws::Structure end |
#hyper_parameters ⇒ Hash<String,String>
Parameters related to tuning the model. For details on the format for different models, see [Custom model hyperparameters].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/custom-models-hp.html
4037 4038 4039 4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 4050 4051 4052 4053 4054 4055 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4037 class CreateModelCustomizationJobRequest < Struct.new( :job_name, :custom_model_name, :role_arn, :client_request_token, :base_model_identifier, :customization_type, :custom_model_kms_key_id, :job_tags, :custom_model_tags, :training_data_config, :validation_data_config, :output_data_config, :hyper_parameters, :vpc_config, :customization_config) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
A name for the fine-tuning job.
4037 4038 4039 4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 4050 4051 4052 4053 4054 4055 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4037 class CreateModelCustomizationJobRequest < Struct.new( :job_name, :custom_model_name, :role_arn, :client_request_token, :base_model_identifier, :customization_type, :custom_model_kms_key_id, :job_tags, :custom_model_tags, :training_data_config, :validation_data_config, :output_data_config, :hyper_parameters, :vpc_config, :customization_config) SENSITIVE = [] include Aws::Structure end |
#job_tags ⇒ Array<Types::Tag>
Tags to attach to the job.
4037 4038 4039 4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 4050 4051 4052 4053 4054 4055 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4037 class CreateModelCustomizationJobRequest < Struct.new( :job_name, :custom_model_name, :role_arn, :client_request_token, :base_model_identifier, :customization_type, :custom_model_kms_key_id, :job_tags, :custom_model_tags, :training_data_config, :validation_data_config, :output_data_config, :hyper_parameters, :vpc_config, :customization_config) SENSITIVE = [] include Aws::Structure end |
#output_data_config ⇒ Types::OutputDataConfig
S3 location for the output data.
4037 4038 4039 4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 4050 4051 4052 4053 4054 4055 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4037 class CreateModelCustomizationJobRequest < Struct.new( :job_name, :custom_model_name, :role_arn, :client_request_token, :base_model_identifier, :customization_type, :custom_model_kms_key_id, :job_tags, :custom_model_tags, :training_data_config, :validation_data_config, :output_data_config, :hyper_parameters, :vpc_config, :customization_config) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM service role that Amazon Bedrock can assume to perform tasks on your behalf. For example, during model training, Amazon Bedrock needs your permission to read input data from an S3 bucket, write model artifacts to an S3 bucket. To pass this role to Amazon Bedrock, the caller of this API must have the ‘iam:PassRole` permission.
4037 4038 4039 4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 4050 4051 4052 4053 4054 4055 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4037 class CreateModelCustomizationJobRequest < Struct.new( :job_name, :custom_model_name, :role_arn, :client_request_token, :base_model_identifier, :customization_type, :custom_model_kms_key_id, :job_tags, :custom_model_tags, :training_data_config, :validation_data_config, :output_data_config, :hyper_parameters, :vpc_config, :customization_config) SENSITIVE = [] include Aws::Structure end |
#training_data_config ⇒ Types::TrainingDataConfig
Information about the training dataset.
4037 4038 4039 4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 4050 4051 4052 4053 4054 4055 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4037 class CreateModelCustomizationJobRequest < Struct.new( :job_name, :custom_model_name, :role_arn, :client_request_token, :base_model_identifier, :customization_type, :custom_model_kms_key_id, :job_tags, :custom_model_tags, :training_data_config, :validation_data_config, :output_data_config, :hyper_parameters, :vpc_config, :customization_config) SENSITIVE = [] include Aws::Structure end |
#validation_data_config ⇒ Types::ValidationDataConfig
Information about the validation dataset.
4037 4038 4039 4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 4050 4051 4052 4053 4054 4055 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4037 class CreateModelCustomizationJobRequest < Struct.new( :job_name, :custom_model_name, :role_arn, :client_request_token, :base_model_identifier, :customization_type, :custom_model_kms_key_id, :job_tags, :custom_model_tags, :training_data_config, :validation_data_config, :output_data_config, :hyper_parameters, :vpc_config, :customization_config) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
The configuration of the Virtual Private Cloud (VPC) that contains the resources that you’re using for this job. For more information, see [Protect your model customization jobs using a VPC].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/vpc-model-customization.html
4037 4038 4039 4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 4050 4051 4052 4053 4054 4055 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4037 class CreateModelCustomizationJobRequest < Struct.new( :job_name, :custom_model_name, :role_arn, :client_request_token, :base_model_identifier, :customization_type, :custom_model_kms_key_id, :job_tags, :custom_model_tags, :training_data_config, :validation_data_config, :output_data_config, :hyper_parameters, :vpc_config, :customization_config) SENSITIVE = [] include Aws::Structure end |