Class: Aws::Bedrock::Types::CreateModelImportJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::CreateModelImportJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_request_token ⇒ String
A unique, case-sensitive identifier to ensure that the API request completes no more than one time.
-
#imported_model_kms_key_id ⇒ String
The imported model is encrypted at rest using this key.
-
#imported_model_name ⇒ String
The name of the imported model.
-
#imported_model_tags ⇒ Array<Types::Tag>
Tags to attach to the imported model.
-
#job_name ⇒ String
The name of the import job.
-
#job_tags ⇒ Array<Types::Tag>
Tags to attach to this import job.
-
#model_data_source ⇒ Types::ModelDataSource
The data source for the imported model.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the model import job.
-
#vpc_config ⇒ Types::VpcConfig
VPC configuration parameters for the private Virtual Private Cloud (VPC) that contains the resources you are using for the import job.
Instance Attribute Details
#client_request_token ⇒ String
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request, but does not return an error. For more information, see [Ensuring idempotency].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html
3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3911 class CreateModelImportJobRequest < Struct.new( :job_name, :imported_model_name, :role_arn, :model_data_source, :job_tags, :imported_model_tags, :client_request_token, :vpc_config, :imported_model_kms_key_id) SENSITIVE = [] include Aws::Structure end |
#imported_model_kms_key_id ⇒ String
The imported model is encrypted at rest using this key.
3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3911 class CreateModelImportJobRequest < Struct.new( :job_name, :imported_model_name, :role_arn, :model_data_source, :job_tags, :imported_model_tags, :client_request_token, :vpc_config, :imported_model_kms_key_id) SENSITIVE = [] include Aws::Structure end |
#imported_model_name ⇒ String
The name of the imported model.
3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3911 class CreateModelImportJobRequest < Struct.new( :job_name, :imported_model_name, :role_arn, :model_data_source, :job_tags, :imported_model_tags, :client_request_token, :vpc_config, :imported_model_kms_key_id) SENSITIVE = [] include Aws::Structure end |
#imported_model_tags ⇒ Array<Types::Tag>
Tags to attach to the imported model.
3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3911 class CreateModelImportJobRequest < Struct.new( :job_name, :imported_model_name, :role_arn, :model_data_source, :job_tags, :imported_model_tags, :client_request_token, :vpc_config, :imported_model_kms_key_id) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The name of the import job.
3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3911 class CreateModelImportJobRequest < Struct.new( :job_name, :imported_model_name, :role_arn, :model_data_source, :job_tags, :imported_model_tags, :client_request_token, :vpc_config, :imported_model_kms_key_id) SENSITIVE = [] include Aws::Structure end |
#job_tags ⇒ Array<Types::Tag>
Tags to attach to this import job.
3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3911 class CreateModelImportJobRequest < Struct.new( :job_name, :imported_model_name, :role_arn, :model_data_source, :job_tags, :imported_model_tags, :client_request_token, :vpc_config, :imported_model_kms_key_id) SENSITIVE = [] include Aws::Structure end |
#model_data_source ⇒ Types::ModelDataSource
The data source for the imported model.
3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3911 class CreateModelImportJobRequest < Struct.new( :job_name, :imported_model_name, :role_arn, :model_data_source, :job_tags, :imported_model_tags, :client_request_token, :vpc_config, :imported_model_kms_key_id) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the model import job.
3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3911 class CreateModelImportJobRequest < Struct.new( :job_name, :imported_model_name, :role_arn, :model_data_source, :job_tags, :imported_model_tags, :client_request_token, :vpc_config, :imported_model_kms_key_id) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
VPC configuration parameters for the private Virtual Private Cloud (VPC) that contains the resources you are using for the import job.
3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 |
# File 'lib/aws-sdk-bedrock/types.rb', line 3911 class CreateModelImportJobRequest < Struct.new( :job_name, :imported_model_name, :role_arn, :model_data_source, :job_tags, :imported_model_tags, :client_request_token, :vpc_config, :imported_model_kms_key_id) SENSITIVE = [] include Aws::Structure end |