Class: Aws::Bedrock::Types::CreatePromptRouterRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#client_request_tokenString

A unique, case-sensitive identifier that you provide to ensure idempotency of your requests. If not specified, the Amazon Web Services SDK automatically generates one for you.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
# File 'lib/aws-sdk-bedrock/types.rb', line 4281

class CreatePromptRouterRequest < Struct.new(
  :client_request_token,
  :prompt_router_name,
  :models,
  :description,
  :routing_criteria,
  :fallback_model,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

An optional description of the prompt router to help identify its purpose.

Returns:

  • (String)


4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
# File 'lib/aws-sdk-bedrock/types.rb', line 4281

class CreatePromptRouterRequest < Struct.new(
  :client_request_token,
  :prompt_router_name,
  :models,
  :description,
  :routing_criteria,
  :fallback_model,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#fallback_modelTypes::PromptRouterTargetModel

The default model to use when the routing criteria is not met.



4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
# File 'lib/aws-sdk-bedrock/types.rb', line 4281

class CreatePromptRouterRequest < Struct.new(
  :client_request_token,
  :prompt_router_name,
  :models,
  :description,
  :routing_criteria,
  :fallback_model,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#modelsArray<Types::PromptRouterTargetModel>

A list of foundation models that the prompt router can route requests to. At least one model must be specified.

Returns:



4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
# File 'lib/aws-sdk-bedrock/types.rb', line 4281

class CreatePromptRouterRequest < Struct.new(
  :client_request_token,
  :prompt_router_name,
  :models,
  :description,
  :routing_criteria,
  :fallback_model,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#prompt_router_nameString

The name of the prompt router. The name must be unique within your Amazon Web Services account in the current region.

Returns:

  • (String)


4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
# File 'lib/aws-sdk-bedrock/types.rb', line 4281

class CreatePromptRouterRequest < Struct.new(
  :client_request_token,
  :prompt_router_name,
  :models,
  :description,
  :routing_criteria,
  :fallback_model,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#routing_criteriaTypes::RoutingCriteria

The criteria, which is the response quality difference, used to determine how incoming requests are routed to different models.



4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
# File 'lib/aws-sdk-bedrock/types.rb', line 4281

class CreatePromptRouterRequest < Struct.new(
  :client_request_token,
  :prompt_router_name,
  :models,
  :description,
  :routing_criteria,
  :fallback_model,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#tagsArray<Types::Tag>

An array of key-value pairs to apply to this resource as tags. You can use tags to categorize and manage your Amazon Web Services resources.

Returns:



4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
# File 'lib/aws-sdk-bedrock/types.rb', line 4281

class CreatePromptRouterRequest < Struct.new(
  :client_request_token,
  :prompt_router_name,
  :models,
  :description,
  :routing_criteria,
  :fallback_model,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end