Class: Aws::Bedrock::Types::CustomModelDataSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::CustomModelDataSource
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Note:
CustomModelDataSource is a union - when making an API calls you must set exactly one of the members.
The data source for a custom model. This is a union type that supports the following member:
-
‘modelPackageArnDataSource` — Specifies a SageMaker AI model package as the data source.
^
Direct Known Subclasses
Defined Under Namespace
Classes: ModelPackageArnDataSource, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#model_package_arn_data_source ⇒ Types::ModelPackageArnDataSource
A SageMaker AI model package ARN as the data source for the custom model.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#model_package_arn_data_source ⇒ Types::ModelPackageArnDataSource
A SageMaker AI model package ARN as the data source for the custom model. When you specify a model package ARN, Amazon Bedrock resolves the model package to retrieve the model artifacts.
4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4541 class CustomModelDataSource < Struct.new( :model_package_arn_data_source, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ModelPackageArnDataSource < CustomModelDataSource; end class Unknown < CustomModelDataSource; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
4541 4542 4543 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4541 def unknown @unknown end |