Class: Aws::Bedrock::Types::CustomModelDeploymentUpdateDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::CustomModelDeploymentUpdateDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Details about an update to a custom model deployment, including the new custom model resource ARN and current update status.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#model_arn ⇒ String
ARN of the new custom model being deployed as part of the update.
-
#update_status ⇒ String
Current status of the deployment update.
Instance Attribute Details
#model_arn ⇒ String
ARN of the new custom model being deployed as part of the update.
4555 4556 4557 4558 4559 4560 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4555 class CustomModelDeploymentUpdateDetails < Struct.new( :model_arn, :update_status) SENSITIVE = [] include Aws::Structure end |
#update_status ⇒ String
Current status of the deployment update.
4555 4556 4557 4558 4559 4560 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4555 class CustomModelDeploymentUpdateDetails < Struct.new( :model_arn, :update_status) SENSITIVE = [] include Aws::Structure end |