Class: Aws::Bedrock::Types::DeleteAutomatedReasoningPolicyBuildWorkflowRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::DeleteAutomatedReasoningPolicyBuildWorkflowRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#build_workflow_id ⇒ String
The unique identifier of the build workflow to delete.
-
#last_updated_at ⇒ Time
The timestamp when the build workflow was last updated.
-
#policy_arn ⇒ String
The Amazon Resource Name (ARN) of the Automated Reasoning policy whose build workflow you want to delete.
Instance Attribute Details
#build_workflow_id ⇒ String
The unique identifier of the build workflow to delete.
4725 4726 4727 4728 4729 4730 4731 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4725 class DeleteAutomatedReasoningPolicyBuildWorkflowRequest < Struct.new( :policy_arn, :build_workflow_id, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp when the build workflow was last updated. This is used for optimistic concurrency control to prevent accidental deletion of workflows that have been modified.
4725 4726 4727 4728 4729 4730 4731 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4725 class DeleteAutomatedReasoningPolicyBuildWorkflowRequest < Struct.new( :policy_arn, :build_workflow_id, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#policy_arn ⇒ String
The Amazon Resource Name (ARN) of the Automated Reasoning policy whose build workflow you want to delete.
4725 4726 4727 4728 4729 4730 4731 |
# File 'lib/aws-sdk-bedrock/types.rb', line 4725 class DeleteAutomatedReasoningPolicyBuildWorkflowRequest < Struct.new( :policy_arn, :build_workflow_id, :last_updated_at) SENSITIVE = [] include Aws::Structure end |