Class: Aws::Bedrock::Types::EvaluationConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::EvaluationConfig
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
EvaluationConfig is a union - when making an API calls you must set exactly one of the members.
EvaluationConfig is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of EvaluationConfig corresponding to the set member.
The configuration details of either an automated or human-based evaluation job.
Defined Under Namespace
Classes: Automated, Human, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#automated ⇒ Types::AutomatedEvaluationConfig
Contains the configuration details of an automated evaluation job that computes metrics.
-
#human ⇒ Types::HumanEvaluationConfig
Contains the configuration details of an evaluation job that uses human workers.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#automated ⇒ Types::AutomatedEvaluationConfig
Contains the configuration details of an automated evaluation job that computes metrics.
5131 5132 5133 5134 5135 5136 5137 5138 5139 5140 5141 5142 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5131 class EvaluationConfig < Struct.new( :automated, :human, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Automated < EvaluationConfig; end class Human < EvaluationConfig; end class Unknown < EvaluationConfig; end end |
#human ⇒ Types::HumanEvaluationConfig
Contains the configuration details of an evaluation job that uses human workers.
5131 5132 5133 5134 5135 5136 5137 5138 5139 5140 5141 5142 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5131 class EvaluationConfig < Struct.new( :automated, :human, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Automated < EvaluationConfig; end class Human < EvaluationConfig; end class Unknown < EvaluationConfig; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
5131 5132 5133 |
# File 'lib/aws-sdk-bedrock/types.rb', line 5131 def unknown @unknown end |