Class: Aws::Bedrock::Types::GetAutomatedReasoningPolicyAnnotationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name]

Instance Attribute Summary collapse

Instance Attribute Details

#annotation_set_hashString

A hash value representing the current state of the annotations. This is used for optimistic concurrency control when updating annotations.

Returns:

  • (String)


6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
# File 'lib/aws-sdk-bedrock/types.rb', line 6166

class GetAutomatedReasoningPolicyAnnotationsResponse < Struct.new(
  :policy_arn,
  :name,
  :build_workflow_id,
  :annotations,
  :annotation_set_hash,
  :updated_at)
  SENSITIVE = [:name]
  include Aws::Structure
end

#annotationsArray<Types::AutomatedReasoningPolicyAnnotation>

The current set of annotations containing rules, variables, and types extracted from the source documents. These can be modified before finalizing the policy.



6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
# File 'lib/aws-sdk-bedrock/types.rb', line 6166

class GetAutomatedReasoningPolicyAnnotationsResponse < Struct.new(
  :policy_arn,
  :name,
  :build_workflow_id,
  :annotations,
  :annotation_set_hash,
  :updated_at)
  SENSITIVE = [:name]
  include Aws::Structure
end

#build_workflow_idString

The unique identifier of the build workflow.

Returns:

  • (String)


6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
# File 'lib/aws-sdk-bedrock/types.rb', line 6166

class GetAutomatedReasoningPolicyAnnotationsResponse < Struct.new(
  :policy_arn,
  :name,
  :build_workflow_id,
  :annotations,
  :annotation_set_hash,
  :updated_at)
  SENSITIVE = [:name]
  include Aws::Structure
end

#nameString

The name of the Automated Reasoning policy.

Returns:

  • (String)


6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
# File 'lib/aws-sdk-bedrock/types.rb', line 6166

class GetAutomatedReasoningPolicyAnnotationsResponse < Struct.new(
  :policy_arn,
  :name,
  :build_workflow_id,
  :annotations,
  :annotation_set_hash,
  :updated_at)
  SENSITIVE = [:name]
  include Aws::Structure
end

#policy_arnString

The Amazon Resource Name (ARN) of the Automated Reasoning policy.

Returns:

  • (String)


6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
# File 'lib/aws-sdk-bedrock/types.rb', line 6166

class GetAutomatedReasoningPolicyAnnotationsResponse < Struct.new(
  :policy_arn,
  :name,
  :build_workflow_id,
  :annotations,
  :annotation_set_hash,
  :updated_at)
  SENSITIVE = [:name]
  include Aws::Structure
end

#updated_atTime

The timestamp when the annotations were last updated.

Returns:

  • (Time)


6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
# File 'lib/aws-sdk-bedrock/types.rb', line 6166

class GetAutomatedReasoningPolicyAnnotationsResponse < Struct.new(
  :policy_arn,
  :name,
  :build_workflow_id,
  :annotations,
  :annotation_set_hash,
  :updated_at)
  SENSITIVE = [:name]
  include Aws::Structure
end