Class: Aws::Bedrock::Types::GetAutomatedReasoningPolicyAnnotationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::GetAutomatedReasoningPolicyAnnotationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name]
Instance Attribute Summary collapse
-
#annotation_set_hash ⇒ String
A hash value representing the current state of the annotations.
-
#annotations ⇒ Array<Types::AutomatedReasoningPolicyAnnotation>
The current set of annotations containing rules, variables, and types extracted from the source documents.
-
#build_workflow_id ⇒ String
The unique identifier of the build workflow.
-
#name ⇒ String
The name of the Automated Reasoning policy.
-
#policy_arn ⇒ String
The Amazon Resource Name (ARN) of the Automated Reasoning policy.
-
#updated_at ⇒ Time
The timestamp when the annotations were last updated.
Instance Attribute Details
#annotation_set_hash ⇒ String
A hash value representing the current state of the annotations. This is used for optimistic concurrency control when updating annotations.
6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6166 class GetAutomatedReasoningPolicyAnnotationsResponse < Struct.new( :policy_arn, :name, :build_workflow_id, :annotations, :annotation_set_hash, :updated_at) SENSITIVE = [:name] include Aws::Structure end |
#annotations ⇒ Array<Types::AutomatedReasoningPolicyAnnotation>
The current set of annotations containing rules, variables, and types extracted from the source documents. These can be modified before finalizing the policy.
6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6166 class GetAutomatedReasoningPolicyAnnotationsResponse < Struct.new( :policy_arn, :name, :build_workflow_id, :annotations, :annotation_set_hash, :updated_at) SENSITIVE = [:name] include Aws::Structure end |
#build_workflow_id ⇒ String
The unique identifier of the build workflow.
6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6166 class GetAutomatedReasoningPolicyAnnotationsResponse < Struct.new( :policy_arn, :name, :build_workflow_id, :annotations, :annotation_set_hash, :updated_at) SENSITIVE = [:name] include Aws::Structure end |
#name ⇒ String
The name of the Automated Reasoning policy.
6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6166 class GetAutomatedReasoningPolicyAnnotationsResponse < Struct.new( :policy_arn, :name, :build_workflow_id, :annotations, :annotation_set_hash, :updated_at) SENSITIVE = [:name] include Aws::Structure end |
#policy_arn ⇒ String
The Amazon Resource Name (ARN) of the Automated Reasoning policy.
6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6166 class GetAutomatedReasoningPolicyAnnotationsResponse < Struct.new( :policy_arn, :name, :build_workflow_id, :annotations, :annotation_set_hash, :updated_at) SENSITIVE = [:name] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the annotations were last updated.
6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6166 class GetAutomatedReasoningPolicyAnnotationsResponse < Struct.new( :policy_arn, :name, :build_workflow_id, :annotations, :annotation_set_hash, :updated_at) SENSITIVE = [:name] include Aws::Structure end |