Class: Aws::Bedrock::Types::GetAutomatedReasoningPolicyBuildWorkflowResultAssetsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_idString

The unique identifier of the specific asset to retrieve when multiple assets of the same type exist. This is required when retrieving SOURCE_DOCUMENT assets, as multiple source documents may have been used in the workflow. The asset ID can be obtained from the asset manifest.

Returns:

  • (String)


6184
6185
6186
6187
6188
6189
6190
6191
# File 'lib/aws-sdk-bedrock/types.rb', line 6184

class GetAutomatedReasoningPolicyBuildWorkflowResultAssetsRequest < Struct.new(
  :policy_arn,
  :build_workflow_id,
  :asset_type,
  :asset_id)
  SENSITIVE = []
  include Aws::Structure
end

#asset_typeString

The type of asset to retrieve (e.g., BUILD_LOG, QUALITY_REPORT, POLICY_DEFINITION, GENERATED_TEST_CASES, POLICY_SCENARIOS, FIDELITY_REPORT, ASSET_MANIFEST, SOURCE_DOCUMENT).

Returns:

  • (String)


6184
6185
6186
6187
6188
6189
6190
6191
# File 'lib/aws-sdk-bedrock/types.rb', line 6184

class GetAutomatedReasoningPolicyBuildWorkflowResultAssetsRequest < Struct.new(
  :policy_arn,
  :build_workflow_id,
  :asset_type,
  :asset_id)
  SENSITIVE = []
  include Aws::Structure
end

#build_workflow_idString

The unique identifier of the build workflow whose result assets you want to retrieve.

Returns:

  • (String)


6184
6185
6186
6187
6188
6189
6190
6191
# File 'lib/aws-sdk-bedrock/types.rb', line 6184

class GetAutomatedReasoningPolicyBuildWorkflowResultAssetsRequest < Struct.new(
  :policy_arn,
  :build_workflow_id,
  :asset_type,
  :asset_id)
  SENSITIVE = []
  include Aws::Structure
end

#policy_arnString

The Amazon Resource Name (ARN) of the Automated Reasoning policy whose build workflow assets you want to retrieve.

Returns:

  • (String)


6184
6185
6186
6187
6188
6189
6190
6191
# File 'lib/aws-sdk-bedrock/types.rb', line 6184

class GetAutomatedReasoningPolicyBuildWorkflowResultAssetsRequest < Struct.new(
  :policy_arn,
  :build_workflow_id,
  :asset_type,
  :asset_id)
  SENSITIVE = []
  include Aws::Structure
end