Class: Aws::Bedrock::Types::GetAutomatedReasoningPolicyBuildWorkflowResultAssetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::GetAutomatedReasoningPolicyBuildWorkflowResultAssetsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_id ⇒ String
The unique identifier of the specific asset to retrieve when multiple assets of the same type exist.
-
#asset_type ⇒ String
The type of asset to retrieve (e.g., BUILD_LOG, QUALITY_REPORT, POLICY_DEFINITION, GENERATED_TEST_CASES, POLICY_SCENARIOS, FIDELITY_REPORT, ASSET_MANIFEST, SOURCE_DOCUMENT).
-
#build_workflow_id ⇒ String
The unique identifier of the build workflow whose result assets you want to retrieve.
-
#policy_arn ⇒ String
The Amazon Resource Name (ARN) of the Automated Reasoning policy whose build workflow assets you want to retrieve.
Instance Attribute Details
#asset_id ⇒ String
The unique identifier of the specific asset to retrieve when multiple assets of the same type exist. This is required when retrieving SOURCE_DOCUMENT assets, as multiple source documents may have been used in the workflow. The asset ID can be obtained from the asset manifest.
6184 6185 6186 6187 6188 6189 6190 6191 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6184 class GetAutomatedReasoningPolicyBuildWorkflowResultAssetsRequest < Struct.new( :policy_arn, :build_workflow_id, :asset_type, :asset_id) SENSITIVE = [] include Aws::Structure end |
#asset_type ⇒ String
The type of asset to retrieve (e.g., BUILD_LOG, QUALITY_REPORT, POLICY_DEFINITION, GENERATED_TEST_CASES, POLICY_SCENARIOS, FIDELITY_REPORT, ASSET_MANIFEST, SOURCE_DOCUMENT).
6184 6185 6186 6187 6188 6189 6190 6191 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6184 class GetAutomatedReasoningPolicyBuildWorkflowResultAssetsRequest < Struct.new( :policy_arn, :build_workflow_id, :asset_type, :asset_id) SENSITIVE = [] include Aws::Structure end |
#build_workflow_id ⇒ String
The unique identifier of the build workflow whose result assets you want to retrieve.
6184 6185 6186 6187 6188 6189 6190 6191 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6184 class GetAutomatedReasoningPolicyBuildWorkflowResultAssetsRequest < Struct.new( :policy_arn, :build_workflow_id, :asset_type, :asset_id) SENSITIVE = [] include Aws::Structure end |
#policy_arn ⇒ String
The Amazon Resource Name (ARN) of the Automated Reasoning policy whose build workflow assets you want to retrieve.
6184 6185 6186 6187 6188 6189 6190 6191 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6184 class GetAutomatedReasoningPolicyBuildWorkflowResultAssetsRequest < Struct.new( :policy_arn, :build_workflow_id, :asset_type, :asset_id) SENSITIVE = [] include Aws::Structure end |