Class: Aws::Bedrock::Types::GetAutomatedReasoningPolicyBuildWorkflowResultAssetsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#build_workflow_assetsTypes::AutomatedReasoningPolicyBuildResultAssets

The requested build workflow asset. This is a union type that returns only one of the available asset types (logs, reports, or generated artifacts) based on the specific asset type requested in the API call.



6303
6304
6305
6306
6307
6308
6309
# File 'lib/aws-sdk-bedrock/types.rb', line 6303

class GetAutomatedReasoningPolicyBuildWorkflowResultAssetsResponse < Struct.new(
  :policy_arn,
  :build_workflow_id,
  :build_workflow_assets)
  SENSITIVE = []
  include Aws::Structure
end

#build_workflow_idString

The unique identifier of the build workflow.

Returns:

  • (String)


6303
6304
6305
6306
6307
6308
6309
# File 'lib/aws-sdk-bedrock/types.rb', line 6303

class GetAutomatedReasoningPolicyBuildWorkflowResultAssetsResponse < Struct.new(
  :policy_arn,
  :build_workflow_id,
  :build_workflow_assets)
  SENSITIVE = []
  include Aws::Structure
end

#policy_arnString

The Amazon Resource Name (ARN) of the Automated Reasoning policy.

Returns:

  • (String)


6303
6304
6305
6306
6307
6308
6309
# File 'lib/aws-sdk-bedrock/types.rb', line 6303

class GetAutomatedReasoningPolicyBuildWorkflowResultAssetsResponse < Struct.new(
  :policy_arn,
  :build_workflow_id,
  :build_workflow_assets)
  SENSITIVE = []
  include Aws::Structure
end