Class: Aws::Bedrock::Types::GetAutomatedReasoningPolicyBuildWorkflowResultAssetsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::GetAutomatedReasoningPolicyBuildWorkflowResultAssetsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#build_workflow_assets ⇒ Types::AutomatedReasoningPolicyBuildResultAssets
The requested build workflow asset.
-
#build_workflow_id ⇒ String
The unique identifier of the build workflow.
-
#policy_arn ⇒ String
The Amazon Resource Name (ARN) of the Automated Reasoning policy.
Instance Attribute Details
#build_workflow_assets ⇒ Types::AutomatedReasoningPolicyBuildResultAssets
The requested build workflow asset. This is a union type that returns only one of the available asset types (logs, reports, or generated artifacts) based on the specific asset type requested in the API call.
6272 6273 6274 6275 6276 6277 6278 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6272 class GetAutomatedReasoningPolicyBuildWorkflowResultAssetsResponse < Struct.new( :policy_arn, :build_workflow_id, :build_workflow_assets) SENSITIVE = [] include Aws::Structure end |
#build_workflow_id ⇒ String
The unique identifier of the build workflow.
6272 6273 6274 6275 6276 6277 6278 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6272 class GetAutomatedReasoningPolicyBuildWorkflowResultAssetsResponse < Struct.new( :policy_arn, :build_workflow_id, :build_workflow_assets) SENSITIVE = [] include Aws::Structure end |
#policy_arn ⇒ String
The Amazon Resource Name (ARN) of the Automated Reasoning policy.
6272 6273 6274 6275 6276 6277 6278 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6272 class GetAutomatedReasoningPolicyBuildWorkflowResultAssetsResponse < Struct.new( :policy_arn, :build_workflow_id, :build_workflow_assets) SENSITIVE = [] include Aws::Structure end |