Class: Aws::Bedrock::Types::GetCustomModelDeploymentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::GetCustomModelDeploymentResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The date and time when the custom model deployment was created.
-
#custom_model_deployment_arn ⇒ String
The Amazon Resource Name (ARN) of the custom model deployment.
-
#description ⇒ String
The description of the custom model deployment.
-
#failure_message ⇒ String
If the deployment status is ‘FAILED`, this field contains a message describing the failure reason.
-
#last_updated_at ⇒ Time
The date and time when the custom model deployment was last updated.
-
#model_arn ⇒ String
The Amazon Resource Name (ARN) of the custom model associated with this deployment.
-
#model_deployment_name ⇒ String
The name of the custom model deployment.
-
#status ⇒ String
The status of the custom model deployment.
-
#update_details ⇒ Types::CustomModelDeploymentUpdateDetails
Details about any pending or completed updates to the custom model deployment, including the new model ARN and update status.
Instance Attribute Details
#created_at ⇒ Time
The date and time when the custom model deployment was created.
6460 6461 6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6460 class GetCustomModelDeploymentResponse < Struct.new( :custom_model_deployment_arn, :model_deployment_name, :model_arn, :created_at, :status, :description, :update_details, :failure_message, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#custom_model_deployment_arn ⇒ String
The Amazon Resource Name (ARN) of the custom model deployment.
6460 6461 6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6460 class GetCustomModelDeploymentResponse < Struct.new( :custom_model_deployment_arn, :model_deployment_name, :model_arn, :created_at, :status, :description, :update_details, :failure_message, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the custom model deployment.
6460 6461 6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6460 class GetCustomModelDeploymentResponse < Struct.new( :custom_model_deployment_arn, :model_deployment_name, :model_arn, :created_at, :status, :description, :update_details, :failure_message, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#failure_message ⇒ String
If the deployment status is ‘FAILED`, this field contains a message describing the failure reason.
6460 6461 6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6460 class GetCustomModelDeploymentResponse < Struct.new( :custom_model_deployment_arn, :model_deployment_name, :model_arn, :created_at, :status, :description, :update_details, :failure_message, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The date and time when the custom model deployment was last updated.
6460 6461 6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6460 class GetCustomModelDeploymentResponse < Struct.new( :custom_model_deployment_arn, :model_deployment_name, :model_arn, :created_at, :status, :description, :update_details, :failure_message, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#model_arn ⇒ String
The Amazon Resource Name (ARN) of the custom model associated with this deployment.
6460 6461 6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6460 class GetCustomModelDeploymentResponse < Struct.new( :custom_model_deployment_arn, :model_deployment_name, :model_arn, :created_at, :status, :description, :update_details, :failure_message, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#model_deployment_name ⇒ String
The name of the custom model deployment.
6460 6461 6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6460 class GetCustomModelDeploymentResponse < Struct.new( :custom_model_deployment_arn, :model_deployment_name, :model_arn, :created_at, :status, :description, :update_details, :failure_message, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the custom model deployment. Possible values are:
-
‘CREATING` - The deployment is being set up and prepared for inference.
-
‘ACTIVE` - The deployment is ready and available for inference requests.
-
‘FAILED` - The deployment failed to be created or became unavailable.
6460 6461 6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6460 class GetCustomModelDeploymentResponse < Struct.new( :custom_model_deployment_arn, :model_deployment_name, :model_arn, :created_at, :status, :description, :update_details, :failure_message, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#update_details ⇒ Types::CustomModelDeploymentUpdateDetails
Details about any pending or completed updates to the custom model deployment, including the new model ARN and update status.
6460 6461 6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 |
# File 'lib/aws-sdk-bedrock/types.rb', line 6460 class GetCustomModelDeploymentResponse < Struct.new( :custom_model_deployment_arn, :model_deployment_name, :model_arn, :created_at, :status, :description, :update_details, :failure_message, :last_updated_at) SENSITIVE = [] include Aws::Structure end |