Class: Aws::Bedrock::Types::GetEvaluationJobResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:job_description]

Instance Attribute Summary collapse

Instance Attribute Details

#application_typeString

Specifies whether the evaluation job is for evaluating a model or evaluating a knowledge base (retrieval and response generation).

Returns:

  • (String)


6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
# File 'lib/aws-sdk-bedrock/types.rb', line 6739

class GetEvaluationJobResponse < Struct.new(
  :job_name,
  :status,
  :job_arn,
  :job_description,
  :role_arn,
  :customer_encryption_key_id,
  :job_type,
  :application_type,
  :evaluation_config,
  :inference_config,
  :output_data_config,
  :creation_time,
  :last_modified_time,
  :failure_messages)
  SENSITIVE = [:job_description]
  include Aws::Structure
end

#creation_timeTime

The time the evaluation job was created.

Returns:

  • (Time)


6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
# File 'lib/aws-sdk-bedrock/types.rb', line 6739

class GetEvaluationJobResponse < Struct.new(
  :job_name,
  :status,
  :job_arn,
  :job_description,
  :role_arn,
  :customer_encryption_key_id,
  :job_type,
  :application_type,
  :evaluation_config,
  :inference_config,
  :output_data_config,
  :creation_time,
  :last_modified_time,
  :failure_messages)
  SENSITIVE = [:job_description]
  include Aws::Structure
end

#customer_encryption_key_idString

The Amazon Resource Name (ARN) of the customer managed encryption key specified when the evaluation job was created.

Returns:

  • (String)


6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
# File 'lib/aws-sdk-bedrock/types.rb', line 6739

class GetEvaluationJobResponse < Struct.new(
  :job_name,
  :status,
  :job_arn,
  :job_description,
  :role_arn,
  :customer_encryption_key_id,
  :job_type,
  :application_type,
  :evaluation_config,
  :inference_config,
  :output_data_config,
  :creation_time,
  :last_modified_time,
  :failure_messages)
  SENSITIVE = [:job_description]
  include Aws::Structure
end

#evaluation_configTypes::EvaluationConfig

Contains the configuration details of either an automated or human-based evaluation job.



6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
# File 'lib/aws-sdk-bedrock/types.rb', line 6739

class GetEvaluationJobResponse < Struct.new(
  :job_name,
  :status,
  :job_arn,
  :job_description,
  :role_arn,
  :customer_encryption_key_id,
  :job_type,
  :application_type,
  :evaluation_config,
  :inference_config,
  :output_data_config,
  :creation_time,
  :last_modified_time,
  :failure_messages)
  SENSITIVE = [:job_description]
  include Aws::Structure
end

#failure_messagesArray<String>

A list of strings that specify why the evaluation job failed to create.

Returns:

  • (Array<String>)


6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
# File 'lib/aws-sdk-bedrock/types.rb', line 6739

class GetEvaluationJobResponse < Struct.new(
  :job_name,
  :status,
  :job_arn,
  :job_description,
  :role_arn,
  :customer_encryption_key_id,
  :job_type,
  :application_type,
  :evaluation_config,
  :inference_config,
  :output_data_config,
  :creation_time,
  :last_modified_time,
  :failure_messages)
  SENSITIVE = [:job_description]
  include Aws::Structure
end

#inference_configTypes::EvaluationInferenceConfig

Contains the configuration details of the inference model used for the evaluation job.



6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
# File 'lib/aws-sdk-bedrock/types.rb', line 6739

class GetEvaluationJobResponse < Struct.new(
  :job_name,
  :status,
  :job_arn,
  :job_description,
  :role_arn,
  :customer_encryption_key_id,
  :job_type,
  :application_type,
  :evaluation_config,
  :inference_config,
  :output_data_config,
  :creation_time,
  :last_modified_time,
  :failure_messages)
  SENSITIVE = [:job_description]
  include Aws::Structure
end

#job_arnString

The Amazon Resource Name (ARN) of the evaluation job.

Returns:

  • (String)


6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
# File 'lib/aws-sdk-bedrock/types.rb', line 6739

class GetEvaluationJobResponse < Struct.new(
  :job_name,
  :status,
  :job_arn,
  :job_description,
  :role_arn,
  :customer_encryption_key_id,
  :job_type,
  :application_type,
  :evaluation_config,
  :inference_config,
  :output_data_config,
  :creation_time,
  :last_modified_time,
  :failure_messages)
  SENSITIVE = [:job_description]
  include Aws::Structure
end

#job_descriptionString

The description of the evaluation job.

Returns:

  • (String)


6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
# File 'lib/aws-sdk-bedrock/types.rb', line 6739

class GetEvaluationJobResponse < Struct.new(
  :job_name,
  :status,
  :job_arn,
  :job_description,
  :role_arn,
  :customer_encryption_key_id,
  :job_type,
  :application_type,
  :evaluation_config,
  :inference_config,
  :output_data_config,
  :creation_time,
  :last_modified_time,
  :failure_messages)
  SENSITIVE = [:job_description]
  include Aws::Structure
end

#job_nameString

The name for the evaluation job.

Returns:

  • (String)


6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
# File 'lib/aws-sdk-bedrock/types.rb', line 6739

class GetEvaluationJobResponse < Struct.new(
  :job_name,
  :status,
  :job_arn,
  :job_description,
  :role_arn,
  :customer_encryption_key_id,
  :job_type,
  :application_type,
  :evaluation_config,
  :inference_config,
  :output_data_config,
  :creation_time,
  :last_modified_time,
  :failure_messages)
  SENSITIVE = [:job_description]
  include Aws::Structure
end

#job_typeString

Specifies whether the evaluation job is automated or human-based.

Returns:

  • (String)


6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
# File 'lib/aws-sdk-bedrock/types.rb', line 6739

class GetEvaluationJobResponse < Struct.new(
  :job_name,
  :status,
  :job_arn,
  :job_description,
  :role_arn,
  :customer_encryption_key_id,
  :job_type,
  :application_type,
  :evaluation_config,
  :inference_config,
  :output_data_config,
  :creation_time,
  :last_modified_time,
  :failure_messages)
  SENSITIVE = [:job_description]
  include Aws::Structure
end

#last_modified_timeTime

The time the evaluation job was last modified.

Returns:

  • (Time)


6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
# File 'lib/aws-sdk-bedrock/types.rb', line 6739

class GetEvaluationJobResponse < Struct.new(
  :job_name,
  :status,
  :job_arn,
  :job_description,
  :role_arn,
  :customer_encryption_key_id,
  :job_type,
  :application_type,
  :evaluation_config,
  :inference_config,
  :output_data_config,
  :creation_time,
  :last_modified_time,
  :failure_messages)
  SENSITIVE = [:job_description]
  include Aws::Structure
end

#output_data_configTypes::EvaluationOutputDataConfig

Contains the configuration details of the Amazon S3 bucket for storing the results of the evaluation job.



6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
# File 'lib/aws-sdk-bedrock/types.rb', line 6739

class GetEvaluationJobResponse < Struct.new(
  :job_name,
  :status,
  :job_arn,
  :job_description,
  :role_arn,
  :customer_encryption_key_id,
  :job_type,
  :application_type,
  :evaluation_config,
  :inference_config,
  :output_data_config,
  :creation_time,
  :last_modified_time,
  :failure_messages)
  SENSITIVE = [:job_description]
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the IAM service role used in the evaluation job.

Returns:

  • (String)


6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
# File 'lib/aws-sdk-bedrock/types.rb', line 6739

class GetEvaluationJobResponse < Struct.new(
  :job_name,
  :status,
  :job_arn,
  :job_description,
  :role_arn,
  :customer_encryption_key_id,
  :job_type,
  :application_type,
  :evaluation_config,
  :inference_config,
  :output_data_config,
  :creation_time,
  :last_modified_time,
  :failure_messages)
  SENSITIVE = [:job_description]
  include Aws::Structure
end

#statusString

The current status of the evaluation job.

Returns:

  • (String)


6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
# File 'lib/aws-sdk-bedrock/types.rb', line 6739

class GetEvaluationJobResponse < Struct.new(
  :job_name,
  :status,
  :job_arn,
  :job_description,
  :role_arn,
  :customer_encryption_key_id,
  :job_type,
  :application_type,
  :evaluation_config,
  :inference_config,
  :output_data_config,
  :creation_time,
  :last_modified_time,
  :failure_messages)
  SENSITIVE = [:job_description]
  include Aws::Structure
end