Class: Aws::Bedrock::Types::GetModelImportJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::GetModelImportJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The time the resource was created.
-
#end_time ⇒ Time
Time that the resource transitioned to terminal state.
-
#failure_message ⇒ String
Information about why the import job failed.
-
#imported_model_arn ⇒ String
The Amazon Resource Name (ARN) of the imported model.
-
#imported_model_kms_key_arn ⇒ String
The imported model is encrypted at rest using this key.
-
#imported_model_name ⇒ String
The name of the imported model.
-
#job_arn ⇒ String
The Amazon Resource Name (ARN) of the import job.
-
#job_name ⇒ String
The name of the import job.
-
#last_modified_time ⇒ Time
Time the resource was last modified.
-
#model_data_source ⇒ Types::ModelDataSource
The data source for the imported model.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role associated with this job.
-
#status ⇒ String
The status of the job.
-
#vpc_config ⇒ Types::VpcConfig
The Virtual Private Cloud (VPC) configuration of the import model job.
Instance Attribute Details
#creation_time ⇒ Time
The time the resource was created.
7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 |
# File 'lib/aws-sdk-bedrock/types.rb', line 7359 class GetModelImportJobResponse < Struct.new( :job_arn, :job_name, :imported_model_name, :imported_model_arn, :role_arn, :model_data_source, :status, :failure_message, :creation_time, :last_modified_time, :end_time, :vpc_config, :imported_model_kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
Time that the resource transitioned to terminal state.
7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 |
# File 'lib/aws-sdk-bedrock/types.rb', line 7359 class GetModelImportJobResponse < Struct.new( :job_arn, :job_name, :imported_model_name, :imported_model_arn, :role_arn, :model_data_source, :status, :failure_message, :creation_time, :last_modified_time, :end_time, :vpc_config, :imported_model_kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#failure_message ⇒ String
Information about why the import job failed.
7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 |
# File 'lib/aws-sdk-bedrock/types.rb', line 7359 class GetModelImportJobResponse < Struct.new( :job_arn, :job_name, :imported_model_name, :imported_model_arn, :role_arn, :model_data_source, :status, :failure_message, :creation_time, :last_modified_time, :end_time, :vpc_config, :imported_model_kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#imported_model_arn ⇒ String
The Amazon Resource Name (ARN) of the imported model.
7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 |
# File 'lib/aws-sdk-bedrock/types.rb', line 7359 class GetModelImportJobResponse < Struct.new( :job_arn, :job_name, :imported_model_name, :imported_model_arn, :role_arn, :model_data_source, :status, :failure_message, :creation_time, :last_modified_time, :end_time, :vpc_config, :imported_model_kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#imported_model_kms_key_arn ⇒ String
The imported model is encrypted at rest using this key.
7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 |
# File 'lib/aws-sdk-bedrock/types.rb', line 7359 class GetModelImportJobResponse < Struct.new( :job_arn, :job_name, :imported_model_name, :imported_model_arn, :role_arn, :model_data_source, :status, :failure_message, :creation_time, :last_modified_time, :end_time, :vpc_config, :imported_model_kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#imported_model_name ⇒ String
The name of the imported model.
7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 |
# File 'lib/aws-sdk-bedrock/types.rb', line 7359 class GetModelImportJobResponse < Struct.new( :job_arn, :job_name, :imported_model_name, :imported_model_arn, :role_arn, :model_data_source, :status, :failure_message, :creation_time, :last_modified_time, :end_time, :vpc_config, :imported_model_kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#job_arn ⇒ String
The Amazon Resource Name (ARN) of the import job.
7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 |
# File 'lib/aws-sdk-bedrock/types.rb', line 7359 class GetModelImportJobResponse < Struct.new( :job_arn, :job_name, :imported_model_name, :imported_model_arn, :role_arn, :model_data_source, :status, :failure_message, :creation_time, :last_modified_time, :end_time, :vpc_config, :imported_model_kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The name of the import job.
7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 |
# File 'lib/aws-sdk-bedrock/types.rb', line 7359 class GetModelImportJobResponse < Struct.new( :job_arn, :job_name, :imported_model_name, :imported_model_arn, :role_arn, :model_data_source, :status, :failure_message, :creation_time, :last_modified_time, :end_time, :vpc_config, :imported_model_kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
Time the resource was last modified.
7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 |
# File 'lib/aws-sdk-bedrock/types.rb', line 7359 class GetModelImportJobResponse < Struct.new( :job_arn, :job_name, :imported_model_name, :imported_model_arn, :role_arn, :model_data_source, :status, :failure_message, :creation_time, :last_modified_time, :end_time, :vpc_config, :imported_model_kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#model_data_source ⇒ Types::ModelDataSource
The data source for the imported model.
7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 |
# File 'lib/aws-sdk-bedrock/types.rb', line 7359 class GetModelImportJobResponse < Struct.new( :job_arn, :job_name, :imported_model_name, :imported_model_arn, :role_arn, :model_data_source, :status, :failure_message, :creation_time, :last_modified_time, :end_time, :vpc_config, :imported_model_kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role associated with this job.
7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 |
# File 'lib/aws-sdk-bedrock/types.rb', line 7359 class GetModelImportJobResponse < Struct.new( :job_arn, :job_name, :imported_model_name, :imported_model_arn, :role_arn, :model_data_source, :status, :failure_message, :creation_time, :last_modified_time, :end_time, :vpc_config, :imported_model_kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the job. A successful job transitions from in-progress to completed when the imported model is ready to use. If the job failed, the failure message contains information about why the job failed.
7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 |
# File 'lib/aws-sdk-bedrock/types.rb', line 7359 class GetModelImportJobResponse < Struct.new( :job_arn, :job_name, :imported_model_name, :imported_model_arn, :role_arn, :model_data_source, :status, :failure_message, :creation_time, :last_modified_time, :end_time, :vpc_config, :imported_model_kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
The Virtual Private Cloud (VPC) configuration of the import model job.
7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 |
# File 'lib/aws-sdk-bedrock/types.rb', line 7359 class GetModelImportJobResponse < Struct.new( :job_arn, :job_name, :imported_model_name, :imported_model_arn, :role_arn, :model_data_source, :status, :failure_message, :creation_time, :last_modified_time, :end_time, :vpc_config, :imported_model_kms_key_arn) SENSITIVE = [] include Aws::Structure end |