Class: Aws::Bedrock::Types::GuardrailSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Contains details about a guardrail.

This data type is used in the following API operations:

  • ListGuardrails response body][1

^

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_ListGuardrails.html#API_ListGuardrails_ResponseSyntax

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the guardrail.

Returns:

  • (String)


9128
9129
9130
9131
9132
9133
9134
9135
9136
9137
9138
9139
9140
# File 'lib/aws-sdk-bedrock/types.rb', line 9128

class GuardrailSummary < Struct.new(
  :id,
  :arn,
  :status,
  :name,
  :description,
  :version,
  :created_at,
  :updated_at,
  :cross_region_details)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#created_atTime

The date and time at which the guardrail was created.

Returns:

  • (Time)


9128
9129
9130
9131
9132
9133
9134
9135
9136
9137
9138
9139
9140
# File 'lib/aws-sdk-bedrock/types.rb', line 9128

class GuardrailSummary < Struct.new(
  :id,
  :arn,
  :status,
  :name,
  :description,
  :version,
  :created_at,
  :updated_at,
  :cross_region_details)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#cross_region_detailsTypes::GuardrailCrossRegionDetails

Details about the system-defined guardrail profile that you’re using with your guardrail, including the guardrail profile ID and Amazon Resource Name (ARN).



9128
9129
9130
9131
9132
9133
9134
9135
9136
9137
9138
9139
9140
# File 'lib/aws-sdk-bedrock/types.rb', line 9128

class GuardrailSummary < Struct.new(
  :id,
  :arn,
  :status,
  :name,
  :description,
  :version,
  :created_at,
  :updated_at,
  :cross_region_details)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#descriptionString

A description of the guardrail.

Returns:

  • (String)


9128
9129
9130
9131
9132
9133
9134
9135
9136
9137
9138
9139
9140
# File 'lib/aws-sdk-bedrock/types.rb', line 9128

class GuardrailSummary < Struct.new(
  :id,
  :arn,
  :status,
  :name,
  :description,
  :version,
  :created_at,
  :updated_at,
  :cross_region_details)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#idString

The unique identifier of the guardrail.

Returns:

  • (String)


9128
9129
9130
9131
9132
9133
9134
9135
9136
9137
9138
9139
9140
# File 'lib/aws-sdk-bedrock/types.rb', line 9128

class GuardrailSummary < Struct.new(
  :id,
  :arn,
  :status,
  :name,
  :description,
  :version,
  :created_at,
  :updated_at,
  :cross_region_details)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#nameString

The name of the guardrail.

Returns:

  • (String)


9128
9129
9130
9131
9132
9133
9134
9135
9136
9137
9138
9139
9140
# File 'lib/aws-sdk-bedrock/types.rb', line 9128

class GuardrailSummary < Struct.new(
  :id,
  :arn,
  :status,
  :name,
  :description,
  :version,
  :created_at,
  :updated_at,
  :cross_region_details)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#statusString

The status of the guardrail.

Returns:

  • (String)


9128
9129
9130
9131
9132
9133
9134
9135
9136
9137
9138
9139
9140
# File 'lib/aws-sdk-bedrock/types.rb', line 9128

class GuardrailSummary < Struct.new(
  :id,
  :arn,
  :status,
  :name,
  :description,
  :version,
  :created_at,
  :updated_at,
  :cross_region_details)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#updated_atTime

The date and time at which the guardrail was last updated.

Returns:

  • (Time)


9128
9129
9130
9131
9132
9133
9134
9135
9136
9137
9138
9139
9140
# File 'lib/aws-sdk-bedrock/types.rb', line 9128

class GuardrailSummary < Struct.new(
  :id,
  :arn,
  :status,
  :name,
  :description,
  :version,
  :created_at,
  :updated_at,
  :cross_region_details)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#versionString

The version of the guardrail.

Returns:

  • (String)


9128
9129
9130
9131
9132
9133
9134
9135
9136
9137
9138
9139
9140
# File 'lib/aws-sdk-bedrock/types.rb', line 9128

class GuardrailSummary < Struct.new(
  :id,
  :arn,
  :status,
  :name,
  :description,
  :version,
  :created_at,
  :updated_at,
  :cross_region_details)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end