Class: Aws::Bedrock::Types::GuardrailTopicPolicyConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Contains details about topics that the guardrail should identify and deny.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#tier_configTypes::GuardrailTopicsTierConfig

The tier that your guardrail uses for denied topic filters.



9327
9328
9329
9330
9331
9332
# File 'lib/aws-sdk-bedrock/types.rb', line 9327

class GuardrailTopicPolicyConfig < Struct.new(
  :topics_config,
  :tier_config)
  SENSITIVE = []
  include Aws::Structure
end

#topics_configArray<Types::GuardrailTopicConfig>

A list of policies related to topics that the guardrail should deny.

Returns:



9327
9328
9329
9330
9331
9332
# File 'lib/aws-sdk-bedrock/types.rb', line 9327

class GuardrailTopicPolicyConfig < Struct.new(
  :topics_config,
  :tier_config)
  SENSITIVE = []
  include Aws::Structure
end