Class: Aws::Bedrock::Types::GuardrailWord
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::GuardrailWord
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
A word configured for the guardrail.
Constant Summary collapse
- SENSITIVE =
[:input_action, :output_action]
Instance Attribute Summary collapse
-
#input_action ⇒ String
The action to take when harmful content is detected in the input.
-
#input_enabled ⇒ Boolean
Indicates whether guardrail evaluation is enabled on the input.
-
#output_action ⇒ String
The action to take when harmful content is detected in the output.
-
#output_enabled ⇒ Boolean
Indicates whether guardrail evaluation is enabled on the output.
-
#text ⇒ String
Text of the word configured for the guardrail to block.
Instance Attribute Details
#input_action ⇒ String
The action to take when harmful content is detected in the input. Supported values include:
-
‘BLOCK` – Block the content and replace it with blocked messaging.
-
‘NONE` – Take no action but return detection information in the trace response.
9428 9429 9430 9431 9432 9433 9434 9435 9436 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9428 class GuardrailWord < Struct.new( :text, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:input_action, :output_action] include Aws::Structure end |
#input_enabled ⇒ Boolean
Indicates whether guardrail evaluation is enabled on the input. When disabled, you aren’t charged for the evaluation. The evaluation doesn’t appear in the response.
9428 9429 9430 9431 9432 9433 9434 9435 9436 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9428 class GuardrailWord < Struct.new( :text, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:input_action, :output_action] include Aws::Structure end |
#output_action ⇒ String
The action to take when harmful content is detected in the output. Supported values include:
-
‘BLOCK` – Block the content and replace it with blocked messaging.
-
‘NONE` – Take no action but return detection information in the trace response.
9428 9429 9430 9431 9432 9433 9434 9435 9436 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9428 class GuardrailWord < Struct.new( :text, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:input_action, :output_action] include Aws::Structure end |
#output_enabled ⇒ Boolean
Indicates whether guardrail evaluation is enabled on the output. When disabled, you aren’t charged for the evaluation. The evaluation doesn’t appear in the response.
9428 9429 9430 9431 9432 9433 9434 9435 9436 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9428 class GuardrailWord < Struct.new( :text, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:input_action, :output_action] include Aws::Structure end |
#text ⇒ String
Text of the word configured for the guardrail to block.
9428 9429 9430 9431 9432 9433 9434 9435 9436 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9428 class GuardrailWord < Struct.new( :text, :input_action, :output_action, :input_enabled, :output_enabled) SENSITIVE = [:input_action, :output_action] include Aws::Structure end |