Class: Aws::Bedrock::Types::InferenceProfileSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::InferenceProfileSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Contains information about an inference profile.
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The time at which the inference profile was created.
-
#description ⇒ String
The description of the inference profile.
-
#inference_profile_arn ⇒ String
The Amazon Resource Name (ARN) of the inference profile.
-
#inference_profile_id ⇒ String
The unique identifier of the inference profile.
-
#inference_profile_name ⇒ String
The name of the inference profile.
-
#models ⇒ Array<Types::InferenceProfileModel>
A list of information about each model in the inference profile.
-
#status ⇒ String
The status of the inference profile.
-
#type ⇒ String
The type of the inference profile.
-
#updated_at ⇒ Time
The time at which the inference profile was last updated.
Instance Attribute Details
#created_at ⇒ Time
The time at which the inference profile was created.
9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 9825 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9813 class InferenceProfileSummary < Struct.new( :inference_profile_name, :description, :created_at, :updated_at, :inference_profile_arn, :models, :inference_profile_id, :status, :type) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The description of the inference profile.
9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 9825 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9813 class InferenceProfileSummary < Struct.new( :inference_profile_name, :description, :created_at, :updated_at, :inference_profile_arn, :models, :inference_profile_id, :status, :type) SENSITIVE = [:description] include Aws::Structure end |
#inference_profile_arn ⇒ String
The Amazon Resource Name (ARN) of the inference profile.
9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 9825 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9813 class InferenceProfileSummary < Struct.new( :inference_profile_name, :description, :created_at, :updated_at, :inference_profile_arn, :models, :inference_profile_id, :status, :type) SENSITIVE = [:description] include Aws::Structure end |
#inference_profile_id ⇒ String
The unique identifier of the inference profile.
9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 9825 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9813 class InferenceProfileSummary < Struct.new( :inference_profile_name, :description, :created_at, :updated_at, :inference_profile_arn, :models, :inference_profile_id, :status, :type) SENSITIVE = [:description] include Aws::Structure end |
#inference_profile_name ⇒ String
The name of the inference profile.
9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 9825 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9813 class InferenceProfileSummary < Struct.new( :inference_profile_name, :description, :created_at, :updated_at, :inference_profile_arn, :models, :inference_profile_id, :status, :type) SENSITIVE = [:description] include Aws::Structure end |
#models ⇒ Array<Types::InferenceProfileModel>
A list of information about each model in the inference profile.
9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 9825 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9813 class InferenceProfileSummary < Struct.new( :inference_profile_name, :description, :created_at, :updated_at, :inference_profile_arn, :models, :inference_profile_id, :status, :type) SENSITIVE = [:description] include Aws::Structure end |
#status ⇒ String
The status of the inference profile. ‘ACTIVE` means that the inference profile is ready to be used.
9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 9825 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9813 class InferenceProfileSummary < Struct.new( :inference_profile_name, :description, :created_at, :updated_at, :inference_profile_arn, :models, :inference_profile_id, :status, :type) SENSITIVE = [:description] include Aws::Structure end |
#type ⇒ String
The type of the inference profile. The following types are possible:
-
‘SYSTEM_DEFINED` – The inference profile is defined by Amazon Bedrock. You can route inference requests across regions with these inference profiles.
-
‘APPLICATION` – The inference profile was created by a user. This type of inference profile can track metrics and costs when invoking the model in it. The inference profile may route requests to one or multiple regions.
9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 9825 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9813 class InferenceProfileSummary < Struct.new( :inference_profile_name, :description, :created_at, :updated_at, :inference_profile_arn, :models, :inference_profile_id, :status, :type) SENSITIVE = [:description] include Aws::Structure end |
#updated_at ⇒ Time
The time at which the inference profile was last updated.
9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 9825 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9813 class InferenceProfileSummary < Struct.new( :inference_profile_name, :description, :created_at, :updated_at, :inference_profile_arn, :models, :inference_profile_id, :status, :type) SENSITIVE = [:description] include Aws::Structure end |