Class: Aws::Bedrock::Types::InvocationLogsConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::InvocationLogsConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Settings for using invocation logs to customize a model.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#invocation_log_source ⇒ Types::InvocationLogSource
The source of the invocation logs.
-
#request_metadata_filters ⇒ Types::RequestMetadataFilters
Rules for filtering invocation logs based on request metadata.
-
#use_prompt_response ⇒ Boolean
Whether to use the model’s response for training, or just the prompt.
Instance Attribute Details
#invocation_log_source ⇒ Types::InvocationLogSource
The source of the invocation logs.
9804 9805 9806 9807 9808 9809 9810 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9804 class InvocationLogsConfig < Struct.new( :use_prompt_response, :invocation_log_source, :request_metadata_filters) SENSITIVE = [] include Aws::Structure end |
#request_metadata_filters ⇒ Types::RequestMetadataFilters
Rules for filtering invocation logs based on request metadata.
9804 9805 9806 9807 9808 9809 9810 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9804 class InvocationLogsConfig < Struct.new( :use_prompt_response, :invocation_log_source, :request_metadata_filters) SENSITIVE = [] include Aws::Structure end |
#use_prompt_response ⇒ Boolean
Whether to use the model’s response for training, or just the prompt. The default value is ‘False`.
9804 9805 9806 9807 9808 9809 9810 |
# File 'lib/aws-sdk-bedrock/types.rb', line 9804 class InvocationLogsConfig < Struct.new( :use_prompt_response, :invocation_log_source, :request_metadata_filters) SENSITIVE = [] include Aws::Structure end |