Class: Aws::Bedrock::Types::MetadataConfigurationForReranking
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::MetadataConfigurationForReranking
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Configuration for how metadata should be used during the reranking process in Knowledge Base vector searches. This determines which metadata fields are included or excluded when reordering search results.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#selection_mode ⇒ String
The mode for selecting which metadata fields to include in the reranking process.
-
#selective_mode_configuration ⇒ Types::RerankingMetadataSelectiveModeConfiguration
Configuration for selective mode, which allows you to explicitly include or exclude specific metadata fields during reranking.
Instance Attribute Details
#selection_mode ⇒ String
The mode for selecting which metadata fields to include in the reranking process. Valid values are ALL (use all available metadata fields) or SELECTIVE (use only specified fields).
11517 11518 11519 11520 11521 11522 |
# File 'lib/aws-sdk-bedrock/types.rb', line 11517 class MetadataConfigurationForReranking < Struct.new( :selection_mode, :selective_mode_configuration) SENSITIVE = [] include Aws::Structure end |
#selective_mode_configuration ⇒ Types::RerankingMetadataSelectiveModeConfiguration
Configuration for selective mode, which allows you to explicitly include or exclude specific metadata fields during reranking. This is only used when selectionMode is set to SELECTIVE.
11517 11518 11519 11520 11521 11522 |
# File 'lib/aws-sdk-bedrock/types.rb', line 11517 class MetadataConfigurationForReranking < Struct.new( :selection_mode, :selective_mode_configuration) SENSITIVE = [] include Aws::Structure end |