Class: Aws::Bedrock::Types::ModelConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::ModelConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Contains the configuration for a model used in an advanced prompt optimization job, including the model ID and inference parameters.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_model_request_fields ⇒ Hash<String,Hash,Array,String,Numeric,Boolean>
Additional model request fields.
-
#inference_config ⇒ Types::InferenceConfiguration
The inference configuration for the model, including parameters such as maximum tokens, temperature, and top-p.
-
#model_id ⇒ String
The model to use for optimization.
Instance Attribute Details
#additional_model_request_fields ⇒ Hash<String,Hash,Array,String,Numeric,Boolean>
Additional model request fields. Use this to pass model-specific parameters that are not included in the standard inference configuration.
11696 11697 11698 11699 11700 11701 11702 |
# File 'lib/aws-sdk-bedrock/types.rb', line 11696 class ModelConfiguration < Struct.new( :model_id, :inference_config, :additional_model_request_fields) SENSITIVE = [] include Aws::Structure end |
#inference_config ⇒ Types::InferenceConfiguration
The inference configuration for the model, including parameters such as maximum tokens, temperature, and top-p.
11696 11697 11698 11699 11700 11701 11702 |
# File 'lib/aws-sdk-bedrock/types.rb', line 11696 class ModelConfiguration < Struct.new( :model_id, :inference_config, :additional_model_request_fields) SENSITIVE = [] include Aws::Structure end |
#model_id ⇒ String
The model to use for optimization. The value depends on the resource that you use:
-
If you use a base model, specify the model ID or its ARN. For a list of model IDs, see Models at a glance in the Amazon Bedrock User Guide.
-
If you use a cross-Region (system-defined) inference profile, specify the inference profile ID or its ARN. For a list of inference profile IDs, see Supported Regions and models for inference profiles in the Amazon Bedrock User Guide.
-
If you use an application inference profile, specify its full ARN, including the account ID and Region.
11696 11697 11698 11699 11700 11701 11702 |
# File 'lib/aws-sdk-bedrock/types.rb', line 11696 class ModelConfiguration < Struct.new( :model_id, :inference_config, :additional_model_request_fields) SENSITIVE = [] include Aws::Structure end |