Class: Aws::Bedrock::Types::ModelCopyJobSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::ModelCopyJobSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Contains details about each model copy job.
This data type is used in the following API operations:
- ListModelCopyJobs response][1
^
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The time that the model copy job was created.
-
#failure_message ⇒ String
If a model fails to be copied, a message describing why the job failed is included here.
-
#job_arn ⇒ String
The Amazon Resoource Name (ARN) of the model copy job.
-
#source_account_id ⇒ String
The unique identifier of the account that the model being copied originated from.
-
#source_model_arn ⇒ String
The Amazon Resource Name (ARN) of the original model being copied.
-
#source_model_name ⇒ String
The name of the original model being copied.
-
#status ⇒ String
The status of the model copy job.
-
#target_model_arn ⇒ String
The Amazon Resource Name (ARN) of the copied model.
-
#target_model_kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key used to encrypt the copied model.
-
#target_model_name ⇒ String
The name of the copied model.
-
#target_model_tags ⇒ Array<Types::Tag>
Tags associated with the copied model.
Instance Attribute Details
#creation_time ⇒ Time
The time that the model copy job was created.
11693 11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 |
# File 'lib/aws-sdk-bedrock/types.rb', line 11693 class ModelCopyJobSummary < Struct.new( :job_arn, :status, :creation_time, :target_model_arn, :target_model_name, :source_account_id, :source_model_arn, :target_model_kms_key_arn, :target_model_tags, :failure_message, :source_model_name) SENSITIVE = [] include Aws::Structure end |
#failure_message ⇒ String
If a model fails to be copied, a message describing why the job failed is included here.
11693 11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 |
# File 'lib/aws-sdk-bedrock/types.rb', line 11693 class ModelCopyJobSummary < Struct.new( :job_arn, :status, :creation_time, :target_model_arn, :target_model_name, :source_account_id, :source_model_arn, :target_model_kms_key_arn, :target_model_tags, :failure_message, :source_model_name) SENSITIVE = [] include Aws::Structure end |
#job_arn ⇒ String
The Amazon Resoource Name (ARN) of the model copy job.
11693 11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 |
# File 'lib/aws-sdk-bedrock/types.rb', line 11693 class ModelCopyJobSummary < Struct.new( :job_arn, :status, :creation_time, :target_model_arn, :target_model_name, :source_account_id, :source_model_arn, :target_model_kms_key_arn, :target_model_tags, :failure_message, :source_model_name) SENSITIVE = [] include Aws::Structure end |
#source_account_id ⇒ String
The unique identifier of the account that the model being copied originated from.
11693 11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 |
# File 'lib/aws-sdk-bedrock/types.rb', line 11693 class ModelCopyJobSummary < Struct.new( :job_arn, :status, :creation_time, :target_model_arn, :target_model_name, :source_account_id, :source_model_arn, :target_model_kms_key_arn, :target_model_tags, :failure_message, :source_model_name) SENSITIVE = [] include Aws::Structure end |
#source_model_arn ⇒ String
The Amazon Resource Name (ARN) of the original model being copied.
11693 11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 |
# File 'lib/aws-sdk-bedrock/types.rb', line 11693 class ModelCopyJobSummary < Struct.new( :job_arn, :status, :creation_time, :target_model_arn, :target_model_name, :source_account_id, :source_model_arn, :target_model_kms_key_arn, :target_model_tags, :failure_message, :source_model_name) SENSITIVE = [] include Aws::Structure end |
#source_model_name ⇒ String
The name of the original model being copied.
11693 11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 |
# File 'lib/aws-sdk-bedrock/types.rb', line 11693 class ModelCopyJobSummary < Struct.new( :job_arn, :status, :creation_time, :target_model_arn, :target_model_name, :source_account_id, :source_model_arn, :target_model_kms_key_arn, :target_model_tags, :failure_message, :source_model_name) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the model copy job.
11693 11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 |
# File 'lib/aws-sdk-bedrock/types.rb', line 11693 class ModelCopyJobSummary < Struct.new( :job_arn, :status, :creation_time, :target_model_arn, :target_model_name, :source_account_id, :source_model_arn, :target_model_kms_key_arn, :target_model_tags, :failure_message, :source_model_name) SENSITIVE = [] include Aws::Structure end |
#target_model_arn ⇒ String
The Amazon Resource Name (ARN) of the copied model.
11693 11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 |
# File 'lib/aws-sdk-bedrock/types.rb', line 11693 class ModelCopyJobSummary < Struct.new( :job_arn, :status, :creation_time, :target_model_arn, :target_model_name, :source_account_id, :source_model_arn, :target_model_kms_key_arn, :target_model_tags, :failure_message, :source_model_name) SENSITIVE = [] include Aws::Structure end |
#target_model_kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key used to encrypt the copied model.
11693 11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 |
# File 'lib/aws-sdk-bedrock/types.rb', line 11693 class ModelCopyJobSummary < Struct.new( :job_arn, :status, :creation_time, :target_model_arn, :target_model_name, :source_account_id, :source_model_arn, :target_model_kms_key_arn, :target_model_tags, :failure_message, :source_model_name) SENSITIVE = [] include Aws::Structure end |
#target_model_name ⇒ String
The name of the copied model.
11693 11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 |
# File 'lib/aws-sdk-bedrock/types.rb', line 11693 class ModelCopyJobSummary < Struct.new( :job_arn, :status, :creation_time, :target_model_arn, :target_model_name, :source_account_id, :source_model_arn, :target_model_kms_key_arn, :target_model_tags, :failure_message, :source_model_name) SENSITIVE = [] include Aws::Structure end |
#target_model_tags ⇒ Array<Types::Tag>
Tags associated with the copied model.
11693 11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 |
# File 'lib/aws-sdk-bedrock/types.rb', line 11693 class ModelCopyJobSummary < Struct.new( :job_arn, :status, :creation_time, :target_model_arn, :target_model_name, :source_account_id, :source_model_arn, :target_model_kms_key_arn, :target_model_tags, :failure_message, :source_model_name) SENSITIVE = [] include Aws::Structure end |