Class: Aws::Bedrock::Types::ModelDataSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::ModelDataSource
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Note:
ModelDataSource is a union - when making an API calls you must set exactly one of the members.
Note:
ModelDataSource is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ModelDataSource corresponding to the set member.
The data source of the model to import.
Direct Known Subclasses
Defined Under Namespace
Classes: S3DataSource, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#s3_data_source ⇒ Types::S3DataSource
The Amazon S3 data source of the model to import.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#s3_data_source ⇒ Types::S3DataSource
The Amazon S3 data source of the model to import.
11707 11708 11709 11710 11711 11712 11713 11714 11715 11716 |
# File 'lib/aws-sdk-bedrock/types.rb', line 11707 class ModelDataSource < Struct.new( :s3_data_source, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class S3DataSource < ModelDataSource; end class Unknown < ModelDataSource; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
11707 11708 11709 |
# File 'lib/aws-sdk-bedrock/types.rb', line 11707 def unknown @unknown end |