Class: Aws::Bedrock::Types::ModelPackageArnDataSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::ModelPackageArnDataSource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Contains the Amazon Resource Name (ARN) of a SageMaker AI model package to use as the data source for a custom model.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#model_package_arn ⇒ String
The Amazon Resource Name (ARN) of the SageMaker AI model package.
Instance Attribute Details
#model_package_arn ⇒ String
The Amazon Resource Name (ARN) of the SageMaker AI model package. The ARN must be for a model package of ‘restricted` type.
To use a model package ARN, you must have the ‘sagemaker:DescribeModelPackage` and `sagemaker:AccessModelPackageData` permissions on the model package resource.
12166 12167 12168 12169 12170 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12166 class ModelPackageArnDataSource < Struct.new( :model_package_arn) SENSITIVE = [] include Aws::Structure end |