Class: Aws::Bedrock::Types::PromptTemplate
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::PromptTemplate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
The template for the prompt that’s sent to the model for response generation.
Constant Summary collapse
- SENSITIVE =
[:text_prompt_template]
Instance Attribute Summary collapse
-
#text_prompt_template ⇒ String
The template for the prompt that’s sent to the model for response generation.
Instance Attribute Details
#text_prompt_template ⇒ String
The template for the prompt that’s sent to the model for response generation. You can include prompt placeholders, which become replaced before the prompt is sent to the model to provide instructions and context to the model. In addition, you can include XML tags to delineate meaningful sections of the prompt template.
For more information, see [Knowledge base prompt template] and [Use XML tags with Anthropic Claude models].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/kb-test-config.html [2]: docs.anthropic.com/en/docs/build-with-claude/prompt-engineering/use-xml-tags
12348 12349 12350 12351 12352 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12348 class PromptTemplate < Struct.new( :text_prompt_template) SENSITIVE = [:text_prompt_template] include Aws::Structure end |