Class: Aws::Bedrock::Types::PromptTemplate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

The template for the prompt that’s sent to the model for response generation.

Constant Summary collapse

SENSITIVE =
[:text_prompt_template]

Instance Attribute Summary collapse

Instance Attribute Details

#text_prompt_templateString

The template for the prompt that’s sent to the model for response generation. You can include prompt placeholders, which become replaced before the prompt is sent to the model to provide instructions and context to the model. In addition, you can include XML tags to delineate meaningful sections of the prompt template.

For more information, see [Knowledge base prompt template] and [Use XML tags with Anthropic Claude models].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/kb-test-config.html [2]: docs.anthropic.com/en/docs/build-with-claude/prompt-engineering/use-xml-tags

Returns:

  • (String)


12243
12244
12245
12246
12247
# File 'lib/aws-sdk-bedrock/types.rb', line 12243

class PromptTemplate < Struct.new(
  :text_prompt_template)
  SENSITIVE = [:text_prompt_template]
  include Aws::Structure
end