Class: Aws::Bedrock::Types::ProvisionedModelSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

A summary of information about a Provisioned Throughput.

This data type is used in the following API operations:

  • ListProvisionedThroughputs response][1

^

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_ListProvisionedModelThroughputs.html#API_ListProvisionedModelThroughputs_ResponseSyntax

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#commitment_durationString

The duration for which the Provisioned Throughput was committed.

Returns:

  • (String)


12424
12425
12426
12427
12428
12429
12430
12431
12432
12433
12434
12435
12436
12437
12438
12439
# File 'lib/aws-sdk-bedrock/types.rb', line 12424

class ProvisionedModelSummary < Struct.new(
  :provisioned_model_name,
  :provisioned_model_arn,
  :model_arn,
  :desired_model_arn,
  :foundation_model_arn,
  :model_units,
  :desired_model_units,
  :status,
  :commitment_duration,
  :commitment_expiration_time,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#commitment_expiration_timeTime

The timestamp for when the commitment term of the Provisioned Throughput expires.

Returns:

  • (Time)


12424
12425
12426
12427
12428
12429
12430
12431
12432
12433
12434
12435
12436
12437
12438
12439
# File 'lib/aws-sdk-bedrock/types.rb', line 12424

class ProvisionedModelSummary < Struct.new(
  :provisioned_model_name,
  :provisioned_model_arn,
  :model_arn,
  :desired_model_arn,
  :foundation_model_arn,
  :model_units,
  :desired_model_units,
  :status,
  :commitment_duration,
  :commitment_expiration_time,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The time that the Provisioned Throughput was created.

Returns:

  • (Time)


12424
12425
12426
12427
12428
12429
12430
12431
12432
12433
12434
12435
12436
12437
12438
12439
# File 'lib/aws-sdk-bedrock/types.rb', line 12424

class ProvisionedModelSummary < Struct.new(
  :provisioned_model_name,
  :provisioned_model_arn,
  :model_arn,
  :desired_model_arn,
  :foundation_model_arn,
  :model_units,
  :desired_model_units,
  :status,
  :commitment_duration,
  :commitment_expiration_time,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#desired_model_arnString

The Amazon Resource Name (ARN) of the model requested to be associated to this Provisioned Throughput. This value differs from the ‘modelArn` if updating hasn’t completed.

Returns:

  • (String)


12424
12425
12426
12427
12428
12429
12430
12431
12432
12433
12434
12435
12436
12437
12438
12439
# File 'lib/aws-sdk-bedrock/types.rb', line 12424

class ProvisionedModelSummary < Struct.new(
  :provisioned_model_name,
  :provisioned_model_arn,
  :model_arn,
  :desired_model_arn,
  :foundation_model_arn,
  :model_units,
  :desired_model_units,
  :status,
  :commitment_duration,
  :commitment_expiration_time,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#desired_model_unitsInteger

The number of model units that was requested to be allocated to the Provisioned Throughput.

Returns:

  • (Integer)


12424
12425
12426
12427
12428
12429
12430
12431
12432
12433
12434
12435
12436
12437
12438
12439
# File 'lib/aws-sdk-bedrock/types.rb', line 12424

class ProvisionedModelSummary < Struct.new(
  :provisioned_model_name,
  :provisioned_model_arn,
  :model_arn,
  :desired_model_arn,
  :foundation_model_arn,
  :model_units,
  :desired_model_units,
  :status,
  :commitment_duration,
  :commitment_expiration_time,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#foundation_model_arnString

The Amazon Resource Name (ARN) of the base model for which the Provisioned Throughput was created, or of the base model that the custom model for which the Provisioned Throughput was created was customized.

Returns:

  • (String)


12424
12425
12426
12427
12428
12429
12430
12431
12432
12433
12434
12435
12436
12437
12438
12439
# File 'lib/aws-sdk-bedrock/types.rb', line 12424

class ProvisionedModelSummary < Struct.new(
  :provisioned_model_name,
  :provisioned_model_arn,
  :model_arn,
  :desired_model_arn,
  :foundation_model_arn,
  :model_units,
  :desired_model_units,
  :status,
  :commitment_duration,
  :commitment_expiration_time,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The time that the Provisioned Throughput was last modified.

Returns:

  • (Time)


12424
12425
12426
12427
12428
12429
12430
12431
12432
12433
12434
12435
12436
12437
12438
12439
# File 'lib/aws-sdk-bedrock/types.rb', line 12424

class ProvisionedModelSummary < Struct.new(
  :provisioned_model_name,
  :provisioned_model_arn,
  :model_arn,
  :desired_model_arn,
  :foundation_model_arn,
  :model_units,
  :desired_model_units,
  :status,
  :commitment_duration,
  :commitment_expiration_time,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#model_arnString

The Amazon Resource Name (ARN) of the model associated with the Provisioned Throughput.

Returns:

  • (String)


12424
12425
12426
12427
12428
12429
12430
12431
12432
12433
12434
12435
12436
12437
12438
12439
# File 'lib/aws-sdk-bedrock/types.rb', line 12424

class ProvisionedModelSummary < Struct.new(
  :provisioned_model_name,
  :provisioned_model_arn,
  :model_arn,
  :desired_model_arn,
  :foundation_model_arn,
  :model_units,
  :desired_model_units,
  :status,
  :commitment_duration,
  :commitment_expiration_time,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#model_unitsInteger

The number of model units allocated to the Provisioned Throughput.

Returns:

  • (Integer)


12424
12425
12426
12427
12428
12429
12430
12431
12432
12433
12434
12435
12436
12437
12438
12439
# File 'lib/aws-sdk-bedrock/types.rb', line 12424

class ProvisionedModelSummary < Struct.new(
  :provisioned_model_name,
  :provisioned_model_arn,
  :model_arn,
  :desired_model_arn,
  :foundation_model_arn,
  :model_units,
  :desired_model_units,
  :status,
  :commitment_duration,
  :commitment_expiration_time,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#provisioned_model_arnString

The Amazon Resource Name (ARN) of the Provisioned Throughput.

Returns:

  • (String)


12424
12425
12426
12427
12428
12429
12430
12431
12432
12433
12434
12435
12436
12437
12438
12439
# File 'lib/aws-sdk-bedrock/types.rb', line 12424

class ProvisionedModelSummary < Struct.new(
  :provisioned_model_name,
  :provisioned_model_arn,
  :model_arn,
  :desired_model_arn,
  :foundation_model_arn,
  :model_units,
  :desired_model_units,
  :status,
  :commitment_duration,
  :commitment_expiration_time,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#provisioned_model_nameString

The name of the Provisioned Throughput.

Returns:

  • (String)


12424
12425
12426
12427
12428
12429
12430
12431
12432
12433
12434
12435
12436
12437
12438
12439
# File 'lib/aws-sdk-bedrock/types.rb', line 12424

class ProvisionedModelSummary < Struct.new(
  :provisioned_model_name,
  :provisioned_model_arn,
  :model_arn,
  :desired_model_arn,
  :foundation_model_arn,
  :model_units,
  :desired_model_units,
  :status,
  :commitment_duration,
  :commitment_expiration_time,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the Provisioned Throughput.

Returns:

  • (String)


12424
12425
12426
12427
12428
12429
12430
12431
12432
12433
12434
12435
12436
12437
12438
12439
# File 'lib/aws-sdk-bedrock/types.rb', line 12424

class ProvisionedModelSummary < Struct.new(
  :provisioned_model_name,
  :provisioned_model_arn,
  :model_arn,
  :desired_model_arn,
  :foundation_model_arn,
  :model_units,
  :desired_model_units,
  :status,
  :commitment_duration,
  :commitment_expiration_time,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end