Class: Aws::Bedrock::Types::ProvisionedModelSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::ProvisionedModelSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
A summary of information about a Provisioned Throughput.
This data type is used in the following API operations:
- ListProvisionedThroughputs response][1
^
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#commitment_duration ⇒ String
The duration for which the Provisioned Throughput was committed.
-
#commitment_expiration_time ⇒ Time
The timestamp for when the commitment term of the Provisioned Throughput expires.
-
#creation_time ⇒ Time
The time that the Provisioned Throughput was created.
-
#desired_model_arn ⇒ String
The Amazon Resource Name (ARN) of the model requested to be associated to this Provisioned Throughput.
-
#desired_model_units ⇒ Integer
The number of model units that was requested to be allocated to the Provisioned Throughput.
-
#foundation_model_arn ⇒ String
The Amazon Resource Name (ARN) of the base model for which the Provisioned Throughput was created, or of the base model that the custom model for which the Provisioned Throughput was created was customized.
-
#last_modified_time ⇒ Time
The time that the Provisioned Throughput was last modified.
-
#model_arn ⇒ String
The Amazon Resource Name (ARN) of the model associated with the Provisioned Throughput.
-
#model_units ⇒ Integer
The number of model units allocated to the Provisioned Throughput.
-
#provisioned_model_arn ⇒ String
The Amazon Resource Name (ARN) of the Provisioned Throughput.
-
#provisioned_model_name ⇒ String
The name of the Provisioned Throughput.
-
#status ⇒ String
The status of the Provisioned Throughput.
Instance Attribute Details
#commitment_duration ⇒ String
The duration for which the Provisioned Throughput was committed.
12319 12320 12321 12322 12323 12324 12325 12326 12327 12328 12329 12330 12331 12332 12333 12334 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12319 class ProvisionedModelSummary < Struct.new( :provisioned_model_name, :provisioned_model_arn, :model_arn, :desired_model_arn, :foundation_model_arn, :model_units, :desired_model_units, :status, :commitment_duration, :commitment_expiration_time, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#commitment_expiration_time ⇒ Time
The timestamp for when the commitment term of the Provisioned Throughput expires.
12319 12320 12321 12322 12323 12324 12325 12326 12327 12328 12329 12330 12331 12332 12333 12334 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12319 class ProvisionedModelSummary < Struct.new( :provisioned_model_name, :provisioned_model_arn, :model_arn, :desired_model_arn, :foundation_model_arn, :model_units, :desired_model_units, :status, :commitment_duration, :commitment_expiration_time, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time that the Provisioned Throughput was created.
12319 12320 12321 12322 12323 12324 12325 12326 12327 12328 12329 12330 12331 12332 12333 12334 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12319 class ProvisionedModelSummary < Struct.new( :provisioned_model_name, :provisioned_model_arn, :model_arn, :desired_model_arn, :foundation_model_arn, :model_units, :desired_model_units, :status, :commitment_duration, :commitment_expiration_time, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#desired_model_arn ⇒ String
The Amazon Resource Name (ARN) of the model requested to be associated to this Provisioned Throughput. This value differs from the ‘modelArn` if updating hasn’t completed.
12319 12320 12321 12322 12323 12324 12325 12326 12327 12328 12329 12330 12331 12332 12333 12334 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12319 class ProvisionedModelSummary < Struct.new( :provisioned_model_name, :provisioned_model_arn, :model_arn, :desired_model_arn, :foundation_model_arn, :model_units, :desired_model_units, :status, :commitment_duration, :commitment_expiration_time, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#desired_model_units ⇒ Integer
The number of model units that was requested to be allocated to the Provisioned Throughput.
12319 12320 12321 12322 12323 12324 12325 12326 12327 12328 12329 12330 12331 12332 12333 12334 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12319 class ProvisionedModelSummary < Struct.new( :provisioned_model_name, :provisioned_model_arn, :model_arn, :desired_model_arn, :foundation_model_arn, :model_units, :desired_model_units, :status, :commitment_duration, :commitment_expiration_time, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#foundation_model_arn ⇒ String
The Amazon Resource Name (ARN) of the base model for which the Provisioned Throughput was created, or of the base model that the custom model for which the Provisioned Throughput was created was customized.
12319 12320 12321 12322 12323 12324 12325 12326 12327 12328 12329 12330 12331 12332 12333 12334 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12319 class ProvisionedModelSummary < Struct.new( :provisioned_model_name, :provisioned_model_arn, :model_arn, :desired_model_arn, :foundation_model_arn, :model_units, :desired_model_units, :status, :commitment_duration, :commitment_expiration_time, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The time that the Provisioned Throughput was last modified.
12319 12320 12321 12322 12323 12324 12325 12326 12327 12328 12329 12330 12331 12332 12333 12334 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12319 class ProvisionedModelSummary < Struct.new( :provisioned_model_name, :provisioned_model_arn, :model_arn, :desired_model_arn, :foundation_model_arn, :model_units, :desired_model_units, :status, :commitment_duration, :commitment_expiration_time, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#model_arn ⇒ String
The Amazon Resource Name (ARN) of the model associated with the Provisioned Throughput.
12319 12320 12321 12322 12323 12324 12325 12326 12327 12328 12329 12330 12331 12332 12333 12334 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12319 class ProvisionedModelSummary < Struct.new( :provisioned_model_name, :provisioned_model_arn, :model_arn, :desired_model_arn, :foundation_model_arn, :model_units, :desired_model_units, :status, :commitment_duration, :commitment_expiration_time, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#model_units ⇒ Integer
The number of model units allocated to the Provisioned Throughput.
12319 12320 12321 12322 12323 12324 12325 12326 12327 12328 12329 12330 12331 12332 12333 12334 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12319 class ProvisionedModelSummary < Struct.new( :provisioned_model_name, :provisioned_model_arn, :model_arn, :desired_model_arn, :foundation_model_arn, :model_units, :desired_model_units, :status, :commitment_duration, :commitment_expiration_time, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#provisioned_model_arn ⇒ String
The Amazon Resource Name (ARN) of the Provisioned Throughput.
12319 12320 12321 12322 12323 12324 12325 12326 12327 12328 12329 12330 12331 12332 12333 12334 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12319 class ProvisionedModelSummary < Struct.new( :provisioned_model_name, :provisioned_model_arn, :model_arn, :desired_model_arn, :foundation_model_arn, :model_units, :desired_model_units, :status, :commitment_duration, :commitment_expiration_time, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#provisioned_model_name ⇒ String
The name of the Provisioned Throughput.
12319 12320 12321 12322 12323 12324 12325 12326 12327 12328 12329 12330 12331 12332 12333 12334 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12319 class ProvisionedModelSummary < Struct.new( :provisioned_model_name, :provisioned_model_arn, :model_arn, :desired_model_arn, :foundation_model_arn, :model_units, :desired_model_units, :status, :commitment_duration, :commitment_expiration_time, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the Provisioned Throughput.
12319 12320 12321 12322 12323 12324 12325 12326 12327 12328 12329 12330 12331 12332 12333 12334 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12319 class ProvisionedModelSummary < Struct.new( :provisioned_model_name, :provisioned_model_arn, :model_arn, :desired_model_arn, :foundation_model_arn, :model_units, :desired_model_units, :status, :commitment_duration, :commitment_expiration_time, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |