Class: Aws::Bedrock::Types::RerankingMetadataSelectiveModeConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::RerankingMetadataSelectiveModeConfiguration
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
RerankingMetadataSelectiveModeConfiguration is a union - when making an API calls you must set exactly one of the members.
RerankingMetadataSelectiveModeConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of RerankingMetadataSelectiveModeConfiguration corresponding to the set member.
Configuration for selectively including or excluding metadata fields during the reranking process. This allows you to control which metadata attributes are considered when reordering search results.
Direct Known Subclasses
Defined Under Namespace
Classes: FieldsToExclude, FieldsToInclude, Unknown
Constant Summary collapse
- SENSITIVE =
[:fields_to_include, :fields_to_exclude]
Instance Attribute Summary collapse
-
#fields_to_exclude ⇒ Array<Types::FieldForReranking>
A list of metadata field names to explicitly exclude from the reranking process.
-
#fields_to_include ⇒ Array<Types::FieldForReranking>
A list of metadata field names to explicitly include in the reranking process.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#fields_to_exclude ⇒ Array<Types::FieldForReranking>
A list of metadata field names to explicitly exclude from the reranking process. All metadata fields except these will be considered when reordering search results. This parameter cannot be used together with fieldsToInclude.
12737 12738 12739 12740 12741 12742 12743 12744 12745 12746 12747 12748 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12737 class RerankingMetadataSelectiveModeConfiguration < Struct.new( :fields_to_include, :fields_to_exclude, :unknown) SENSITIVE = [:fields_to_include, :fields_to_exclude] include Aws::Structure include Aws::Structure::Union class FieldsToInclude < RerankingMetadataSelectiveModeConfiguration; end class FieldsToExclude < RerankingMetadataSelectiveModeConfiguration; end class Unknown < RerankingMetadataSelectiveModeConfiguration; end end |
#fields_to_include ⇒ Array<Types::FieldForReranking>
A list of metadata field names to explicitly include in the reranking process. Only these fields will be considered when reordering search results. This parameter cannot be used together with fieldsToExclude.
12737 12738 12739 12740 12741 12742 12743 12744 12745 12746 12747 12748 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12737 class RerankingMetadataSelectiveModeConfiguration < Struct.new( :fields_to_include, :fields_to_exclude, :unknown) SENSITIVE = [:fields_to_include, :fields_to_exclude] include Aws::Structure include Aws::Structure::Union class FieldsToInclude < RerankingMetadataSelectiveModeConfiguration; end class FieldsToExclude < RerankingMetadataSelectiveModeConfiguration; end class Unknown < RerankingMetadataSelectiveModeConfiguration; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
12737 12738 12739 |
# File 'lib/aws-sdk-bedrock/types.rb', line 12737 def unknown @unknown end |