Class: Aws::Bedrock::Types::ResourceInUseException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrock/types.rb

Overview

Thrown when attempting to delete or modify a resource that is currently being used by other resources or operations. For example, trying to delete an Automated Reasoning policy that is referenced by an active guardrail.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


12760
12761
12762
12763
12764
# File 'lib/aws-sdk-bedrock/types.rb', line 12760

class ResourceInUseException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end