Class: Aws::Bedrock::Types::SageMakerEndpoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::Bedrock::Types::SageMakerEndpoint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrock/types.rb
Overview
Specifies the configuration for a Amazon SageMaker endpoint.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#execution_role ⇒ String
The ARN of the IAM role that Amazon SageMaker can assume to access model artifacts and docker image for deployment on Amazon EC2 compute instances or for batch transform jobs.
-
#initial_instance_count ⇒ Integer
The number of Amazon EC2 compute instances to deploy for initial endpoint creation.
-
#instance_type ⇒ String
The Amazon EC2 compute instance type to deploy for hosting the model.
-
#kms_encryption_key ⇒ String
The Amazon Web Services KMS key that Amazon SageMaker uses to encrypt data on the storage volume attached to the Amazon EC2 compute instance that hosts the endpoint.
-
#vpc ⇒ Types::VpcConfig
The VPC configuration for the endpoint.
Instance Attribute Details
#execution_role ⇒ String
The ARN of the IAM role that Amazon SageMaker can assume to access model artifacts and docker image for deployment on Amazon EC2 compute instances or for batch transform jobs.
13096 13097 13098 13099 13100 13101 13102 13103 13104 |
# File 'lib/aws-sdk-bedrock/types.rb', line 13096 class SageMakerEndpoint < Struct.new( :initial_instance_count, :instance_type, :execution_role, :kms_encryption_key, :vpc) SENSITIVE = [] include Aws::Structure end |
#initial_instance_count ⇒ Integer
The number of Amazon EC2 compute instances to deploy for initial endpoint creation.
13096 13097 13098 13099 13100 13101 13102 13103 13104 |
# File 'lib/aws-sdk-bedrock/types.rb', line 13096 class SageMakerEndpoint < Struct.new( :initial_instance_count, :instance_type, :execution_role, :kms_encryption_key, :vpc) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The Amazon EC2 compute instance type to deploy for hosting the model.
13096 13097 13098 13099 13100 13101 13102 13103 13104 |
# File 'lib/aws-sdk-bedrock/types.rb', line 13096 class SageMakerEndpoint < Struct.new( :initial_instance_count, :instance_type, :execution_role, :kms_encryption_key, :vpc) SENSITIVE = [] include Aws::Structure end |
#kms_encryption_key ⇒ String
The Amazon Web Services KMS key that Amazon SageMaker uses to encrypt data on the storage volume attached to the Amazon EC2 compute instance that hosts the endpoint.
13096 13097 13098 13099 13100 13101 13102 13103 13104 |
# File 'lib/aws-sdk-bedrock/types.rb', line 13096 class SageMakerEndpoint < Struct.new( :initial_instance_count, :instance_type, :execution_role, :kms_encryption_key, :vpc) SENSITIVE = [] include Aws::Structure end |
#vpc ⇒ Types::VpcConfig
The VPC configuration for the endpoint.
13096 13097 13098 13099 13100 13101 13102 13103 13104 |
# File 'lib/aws-sdk-bedrock/types.rb', line 13096 class SageMakerEndpoint < Struct.new( :initial_instance_count, :instance_type, :execution_role, :kms_encryption_key, :vpc) SENSITIVE = [] include Aws::Structure end |